<?php

use Elementor\{Plugin,
	Controls_Manager,
	Group_Control_Typography,
	Repeater,
	Utils
};


define( 'TT_ELEMENTOR_ADDONS_URL', plugins_url( '/', __FILE__ ) );
define( 'TT_ELEMENTOR_ADDONS_PATH', plugin_dir_path( __FILE__ ) );
define( 'TT_ELEMENTOR_ADDONS_FILE', __FILE__ );

//define version
define('QUIETY_ADDONS_VERSION_', '3.1.5');

// define render css
define('QUIETY_ADDONS_CSS_RENDER_', true);

// define minify render css
define('QUIETY_ADDONS_CSS_RENDER_MINIFY', false);

// render icon from css files
define('QUIETY_ADDONS_ICON_RENDER', false);

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Quiety_Shortcode {
	/**
	 * Holds the class object.
	 *
	 * @since 1.0
	 *
	 */
	public static $_instance;

	/**
	 * Localize data array
	 *
	 * @var array
	 */
	public $localize_data = array();

	/**
	 * Elmentor widget directory path
	 *
	 * @var string
	 */
	public $dir_path = '';

	/**
	 * Load Construct
	 *
	 * @since 1.0
	 */

	public function __construct() {

		$this->dir_path = plugin_dir_path( __FILE__ );
		add_action( 'plugins_loaded', [ $this, 'elementor_setup' ] );

		add_action( 'elementor/init', [ $this, 'quiety_elementor_init' ] );
		add_action( 'elementor/frontend/before_enqueue_scripts', [ $this, 'before_enqueue_scripts' ] );
		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'after_register_scripts' ] );

	}

	public function after_register_scripts() {
		wp_register_script( 'countUp', QUIETY_SCRIPTS . '/countUp.min.js', array( 'jquery' ), QUIETY_CORE_VERSION, true );
		wp_register_script( 'appear-js', QUIETY_SCRIPTS . '/jquery.appear.js', array( 'jquery' ), QUIETY_CORE_VERSION, true );
		wp_register_script( 'countTo', QUIETY_SCRIPTS . '/jquery.countTo.js', array( 'jquery' ), QUIETY_CORE_VERSION, true );
		wp_register_script( 'parallax-scroll', QUIETY_SCRIPTS . '/jquery.parallax-scroll.js', array( 'jquery' ), QUIETY_CORE_VERSION, true );
		wp_register_script( 'gmap3', QUIETY_SCRIPTS . '/gmap.js', array( 'jquery' ), QUIETY_CORE_VERSION, true );
		wp_register_script( 'isotope', QUIETY_SCRIPTS . '/isotope.pkgd.min.js', array( 'jquery' ), QUIETY_CORE_VERSION, true );
		wp_register_script( 'parallax', QUIETY_SCRIPTS . '/parallax.min.js', array( 'jquery' ), QUIETY_CORE_VERSION, true );
		wp_register_script( 'jquery-parallax', QUIETY_SCRIPTS . '/jquery.parallax.min.js', array( 'jquery' ), QUIETY_CORE_VERSION, true );
		wp_register_script( 'jquery-parallax', QUIETY_SCRIPTS . '/jquery.parallax.min.js', array( 'jquery' ), QUIETY_CORE_VERSION, true );

        wp_enqueue_script('swiper', QUIETY_VEND . '/swiper/swiper.min.js', array(),  '8.3.1', true);

        wp_register_script( 'countdown', QUIETY_SCRIPTS . '/jquery.countdown.js', array( 'jquery' ), QUIETY_CORE_VERSION, true );
	}

	/**
	 * Enqueue Scripts
	 *
	 * @return void
	 */

	public function before_enqueue_scripts() {
		wp_enqueue_script( 'quiety-elementor', QUIETY_SCRIPTS . '/elementor.js', array(
			'jquery',
			'elementor-frontend'
		), QUIETY_CORE_VERSION, true );
	}

	/**
	 * Elementor Initialization
	 *
	 * @since 1.0
	 *
	 */

	public function quiety_elementor_init() {
		\Elementor\Plugin::$instance->elements_manager->add_category(
		'tt-elements', [
				'title' => esc_html__( 'Quiety Elements', 'quiety-core' ),
				'icon'  => 'fa fa-plug',
			]
		);
	}

	/**
	 * Installs default variables and checks if Elementor is installed
	 *
	 * @return void
	 */
	public function elementor_setup() {
		/**
		 * Check if Elementor installed and activated
		 * @see https://developers.elementor.com/creating-an-extension-for-elementor/
		 */
		if ( ! did_action( 'elementor/loaded' ) ) {
			return;
		}

		// Include Modules files
		$this->includes();

		$this->init_addons();
	}

	/**
	 * Load required core files.
	 */
	public function includes() {
		$this->init_helper_files();
	}

	/**
	 * Require initial necessary files
	 */
	public function init_helper_files() {
		require_once $this->dir_path . 'includes/icon_settings.php';

		include_once $this->dir_path . 'modules/templates/api.php';
		include_once $this->dir_path . 'modules/templates/import.php';
		include_once $this->dir_path . 'modules/templates/init.php';
		include_once $this->dir_path . 'modules/templates/load.php';

		\QUIETY_ELEMENTOR\Templates\DL_Import::instance()->load();
		\QUIETY_ELEMENTOR\Templates\Dl_Load::instance()->load();
		\QUIETY_ELEMENTOR\Templates\DL_Templates::instance()->init();
	}

	/**
	 * Load required file for addons integration
	 */
	public function init_addons() {
		add_action( 'elementor/widgets/register', [ $this, 'widgets_area' ] );
		add_action( 'elementor/controls/controls_registered', [ $this, 'controls_area' ] );

		//        // Register Frontend Widget Scripts
		//        add_action('elementor/frontend/after_register_scripts', [$this, 'register_widget_scripts']);
		//
		//        // Register Backend Widget Scripts
		//        add_action('elementor/editor/before_enqueue_scripts', [$this, 'extensions_scripts']);
		//
		$this->init_modules_files();
	}


	/**
	 * Register widgets by file name
	 */
	public function register_widgets_addon( $file_name ) {
		$widget_manager = Plugin::instance()->widgets_manager;

		$base  = basename( str_replace( '.php', '', $file_name ) );
		$class = ucwords( str_replace( '-', ' ', $base ) );
		$class = str_replace( ' ', '_', $class );
		$class = sprintf( 'Quiety\Widgets\%s', $class ); // Ultraland\Widgets\abc;


		// Class File
		require_once $file_name;

		if ( class_exists( $class ) ) {
			$widget_manager->register_widget_type( new $class );
		}
	}

	/**
	 * Load widgets require function
	 */
	public function widgets_area() {
		$this->widgets_register();
	}

	/**
	 * Requires widgets files
	 */
	private function widgets_register() {
		foreach ( glob( $this->dir_path . 'widgets/' . '*.php' ) as $file ) {
			$this->register_widgets_addon( $file );
		}
	}

	/**
	 * Load controls require function
	 */
	public function controls_area() {
		$this->controls_register();
	}

	/**
	 * Requires controls files
	 */
	private function controls_register() {
		foreach ( glob( $this->dir_path . 'controls/' . '*.php' ) as $file ) {
			$this->register_controls_addon( $file );
		}
	}

	/**
	 * Register addon by file name.
	 */
	public function register_controls_addon( $file_name ) {
		$controls_manager = Plugin::$instance->controls_manager;

		$base  = basename( str_replace( '.php', '', $file_name ) );
		$class = ucwords( str_replace( '-', ' ', $base ) );
		$class = str_replace( ' ', '_', $class );
		$class = sprintf( 'Quiety\Controls\%s', $class );

		// Class Constructor File
		require_once $file_name;

		if ( class_exists( $class ) ) {
			$name_class = new $class();
			$controls_manager->register_control( $name_class->get_type(), new $class );
		}
	}

	/**
	 * Require initial necessary files
	 */
	public function init_modules_files() {
		foreach ( glob( $this->dir_path . 'section/' . '*.php' ) as $file ) {
			$this->register_modules_addon( $file );
		}
	}

	/**
	 * Register addon by file name
	 */
	public function register_modules_addon( $file_name ) {
		$base  = basename( str_replace( '.php', '', $file_name ) );
		$class = ucwords( str_replace( '-', ' ', $base ) );
		$class = str_replace( ' ', '_', $class );
		$class = sprintf( 'Quiety\Section\%s', $class );

		// Class File
		require_once $file_name;

		if ( class_exists( $class ) ) {
			new $class();
		}
	}

	public static function ultraland_get_instance() {
		if ( ! isset( self::$_instance ) ) {
			self::$_instance = new Quiety_Shortcode();
		}

		return self::$_instance;
	}
}

$quiety_shortcode = Quiety_Shortcode::ultraland_get_instance();

