<?php

namespace Quiety\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\{Group_Control_Background,
	Group_Control_Border,
	Group_Control_Box_Shadow,
	Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Repeater};


class quiety_about_slider extends \Elementor\Widget_Base {

	public function get_name() {
		return 'quiety_about_slider';
	}

	public function get_title() {
		return esc_html__( 'Quiey About Slider', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-code';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	public function get_keywords() {
		return [ 'about-slider', 'slider', 'about', 'about slider' ];
	}

    protected function register_controls() {
        $this->register_content();
        $this->register_style();
    }

    public function register_content() {

        $this->start_controls_section(
            'about_slider_content_section', 
            [
                'label'     => esc_html__( 'Slider Content', 'quiety-core'), 
                'tab'       => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        ); 

        $this->add_control(
            'quiete_about_single_slide', 
            [
                'label'     => esc_html__('Single Slide Item', 'quiety-core'), 
                'type'      => \Elementor\Controls_Manager::REPEATER,
                'fields'    => [
                    [
                        'name'      => 'slide_img',
                        'label'     => esc_html__('Slide Image', 'quiety-core'),
                        'type'      => \Elementor\Controls_Manager::MEDIA,
                        'default' => [
                            'url' => \Elementor\Utils::get_placeholder_image_src(),
                        ],
                    ], 
                    [
                        'name'     => 'slide_title', 
                        'label'    => esc_html__('Slide Title', 'quiety-core'), 
                        'label_block' => true,
                        'type'     => \Elementor\Controls_Manager::TEXT,
                        'default' => esc_html__( 'What is CRM', 'quiety-core' ),
				        'placeholder' => esc_html__( 'Slide Title', 'quiety-core' ),
					], 
					[
						'name'     		=> 'slide_description',
						'label'    		=> esc_html__('Slide Description', 'quiety-core'),
						'label_block' 	=> true,
						'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
						'default'       => esc_html__('Bring in quality leads, nurture them, in a single place.', 'quiety-core'),
					], 
					[
						'name' 			=> 'button_text', 
						'label' 		=> esc_html__('Button Text', 'quiety-core'),
						'label_block' 	=> true,
						'type' 			=> \Elementor\Controls_Manager::TEXT,
						'default' 		=> esc_html__('Explore More'), 
					], 

					[
						'name' 			=> 'button_link', 
						'label' 		=> esc_html__('Button Link', 'quiety-core'),
						'label_block' 	=> true,
						'type' 			=> \Elementor\Controls_Manager::TEXT,
						'default' 		=> esc_html__('#'), 
					], 

					[
						'name'  => 'button_icon',
						'label' => esc_html__( 'Button Icon', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::ICONS,
						'default' => [
							'value' => 'fas fa-circle',
							'library' => 'fa-solid',
						],
					]
                ]
            ]
        );

        $this->end_controls_section();
    }

    public function register_style() {
        $this->start_controls_section(
			'about_slider_style', 
			[
				'label'     => esc_html__( 'Slider Style', 'quiety-core'), 
            	'tab'       => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs('style_normal_tabs'); 

		$this->start_controls_tab(
			'style_normal', 
			[
				'label'    => esc_html__('Normal Style', 'quiety-core'),
			]
		);

		$this->add_control(
			'text_align',
			[
				'label' => esc_html__( 'Alignment', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'quiety-core' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'quiety-core' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'quiety-core' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'toggle' => true,
				'selectors' => [
					'{{WRAPPER}} .crm-htw-single' => 'text-align: {{VALUE}};',
				],
			]
		);
		
		$this->add_group_control(
			\ELEMENTOR\Group_Control_Typography::get_type(), 
			[
				'name'    => 'text_typography', 
				'selector'  => '{{WRAPPER}} .crm-htw-single p',
			]
		);

		$this->add_control(
			'button_color', 
			[
				'label'    => 'Button Color', 
				'type'     => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .crm-htw-single .read-more-link'  => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\ELEMENTOR\Group_Control_Typography::get_type(),
			[
				'name'    => 'button_typography', 
				'selector'  => '{{WRAPPER}} .crm-htw-single .read-more-link',
			]
		);

		$this->add_control(
			'slider_bg', 
			[
				'label'     => esc_html__('Background Color', 'quiety-core'),
				'type' 		=> \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .crm-htw-single' => 'background-color: {{VALUE}}',
				]
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'selector' => '{{WRAPPER}} .crm-htw-single',
			]
		);

		$this->add_control(
			'border_radius', 
			[
				'label'  		=> esc_html__('Border Radius', 'quiety-core'),
				'type'   		=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' 	=> ['px', '%', 'em', 'rem', 'custom'],
				'selectors'     => [
					'{{WRAPPER}} .crm-htw-single' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->add_group_control(
			\ELEMENTOR\Group_Control_Box_Shadow::get_type(), 
			[
				'name'   => 'box_shadow',
				'selector' => '{{WRAPPER}} .crm-htw-single',
			]
		);

		$this->add_control(
			'title_color', 
			[
				'label'    => esc_html__('Title Color', 'quiety-core'), 
				'type'     => \Elementor\Controls_Manager::COLOR,
				'selectors'  => [
					'{{WRAPPER}} .crm-htw-single h6'  => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\ELEMENTOR\Group_Control_Typography::get_type(),
			[
				'name'  => 'title_typography', 
				'selector' 	=> '{{WRAPPER}} .crm-htw-single h6',
			]
		);

		$this->add_control(
			'text_color', 
			[
				'label'    => esc_html__('Text Color', 'quiety-core'),
				'type'     => \Elementor\Controls_Manager::COLOR,
				'selectors'  => [
					'{{WRAPPER}} .crm-htw-single p'  => 'color: {{VALUE}}',
				],
			]
		);
		$this->end_controls_tab();

		$this->start_controls_tab(
			'hover_style', 
			[
				'label'    => esc_html__('Hover', 'quiety-core'), 
			]
		); 

		$this->add_group_control(
			\ELEMENTOR\Group_Control_Box_Shadow::get_type(),
			[
				'name'   => 'box_hover_shadow',
				'selector' => '{{WRAPPER}} .crm-htw-single:hover',
			]
		);

		$this->add_control(
			'hover_border_color',
			[
				'label'   => esc_html__('Border Color', 'quiety-core'),
				'type'  => \Elementor\Controls_Manager::COLOR,
				'selectors'  => [
					'{{WRAPPER}} .crm-htw-single:hover' => 'border-color: {{VALUE}}',
				]
			] 
		);

		$this->add_control(
			'button_hover_color',
			[
				'label' => esc_html__('Button Hover Color', 'quiety-core'),
				'type'  => \Elementor\Controls_Manager::COLOR, 
				'selectors'  => [
					'{{WRAPPER}} .crm-htw-single .read-more-link:hover' => 'color: {{VALUE}}',
				]
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();


		$this->end_controls_section();

		//===================== Slider Control ======================//
		$this->start_controls_section('sec_slider_control', [
			'label' => esc_html__('Slider Control', 'quiety-core')
		]);

		$this->add_control('loop', [
			'label'        => esc_html__('Loop', 'quiety-core'),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__('On', 'quiety-core'),
			'label_off'    => esc_html__('Off', 'quiety-core'),
			'return_value' => 'yes',
			'default'      => 'yes'
		]);

		$this->add_control('speed', [
			'label'   => __('Speed', 'quiety-core'),
			'type'    => Controls_Manager::NUMBER,
			'default' => 700,
		]);

		$this->add_control('autoplay', [
			'label'        => esc_html__('Autoplay', 'quiety-core'),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__('On', 'quiety-core'),
			'label_off'    => esc_html__('Off', 'quiety-core'),
			'return_value' => 'yes',
			'default'      => 'yes'
		]);

		$this->add_control('autoplay_time', [
			'label'   => __('Autoplay Time', 'quiety-core'),
			'type'    => Controls_Manager::NUMBER,
			'default' => 3000,
			'condition' => [
				'autoplay' => 'yes'
			]
		]);

		$this->add_control(
			'show_items_desktop',
			[
				'label'     => esc_html__('Display Items [Desktop]', 'quiety-core'),
				'type'      => Controls_Manager::NUMBER,

			]
		);
		$this->add_control(
			'show_items_tablet',
			[
				'label'     => esc_html__('Display Items [Tablet]', 'quiety-core'),
				'type'      => Controls_Manager::NUMBER,

			]
		);
		$this->add_control(
			'show_items_mobile',
			[
				'label'     => esc_html__('Display Items [Mobile]', 'quiety-core'),
				'type'      => Controls_Manager::NUMBER,
				'default'	=> 1
			]
		);
		$this->add_control(
			'item_space',
			[
				'label' => __('Item Space', 'quiety-core'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
						'step' => 1,
					]
				],
				'default' => [
					'size' => 24,
				]
			]
		);

		$this->end_controls_section();
    }

	protected function render() {
		$settings = $this->get_settings_for_display();
		extract($settings);

		if ( $settings['quiete_about_single_slide'] ) { ?>
				
			<div class="crm-htw-slider overflow-hidden swiper ms-lg-3 mt-4 mt-lg-0"
				<?php 
				echo quiety_swiper_attrebutes( 
					$show_items_desktop, 
					$loop, 
					$autoplay, 
					$autoplay_time, 
					$speed, 
					$item_space['size'], 
					$show_items_tablet, 
					$show_items_mobile,
					'progressbar',
					'.swiper-pagination'
				) ?> >
				<div class="swiper-wrapper">

					<?php
					$total_slide = !empty($quiete_about_single_slide) ? count($quiete_about_single_slide) : '';
					 foreach( $settings['quiete_about_single_slide'] as $item ) { ?>

						<div class="crm-htw-single swiper-slide">

							<?php if( !empty($item['slide_img']) ) { 
								echo wp_get_attachment_image($item['slide_img']['id'], 'full', '', array( 'class' => 'img-fluid mb-30' )); 
							} 

							if ( !empty($item['slide_title']) ) { ?>
								<h6 class='mb-2'><?php echo esc_html($item['slide_title']); ?></h6>
							<?php }

							if ( !empty($item['slide_description']) ) { ?>
								<p class='mb-2'><?php echo esc_html($item['slide_description']); ?></p>
							<?php }

							if ( !empty($item['button_text']) ) { ?>
								<a href="<?php echo esc_attr($item['button_link']); ?>" class='read-more-link'><?php echo esc_html($item['button_text']); \Elementor\Icons_Manager::render_icon( $item['button_icon'], [ 'aria-hidden' => 'true' ] ); ?></a>
							<?php } ?>

						</div>
					<?php } ?>
				</div>
				<div class="pagination-wrapper">
					<span class="crm_init_value slide_counter">01</span>
					<div class="swiper-pagination"></div>
					<span class="crm_total_value slide_counter"><?php echo esc_html( str_pad($total_slide, 2, 0, STR_PAD_LEFT)) ?></span>
				</div>
			</div>

		<?php } ?>

	<?php }

}