<?php

namespace Quiety\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\{Group_Control_Background,
	Group_Control_Border,
	Group_Control_Box_Shadow,
	Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Repeater};


class Quiety_Accordion extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-accordion';
	}

	// public function get_id() {
	//    	return 'header-search';
	// }

	public function get_title() {
		return __( 'Quiety Accordion', 'quiety-core' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-accordion';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {
		//select option start ------------------------------------------------
		$this->start_controls_section(
			'style_section',
			[
				'label' => esc_html__( 'Accordion Style', 'quiety-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'layout',
			[
				'label' => esc_html__( 'Select Style', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1' => esc_html__( 'Style 01', 'quiety-core' ),
					'2' => esc_html__( 'Style 02', 'quiety-core' ),
					'3' => esc_html__( 'Style 03', 'quiety-core' ),
					'4' => esc_html__( 'Style 04', 'quiety-core' ),
					'5' => esc_html__( 'Style 05', 'quiety-core' ),
				]
			]
		);
		$this->end_controls_section();

		//select option close -----------------------------------------
		$this->start_controls_section( 'section_content', [
			'label' => __( 'Content', 'quiety-core' ),
			'condition' => [
					'layout!' => '4',
			]
		] );

		$repeater = new Repeater();

		$repeater->add_control( 'accordion_title', [
			'label'       => __( 'Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => __( 'List Title', 'quiety-core' ),
			'label_block' => true,
		] );
		
		$repeater->add_control( 'accordion_content', [
			'label'      => __( 'Content', 'quiety-core' ),
			'type'       => Controls_Manager::WYSIWYG,
			'default'    => __( 'List Content', 'quiety-core' ),
			'show_label' => false,
		] );

		$repeater->add_control(
			'show_icon',
			[
				'label' => __( 'Show Icon', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'your-plugin' ),
				'label_off' => __( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$repeater->add_control( 'accordion_icon', [
			'label'     => __( 'Icon', 'quiety-core' ),
			'type'      => Controls_Manager::ICONS,
			'default'   => [
				'value'   => 'fas fa-star',
				'library' => 'solid',
			],
			'condition' => ['show_icon' => 'yes']
		] );


		$this->add_control( 'tt-accordion', [
			'label'       => __( 'Accordion List', 'quiety-core' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'accordion_title'   => __( 'Is SEO a risky and time consuming proposition?', 'quiety-core' ),
					'accordion_content' => __( 'There are many variations of passages of Lorem Ipsum available but the majority suffered is alteration in that  words which don\'t look even slightly believable. If you are Lorem Ipsum you need to be sure there isn\'t anything ready too much embarrassing.', 'quiety-core' ),
				],
				[
					'accordion_title'   => __( 'How to choose a perfect digital marketing plan?', 'quiety-core' ),
					'accordion_content' => __( 'There are many variations of passages of Lorem Ipsum available but the majority suffered is alteration in that  words which don\'t look even slightly believable. If you are Lorem Ipsum you need to be sure there isn\'t anything ready too much embarrassing.', 'quiety-core' ),
				],
				[
					'accordion_title'   => __( 'Is it feasible to go for a complete website audit?', 'quiety-core' ),
					'accordion_content' => __( 'There are many variations of passages of Lorem Ipsum available but the majority suffered is alteration in that  words which don\'t look even slightly believable. If you are Lorem Ipsum you need to be sure there isn\'t anything ready too much embarrassing.', 'quiety-core' ),
				],
				[
					'accordion_title'   => __( 'How to go about with a bespoke SMO strategy?', 'quiety-core' ),
					'accordion_content' => __( 'There are many variations of passages of Lorem Ipsum available but the majority suffered is alteration in that  words which don\'t look even slightly believable. If you are Lorem Ipsum you need to be sure there isn\'t anything ready too much embarrassing.', 'quiety-core' ),
				],
				[
					'accordion_title'   => __( 'Is internet marketing expensive?', 'quiety-core' ),
					'accordion_content' => __( 'There are many variations of passages of Lorem Ipsum available but the majority suffered is alteration in that  words which don\'t look even slightly believable. If you are Lorem Ipsum you need to be sure there isn\'t anything ready too much embarrassing.', 'quiety-core' ),
				],
			],
			'title_field' => '{{{ accordion_title }}}',
		] );

		$this->end_controls_section();


		// repeater 4 style start -------------------------------
		$this->start_controls_section(
			'accordion4_section',
			[
				'label' => esc_html__( 'Accordion', 'quiety-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => [
					'layout' => '4',
				]
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'tab_title',
			[
				'label' => esc_html__( 'Tab Title', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'About Us' , 'quiety-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'accor_title',
			[
				'label' => esc_html__( 'Accordion Title', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Where are You Based?' , 'quiety-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'accor_content',
			[
				'label' => esc_html__( 'Content', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => esc_html__( 'List Title' , 'quiety-core' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'accordion4_sec',
			[
				'label' => esc_html__( 'Repeater List', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'tab_title' => esc_html__( 'About Us', 'quiety-core' ),
						'accor_title' => esc_html__( 'Where are You Based?', 'quiety-core' ),
					],
				],
				'title_field' => '{{{ tab_title }}}',
			]
		);
		$this->end_controls_section();


		/**
		 *  Accordian Style Controls
		 */

		$this->start_controls_section( 'title_style__section', [
			'label' => __( 'Title', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .quiety-accordion .accordion-button, {{WRAPPER}} .custom-accordion .accordion-button, {{WRAPPER}} .accordion-title-style',
		] );

		$this->add_control( 'faq_title_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .quiety-accordion .accordion-button.collapsed' => 'color: {{VALUE}}',
				'{{WRAPPER}} .custom-accordion .accordion-button, {{WRAPPER}} .accordion-title-style' => 'color: {{VALUE}}',
			],
		] );

		$this->add_control( 'faq_title_active_color', [
			'label'     => __( 'Active Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .quiety-accordion .accordion-button:not(.collapsed)' => 'color: {{VALUE}}',
				'{{WRAPPER}} .custom-accordion .accordion-button' => 'color: {{VALUE}}',
			],
		] );
		$this->add_control('accordion_active_title_bg', [
			'label'     => __('Title Background', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .quiety-accordion .accordion-item.active .accordion-header' => 'background: {{VALUE}}',
				'{{WRAPPER}} .custom-accordion .accordion-button' => 'background: {{VALUE}}',
			],
		]);

		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__( 'Padding', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .quiety-accordion .accordion-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .custom-accordion .accordion-button, {{WRAPPER}} .accordion-title-style' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->end_controls_section();

		$this->start_controls_section( 'content_style_section', [
			'label' => __( 'Content', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'faq_ontent_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .accordion-body, {{WRAPPER}} .accordion-content-style',
		] );

		$this->add_control( 'faq_content_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .accordion-body, {{WRAPPER}} .accordion-content-style, {{WRAPPER}} .accordion-content-style p' => 'color: {{VALUE}}',
			],
		] );
		$this->add_control(
			'content_padding',
			[
				'label' => esc_html__('Padding', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors' => [
					'{{WRAPPER}} .accordion-collapse.collapse.show .accordion-body, {{WRAPPER}} .accordion-content-style' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};transition:0.4s;',
				],
			]
		);
		$this->end_controls_section();
		
		// Accordion Icon Style ==============================
		$this->start_controls_section( 'icon_style_section', [
			'label' => __( 'Icon', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );
		$this->add_control(
			'accordion_normal_icon',
			[
				'label' => esc_html__('Normal ', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control( 'accordion_icon_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .quiety-accordion .accordion-button.collapsed:after' => 'color: {{VALUE}}',
			],
		] );
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'accordion_icon_bg',
				'label' => esc_html__('Background', 'quiety-core'),
				'types' => ['classic', 'gradient'],
				'selector' => '{{WRAPPER}} .quiety-accordion .accordion-button.collapsed:after',
			]
		);

		$this->add_control(
			'accordion_active_icon',
			[
				'label' => esc_html__('Active ', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_control( 'accordion_active_icon_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .quiety-accordion .accordion-button:not(.collapsed):after' => 'color: {{VALUE}}',
			],
		] );
		
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'accordion_active_icon_bg',
				'label' => esc_html__('Background', 'quiety-core'),
				'types' => ['classic', 'gradient'],
				'selector' => '{{WRAPPER}} .quiety-accordion .accordion-button:not(.collapsed):after',
			]
		);

		$this->end_controls_section();
		// End Accordion Icon Style ==============================


		$this->start_controls_section( 'box_style_section', [
			'label' => __( 'Box Wrapper', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
			'condition' => [
				'layout' => '1',
			]
		] );

		$this->add_control(
			'box_border_radius',
			[
				'label' => __( 'Border Radius', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .accordion-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'faq_margin_bottom',
			[
				'label' => esc_html__( 'Space Between', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .quiety-accordion .accordion-item:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}} !important;',
				],
			]
		);


		$this->start_controls_tabs(
			'style_tabs'
		);

		$this->start_controls_tab(
			'style_normal_tab',
			[
				'label' => esc_html__( 'Normal', 'quiety-core' ),
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'acc_background',
				'label' => __( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .accordion-item',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'acc_border',
				'label' => __( 'Border', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .accordion-item',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_box_shadow',
				'label' => __( 'Box Shadow', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .accordion-item',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_hover_tab',
			[
				'label' => esc_html__( 'Hover', 'quiety-core' ),
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'acc_background_active',
				'label' => __( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .accordion-item.active',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'acc_border_active',
				'label' => __( 'Border', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .accordion-item.active',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_box_shadow_active',
				'label' => __( 'Box Shadow', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .accordion-item.active',
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->end_controls_section();

	}

	protected function render() {

		$settings  = $this->get_settings_for_display();
		$accordion = $settings['tt-accordion'];
		extract($settings);

		$faq_id = 'quiety-accordion-' . substr( $this->get_id_int(), 0, 3 );
		$faq    = 'quiety-acc-' . substr( $this->get_id_int(), 0, 3 );
		$faq_o  = 'quiety-acco-' . substr( $this->get_id_int(), 0, 3 );

		include __DIR__ . '/templates/accordion/layout-'.$layout.'.php';
		?>

		
		
		<?php


	}
}