<?php

namespace Quiety\Widgets;

if (! defined('ABSPATH')) {
	exit;
}

use Elementor\{Group_Control_Box_Shadow, Widget_Base, Controls_Manager, Group_Control_Typography, Group_Control_Border};


class Quiety_Button extends Widget_Base
{

	public function get_name()
	{
		return 'tt-button';
	}

	public function get_title()
	{
		return __('Quiety Button', 'quiety-core');
	}

	public function get_icon()
	{
		return 'eicon-button';
	}

	public function get_categories()
	{
		return ['tt-elements'];
	}

	/**
	 * Get button sizes.
	 *
	 * Retrieve an array of button sizes for the button widget.
	 *
	 * @return array An array containing button sizes.
	 * @since 1.0.0
	 * @access public
	 * @static
	 *
	 */
	public static function get_button_sizes()
	{
		return [
			'btn-xs' => __('Extra Small', 'quiety-core'),
			'btn-sm' => __('Small', 'quiety-core'),
			'btn-md' => __('Medium', 'quiety-core'),
			'btn-lg' => __('Large', 'quiety-core'),
			'btn-xl' => __('Extra Large', 'quiety-core'),
		];
	}

	/**
	 * Register button widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls()
	{

		$this->start_controls_section(
			'section_button',
			[
				'label' => __('Button', 'quiety-core'),
			]
		);

		$this->add_control(
			'btn_style',
			[
				'label' => __('Button Style', 'quiety-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'1' => __('Default', 'quiety-core'),
					'2' => __('Play Button', 'quiety-core'),
					'3' => __('Button', 'quiety-core'),
				],
				'default' => '1',
			]
		);


		$this->add_control(
			'button_size',
			[
				'label' => __('Size', 'quiety-core'),
				'type' => Controls_Manager::SELECT,
				'default' => 'btn-md',
				'options' => $this->get_button_sizes(),
			]
		);

		$this->add_control(
			'button_shape',
			[
				'label' => __('Shape', 'quiety-core'),
				'type' => Controls_Manager::SELECT,
				'default' => 'btn-round',
				'options' => [
					'btn-square' => __('Square', 'quiety-core'),
					'btn-round' => __('Round', 'quiety-core'),
					'btn-circle' => __('Circle', 'quiety-core'),
				],
				'condition' => [
					'style' => '1'
				]
			]
		);

		$this->add_control(
			'button_style',
			[
				'label' => __('Shape Style', 'quiety-core'),
				'type' => Controls_Manager::SELECT,
				'default' => 'btn-default',
				'options' => [
					'btn-default' => __('Default', 'quiety-core'),
					'btn-outline' => __('Outline', 'quiety-core'),
				],
				'condition' => [
					'style' => '1'
				]
			]
		);

		$this->add_control(
			'text',
			[
				'label' => __('Text', 'quiety-core'),
				'type' => Controls_Manager::TEXT,
				'default' => __('Learn More', 'quiety-core'),
				'placeholder' => __('Button Text', 'quiety-core'),
			]
		);

		$this->add_control(
			'link',
			[
				'label' => __('Link', 'quiety-core'),
				'type' => Controls_Manager::URL,
				'placeholder' => 'http://your-link.com',
				'default' => [
					'url' => '#',
				],
			]
		);

		$this->add_control('selected_icon', [
			'label'     => __('Icon', 'quiety-core'),
			'type'      => Controls_Manager::ICONS,
			'default'   => [
				'value'   => 'fas fa-arrow-right',
				'library' => 'solid',
			],
		]);

		$this->add_control(
			'icon_align',
			[
				'label' => __('Icon Position', 'quiety-core'),
				'type' => Controls_Manager::SELECT,
				'default' => 'right',
				'options' => [
					'left' => __('Before', 'quiety-core'),
					'right' => __('After', 'quiety-core'),
				],
				'condition' => [
					'selected_icon!' => '',
				],
			]
		);

		$this->add_control(
			'icon_indent',
			[
				'label' => __('Icon Spacing', 'quiety-core'),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
					],
				],
				'condition' => [
					'selected_icon!' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .tt-btn .elementor-align-icon-right' => 'margin-left: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .tt-btn .elementor-align-icon-left' => 'margin-right: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'is_hover_translate',
			[
				'label' => esc_html__('Show Hover Icon Effect', 'plugin-name'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'your-plugin'),
				'label_off' => esc_html__('Hide', 'your-plugin'),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
					'btn_style' => '1'
				]
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label' => __('Alignment', 'quiety-core'),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __('Left', 'quiety-core'),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __('Center', 'quiety-core'),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __('Right', 'quiety-core'),
						'icon' => 'fa fa-align-right',
					],
					'justify' => [
						'title' => __('Justified', 'quiety-core'),
						'icon' => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'default' => '',
			]
		);

		$this->add_control(
			'view',
			[
				'label' => __('View', 'quiety-core'),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);

		$this->end_controls_section();

		// Style Section
		//======================

		$this->start_controls_section(
			'section_style',
			[
				'label' => __('Button', 'quiety-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typography',
				'label' => __('Typography', 'quiety-core'),
				'selector' => '{{WRAPPER}} .tt-btn',
				'selector' => '{{WRAPPER}} .btn-38-style .morder_btn__',
			]
		);

		$this->add_control(
			'border_radius',
			[
				'label' => __('Border Radius', 'quiety-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%'],
				'selectors' => [
					'{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn, {{WRAPPER}} .btn-38-style .morder_btn__' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->add_control(
			'btn_padding',
			[
				'label' => __('Padding', 'quiety-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn, {{WRAPPER}} .btn-38-style .morder_btn__' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->start_controls_tabs('tabs_button_style');

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => __('Normal', 'quiety-core'),
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label' => __('Color', 'quiety-core'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'background_color',
			[
				'label' => __('Background Color', 'quiety-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'label' => __('Border', 'quiety-core'),
				'selector' => '{{WRAPPER}} .tt-btn',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow',
				'label' => __('Box Shadow', 'quiety-core'),
				'selector' => '{{WRAPPER}} .tt-btn',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __('Hover', 'quiety-core'),
			]
		);

		$this->add_control(
			'hover_color',
			[
				'label' => __('Color', 'quiety-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'background_color_hover',
			[
				'label' => __('Background Color', 'quiety-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border_hover',
				'label' => __('Border', 'quiety-core'),
				'selector' => '{{WRAPPER}} .tt-btn:hover'
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow_hover',
				'label' => __('Box Shadow', 'quiety-core'),
				'selector' => '{{WRAPPER}} .tt-btn:hover',
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}

	/**
	 * Render button widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		extract($settings);
		$button_type = $settings['button_size'];

		$this->add_render_attribute('wrapper', 'class', 'tt-btn-wrapper');

		if (!empty($settings['link']['url'])) {
			$this->add_render_attribute('button', 'href', $settings['link']['url']);
			$this->add_render_attribute('button', 'class', 'tt-btn-link');

			if ($settings['link']['is_external']) {
				$this->add_render_attribute('button', 'target', '_blank');
			}

			if ($settings['link']['nofollow']) {
				$this->add_render_attribute('button', 'rel', 'nofollow');
			}
		}

		$this->add_render_attribute('button', 'class', 'tt-btn');


		if (!empty($settings['btn_style'] == '1')) {
			if (!empty($settings['button_shape'])) {
				$this->add_render_attribute('button', 'class', $settings['button_shape']);
			}
		}

		if (!empty($settings['button_size'])) {
			$this->add_render_attribute('button', 'class', $settings['button_size']);
		}

		if (!empty($settings['btn_style'] == '1')) {
			if (!empty($settings['button_style'])) {
				$this->add_render_attribute('button', 'class', $settings['button_style']);
			}
		}

		if (!empty($settings['btn_style'] == '1')) {
			if (!empty($settings['is_hover_translate'])) {
				$this->add_render_attribute('button', 'class', 'hover_translate');
			}
		}

		if (!empty($settings['btn_style'] == '2')) {
			$this->add_render_attribute('button', 'class', 'popup-youtube watch-now-btn');
		} 
		
		if( $btn_style == '3' ){
			$this->remove_render_attribute('button', 'class', 'tt-btn');
			$this->add_render_attribute('button', 'class', 'btn-38-style');
		}
		?>

		<!--Render HTML-->
		<div <?php echo $this->get_render_attribute_string('wrapper'); ?>>
			<a <?php echo $this->get_render_attribute_string('button'); ?>>
				<?php
				if( $btn_style != 3 ){ 
					$this->render_text(); 
				}
				else{
					$this->render_text_layout_3();
				}
				?>
			</a>			
		</div>
		<?php

	}

	/**
	 * Render button widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function content_template()
	{ ?>
		<#
			view.addRenderAttribute( 'text' , 'class' , 'btn-text' );
			view.addInlineEditingAttributes( 'text' , 'none' );

			var iconHTML=elementor.helpers.renderIcon( view, settings.selected_icon, { 'aria-hidden' : true }, 'i' , 'object' );
		#>
		<div class="tt-btn-wrapper">
			<a class="tt-btn {{ settings.button_shape }} {{ settings.button_size }} {{ settings.button_style }} elementor-animation-{{ settings.hover_animation }}" href="{{ settings.link.url }}">
				<span class="tt-btn-content-wrapper">
					<span class="tt-btn-icon elementor-align-icon-{{ settings.icon_align }}">
						{{{ iconHTML.value }}}
					</span>
					<span {{{ view.getRenderAttributeString( 'text' ) }}}>{{{ settings.text }}}</span>
				</span>
			</a>
		</div>
		<?php
	}

	/**
	 * Render button text.
	 *
	 * Render button widget text.
	 *
	 * @since 1.5.0
	 * @access protected
	 */
	protected function render_text()
	{
		$settings = $this->get_settings();
		$this->add_render_attribute('content-wrapper', 'class', 'tt-btn-content-wrapper');
		$this->add_render_attribute('icon-align', 'class', 'elementor-align-icon-' . $settings['icon_align']);
		$this->add_render_attribute('icon-align', 'class', 'tt-btn-icon');

		$this->add_render_attribute('text', 'class', 'tt-btn-text'); ?>

		<span <?php echo $this->get_render_attribute_string('content-wrapper'); ?>>
			<?php if (!empty($settings['selected_icon'])) : ?>
				<span <?php echo $this->get_render_attribute_string('icon-align'); ?>>
					<?php if (! empty($settings['selected_icon'])) : ?>
						<?php \Elementor\Icons_Manager::render_icon($settings['selected_icon'], ['aria-hidden' => 'true']); ?>
					<?php endif; ?>
				</span>
			<?php endif; ?>
			<span <?php echo $this->get_render_attribute_string('text'); ?>><?php echo $settings['text']; ?></span>
		</span>	
		<?php
	}

	protected function render_text_layout_3(){ 
		$settings = $this->get_settings(); ?>
		<span class="morder_btn__ home-38-bg-brand fw-medium"><?php echo esc_html($settings['text']) ?></span>
		<span class="hover-style home-38-bg-brand">
			<span class="arrow-style">
				<svg width="16" height="16" viewBox="0 0 16 16" fill="none" xmlns="http://www.w3.org/2000/svg">
					<path d="M1.21766 15.0584C1.21766 15.0584 7.75258 8.52338 15.2261 1.04991M15.2261 1.04991C9.82726 6.44871 3.31475 1.92927 3.31475 1.92927M15.2261 1.04991C9.82726 6.44871 14.3467 12.9612 14.3467 12.9612" stroke="#010101" stroke-width="1.42857" />
				</svg>
			</span>
			<span class="arrow-style">
				<svg width="16" height="16" viewBox="0 0 16 16" fill="none" xmlns="http://www.w3.org/2000/svg">
					<path d="M1.21766 15.0584C1.21766 15.0584 7.75258 8.52338 15.2261 1.04991M15.2261 1.04991C9.82726 6.44871 3.31475 1.92927 3.31475 1.92927M15.2261 1.04991C9.82726 6.44871 14.3467 12.9612 14.3467 12.9612" stroke="#010101" stroke-width="1.42857" />
				</svg>
			</span>
		</span>
		<?php
	}
	
}
