<?php

namespace Quiety\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Widget_Base;

if (!defined('ABSPATH')) {
	exit;
} // Exit if accessed directly

class quiety_goal_stages extends Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name()
	{
		return 'quiety_goal_stages';
	}


	public function get_title()
	{
		return __('Goal Stages', 'quiety-core');
	}

	public function get_icon()
	{

		return 'eicon-bullet-list';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories()
	{
		return ['tt-elements'];
	}

	protected function register_controls()
	{

		$this->start_controls_section(
			'goal_stages',
			[
				'label' => esc_html__('Goal Stages', 'quiety-core'),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'image',
			[
				'label' => esc_html__('Choose Image', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::MEDIA,
			]
		);
		$repeater->add_control(
			'title',
			[
				'label' => esc_html__('Title', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__('Default title', 'quiety-core'),
				'placeholder' => esc_html__('Type your title here', 'quiety-core'),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'content',
			[
				'label' => esc_html__('Content', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'rows' => 10,
				'default' => esc_html__('Default description', 'quiety-core'),
				'placeholder' => esc_html__('Type your description here', 'quiety-core'),
			]
		);

		$this->add_control(
			'goal_list',
			[
				'label' => esc_html__('Goal Stage Repeater', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'title' => esc_html__('Advanced analytics', 'quiety-core'),
					],
				],
				'title_field' => '{{{ title }}}',
			]
		);

		$this->end_controls_section();


		//===================== Slider Control ======================//
		$this->start_controls_section('sec_slider_control', [
			'label' => esc_html__('Slider Control', 'quiety-core')
		]);

		$this->add_control('loop', [
			'label'        => esc_html__('Loop', 'quiety-core'),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__('On', 'quiety-core'),
			'label_off'    => esc_html__('Off', 'quiety-core'),
			'return_value' => 'yes',
			'default'      => 'yes'
		]);

		$this->add_control('speed', [
			'label'   => __('Speed', 'quiety-core'),
			'type'    => Controls_Manager::NUMBER,
			'default' => 700,
		]);

		$this->add_control('autoplay', [
			'label'        => esc_html__('Autoplay', 'quiety-core'),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__('On', 'quiety-core'),
			'label_off'    => esc_html__('Off', 'quiety-core'),
			'return_value' => 'yes',
			'default'      => 'yes'
		]);

		$this->add_control('autoplay_time', [
			'label'   => __('Autoplay Time', 'quiety-core'),
			'type'    => Controls_Manager::NUMBER,
			'default' => 3000,
			'condition' => [
				'autoplay' => 'yes'
			]
		]);

		$this->add_control(
			'show_items_desktop',
			[
				'label'     => esc_html__('Display Items [Desktop]', 'quiety-core'),
				'type'      => Controls_Manager::NUMBER,

			]
		);
		$this->add_control(
			'show_items_tablet',
			[
				'label'     => esc_html__('Display Items [Tablet]', 'quiety-core'),
				'type'      => Controls_Manager::NUMBER,

			]
		);
		$this->add_control(
			'show_items_mobile',
			[
				'label'     => esc_html__('Display Items [Mobile]', 'quiety-core'),
				'type'      => Controls_Manager::NUMBER,
				'default'	=> 1
			]
		);
		$this->add_control(
			'item_space',
			[
				'label' => __('Item Space', 'quiety-core'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
						'step' => 1,
					]
				],
				'default' => [
					'size' => 24,
				]
			]
		);

		$this->end_controls_section();
	}

	protected function render()
	{
		$settings = $this->get_settings_for_display();
		extract($settings); ?>

		<div class="ca-goal-section">
			<div class="col-12">
				<div class="overflow-hidden swiper ca-goal-slider"
					<?php 
					echo quiety_swiper_attrebutes( 
						$show_items_desktop, 
						$loop, 
						$autoplay, 
						$autoplay_time, 
						$speed, 
						$item_space['size'], 
						$show_items_tablet, 
						$show_items_mobile,
						'bullets',
						'.ca-goal-slider__pagination'						
					) ?> >
					<div class="swiper-wrapper">

						<?php
						if (!empty($goal_list)) {
							foreach ($goal_list as $value) { ?>
								<div class="swiper-slide">
									<div class="padding-x-3">
										<div class="ca-goal-card bgc-white rounded-4 padding-5 padding-md-10 text-center">

											<div class="d-grid place-content-center width-21 height-21 rounded-circle mx-auto margin-bottom-6 bgc-base">
												<img src="<?php echo esc_attr($value['image']['url']) ?>" alt="image" class="img-fluid">
											</div>

											<?php
											if (!empty($value['title'])) {
												echo '<h6 class="heading-6 clr-text margin-bottom-3 lh-1 font-weight-bold">' . esc_html($value['title']) . '</h6>';
											}
											?>

											<?php
											if (!empty($value['content'])) {
												echo '<p class="clr-paragraph mb-0">' . esc_html($value['content']) . '</p>';
											}
											?>

											<span class="ca-goal-card__extension ca-goal-card__extension-start"></span>
											<span class="ca-goal-card__extension ca-goal-card__extension-end"></span>
										</div>
									</div>
								</div>
							<?php
							}
						}
						?>
					</div>
				</div>
				<div class="position-relative margin-top-8">
					<div class="swiper-pagination ca-goal-slider__pagination w-100"></div>
				</div>
			</div>
		</div>

	<?php
	}
}
