<?php
namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

use Elementor\{Controls_Manager,
    Group_Control_Text_Shadow,
    Widget_Base,
    Group_Control_Typography,
    Utils};


class quiety_heading extends Widget_Base {

    public function get_name() {
        return 'quiety_heading';
    }

    public function get_title() {
        return esc_html__( 'Quiety Heading', 'quiety-core' );
    }

    public function get_icon() {
        return 'eicon-t-letter';
    }

    public function get_categories() {
        return [ 'tt-elements' ];
    }

    /**
     * Name: register_controls
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: themetags
     */
    protected function register_controls() {
        $this-> elementor_content_control();
        $this-> elementor_style_control();
    }

    /**
     * Name: elementor_content_control
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: themetags
     */
    public function elementor_content_control() {

        $this->start_controls_section(
            'section_title', [
                'label' => __( 'Title', 'quiety-core' ),
            ]
        );

        // Heading Style
        $this->add_control(
            'layout', [
                'label' => __( 'Heading Layout', 'quiety-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => __( 'Default', 'quiety-core' ),
                    '2' => __( 'Title with Icon', 'quiety-core' ),
                    '3' => __('Title with Shape', 'quiety-core'),
                ],
                'default' => '1',
                'separator' => 'after'
            ]
        );

        $this->add_control(
            'title', [
                'label' => __( 'Title', 'quiety-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'description' => __( 'Highlighted text must be write in { }. Example : Welcome to { Our Website }', 'quiety-core'),
                'dynamic' => [
                    'active' => true,
                ],
                'placeholder' => __( 'Enter your title', 'quiety-core' ),
                'default' => __( 'Add Your Heading Text Here', 'quiety-core' ),
            ]
        );

        $this->add_control(
            'link', [
                'label' => __( 'Link', 'quiety-core' ),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'default' => [
                    'url' => '',
                ],
                'separator' => 'before',
                'condition' => [
                    'layout' => '1', 
                    'layout' => '2', 
                ]
            ]
        );

        $this->add_control(
            'size', [
                'label' => __( 'Size', 'quiety-core' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'default',
                'options' => [
                    'default' => __( 'Default', 'quiety-core' ),
                    'small' => __( 'Small', 'quiety-core' ),
                    'medium' => __( 'Medium', 'quiety-core' ),
                    'large' => __( 'Large', 'quiety-core' ),
                    'xl' => __( 'XL', 'quiety-core' ),
                    'xxl' => __( 'XXL', 'quiety-core' ),
                ],
                'condition' => [
                    'layout' => '1'
                ]
            ]
        );

        $this->add_control(
			'shape_image',
			[
				'label' => esc_html__( 'Shape Image', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'layout' => '3'
                ]
			]
		);

        $this->add_control(
            'header_size', [
                'label' => __( 'HTML Tag', 'quiety-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                    'div' => 'div',
                    'span' => 'span',
                    'p' => 'p',
                ],
                'default' => 'h2',
                'condition' => [
                    'layout' => '1'
                ]
            ]
        );

        $this->add_responsive_control(
            'align', [
                'label' => __( 'Alignment', 'quiety-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __( 'Left', 'quiety-core' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'quiety-core' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => __( 'Right', 'quiety-core' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                    'justify' => [
                        'title' => __( 'Justified', 'quiety-core' ),
                        'icon' => 'eicon-text-align-justify',
                    ],
                ],
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}} .hd-hero-title' => 'text-align: {{VALUE}}'
                ],
            ]
        );

        $this->add_control(
            'view', [
                'label' => __( 'View', 'quiety-core' ),
                'type' => Controls_Manager::HIDDEN,
                'default' => 'traditional',
            ]
        );

        $this->add_control(
            'title_icon', [
                'label' => esc_html__( 'Icon', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => '',
                    'library' => '',
                ],
                'condition' => [
                    'layout' => '2'
                ],
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'title_icon_position', [
                'label' => esc_html__( 'Icon Position', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'icon_after',
                'options' => [
                    'icon_before'  => esc_html__( 'Before', 'quiety-core' ),
                    'icon_after' => esc_html__( 'After', 'quiety-core' ),
                ],
            ]
        );

        $this->end_controls_section(); //End Title

    }


    /**
     * Name: elementor_style_control
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: themetags
     */
    public function elementor_style_control () {

        // ========================== Title Style =========================== //
        $this->start_controls_section(
            'section_title_style', [
                'label' => __( 'Title', 'quiety-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color', [
                'label' => __( 'Text Color', 'quiety-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-heading-title' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .highlighted-icon span' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .hd-hero-title' => 'color: {{VALUE}};'
                ],
            ]
        );

        $this->add_control(
            'title_hover_color', [
                'label' => __( 'Text Hover Color', 'quiety-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-heading-title:hover' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .highlighted-icon:hover span' => 'color: {{VALUE}};',
                ],
                'separator' => 'after'
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name' => 'typography',
                'selector' => '{{WRAPPER}} .elementor-heading-title, {{WRAPPER}} .highlighted-icon span, {{WRAPPER}} .hd-hero-title',
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(), [
                'name' => 'text_shadow',
                'selector' => '{{WRAPPER}} .elementor-heading-title, {{WRAPPER}} .highlighted-icon span',
            ]
        );

        $this->add_control(
            'blend_mode', [
                'label' => __( 'Blend Mode', 'quiety-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '' => __( 'Normal', 'quiety-core' ),
                    'multiply' => 'Multiply',
                    'screen' => 'Screen',
                    'overlay' => 'Overlay',
                    'darken' => 'Darken',
                    'lighten' => 'Lighten',
                    'color-dodge' => 'Color Dodge',
                    'saturation' => 'Saturation',
                    'color' => 'Color',
                    'difference' => 'Difference',
                    'exclusion' => 'Exclusion',
                    'hue' => 'Hue',
                    'luminosity' => 'Luminosity',
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-heading-title' => 'mix-blend-mode: {{VALUE}}',
                    '{{WRAPPER}} .highlighted-text' => 'mix-blend-mode: {{VALUE}}',
                ],
                'separator' => 'none',
                'condition' => [
                    'layout' => '1'
                ]
            ]
        );

        $this->end_controls_section(); // End Title Style


        //================================ Title Highlighted Colors ============================//
        $this->start_controls_section(
            'section_highlighted_style', [
                'label' => __( 'Highlighted', 'quiety-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => '1',
                    'layout' => '3',
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name' => 'highlighted_typo',
                'selector' => '{{WRAPPER}} .elementor-heading-title span',
            ]
        );
        $this->add_control(
            'highlighted_color', [
                'label' => __( 'Text Color', 'quiety-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-heading-title span' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .highlighted_text' => 'color: {{VALUE}}'
                ],
            ]
        );
        $this->add_control(
			'heading_text_grident',
			[
				'label' => esc_html__( 'Enable Gradient Color', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'quiety-core' ),
				'label_off' => esc_html__( 'Hide', 'quiety-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'highlighted_text_background',
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .highlighted_text',
                'condition' => [
                    'heading_text_grident' => 'yes',
                ]
			]
		);

        

        $this->end_controls_section(); //End Title Highlighted Colors


        //================================ Icon Colors ============================//
        $this->start_controls_section(
            'style_icon_color', [
                'label' => __( 'Icon', 'quiety-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => '2'
                ]
            ]
        );

        $this->add_control(
            'icon_color', [
                'label' => esc_html__( 'Color', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .highlighted-icon svg path' => 'stroke: {{VALUE}}; fill: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'icon_hover_color', [
                'label' => esc_html__( 'Hover Color', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .highlighted-icon:hover svg path' => 'stroke: {{VALUE}}; fill: {{VALUE}}',
                ],
                'separator' => 'after'
            ]
        );

        $this->add_responsive_control(
            'icon_img_width', [
                'label' => esc_html__( 'Width', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .highlighted-icon svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->end_controls_section(); //End Title Icon Colors

    }


    /**
     * Name: render
     * Desc: Widgets Render
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        extract($settings);




        if ( '' === $settings['title'] ) {
            return;
        }

        $this->add_render_attribute( 'title', 'class', 'elementor-heading-title' );

        if ( ! empty( $settings['size'] ) ) {
            $this->add_render_attribute( 'title', 'class', 'elementor-size-' . $settings['size'] );
        }

        $this->add_inline_editing_attributes( 'title' );

        $title = !empty($settings['title']) ? $settings['title'] : '';

        if ( ! empty( $settings['link']['url'] ) ) {
            $this->add_link_attributes( 'url', $settings['link'] );
            $title = sprintf( '<a %1$s>%2$s</a>', $this->get_render_attribute_string( 'url' ), $title );
        }

        $text_gradient = $heading_text_grident == 'yes' ? 'quiety_gradient_text' : '';
        if ( $settings['layout'] == '1' ) {
            $title_html = sprintf( '<%1$s %2$s>%3$s</%1$s>', Utils::validate_html_tag( $settings['header_size'] ), $this->get_render_attribute_string( 'title' ), $title );
            echo Quiety_Core_Helper()->kses_post(str_replace(['{', '}'], ['<span class="highlighted_text '.esc_attr($text_gradient).'">', '</span>'], $title_html));
        }
        if ( $settings['layout'] == '2' ) {
            ?>
            <a <?php Quiety_Core_Helper()->the_button($settings['link']) ?> class="highlighted-icon">
                <?php if ( !empty($settings['title_icon_position'] === 'icon_before' ) ) : ?>
                    <span class="ms-1">
                        <?php \Elementor\Icons_Manager::render_icon( $settings['title_icon'] ); ?>
                    </span>
                <?php endif; ?>
                <span><?php echo Quiety_Core_Helper()->kses_post($settings['title']) ?></span>
                <?php if ( !empty($settings['title_icon_position'] === 'icon_after' ) ) : ?>
                    <span class="ms-1">
                        <?php \Elementor\Icons_Manager::render_icon( $settings['title_icon'] ); ?>
                    </span>
                <?php endif; ?>
            </a>
            <?php
        }

        if ( $settings['layout'] == '3' ) { 

		    $image_src = !empty( $settings['shape_image']['url'] ) ? '<img src='. esc_url($settings['shape_image']['url'] ).' class="position-absolute hd-line-shape">' : ''; ?>

            <h1 class="hd-hero-title">
			    <?php echo str_replace(array('{', '}'), array('<mark class="highlighted_text '.esc_attr($text_gradient).'">'. $image_src, "</mark>"), $settings['title']); ?>
		    </h1>

        <?php }
    }

}