<?php

namespace Quiety\Widgets;

if (!defined('ABSPATH')) {
	exit;
}

use Elementor\{
	Controls_Manager,
	Widget_Base,
	Group_Control_Typography,
	Repeater,
	Utils
};

class Quiety_Image_Box extends Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * @since 1.0.0
	 */
	public function get_name()
	{
		return 'quiety_image_box';
	}

	/**
	 * Get widget title.
	 *
	 * @since 1.0.0
	 */
	public function get_title()
	{
		return __('Quiety Image Box', 'quiety-core');
	}

	/**
	 * Get widget icon.
	 *
	 * @since 1.0.0
	 */
	public function get_icon()
	{
		return 'eicon-image-box';
	}

	/**
	 * Get widget categories.
	 *
	 * @since 1.0.0
	 */
	public function get_categories()
	{
		return ['tt-elements'];
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 1.0.0
	 */
	public function get_keywords()
	{
		return ['Image Box', 'quiety'];
	}

	/**
	 * Register widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls()
	{

		//============================================
		// START TEAME CONTENT
		//============================================
		$this->start_controls_section('image_box_content', [
			'label' => __('Image Box', 'quiety-core'),
			'tab'   => Controls_Manager::TAB_CONTENT,
		]);

		$this->add_control('layout', [
			'label'   => __('Layout', 'quiety-core'),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => 'layout-1',
			'options' => [
				'layout-1'     => __('Layout One', 'quiety-core'),
				'layout-2'     => __('Layout Two', 'quiety-core'),
			],
		]);

		//content start ---------------------
		$this->add_control(
			'serial_number',
			[
				'label' => esc_html__('Serial Number', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__('01', 'quiety-core'),
				'placeholder' => esc_html__('01', 'quiety-core'),
			]
		);
		$this->add_control(
			'box_title',
			[
				'label' => esc_html__('Title', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__('Expertise and Innovation Business', 'quiety-core'),
				'placeholder' => esc_html__('Type your title here', 'quiety-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'box_subtitle',
			[
				'label' => esc_html__('Subtitle', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__('A creative agency brings a wealth of expertise and innovative', 'quiety-core'),
				'placeholder' => esc_html__('Type your title here', 'quiety-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'btn_title',
			[
				'label' => esc_html__( 'Button Title', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Default title', 'quiety-core' ),
				'placeholder' => esc_html__( 'Type your title here', 'quiety-core' ),
				'label_block' => true,
				'condition' => [
					'layout' => 'layout-2',
				]
			]
		);
		$this->add_control(
			'btn_link',
			[
				'label' => esc_html__( 'Button Link', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'options' => [ 'url', 'is_external', 'nofollow' ],
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
					// 'custom_attributes' => '',
				],
				'label_block' => true,
				'condition' => [
					'layout' => 'layout-2',
				]
			]
		);
		$this->add_control(
			'imgbox_image',
			[
				'label' => esc_html__('Box Image', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'layout' => 'layout-1',
				]
			]
		);
		$this->end_controls_section();

		//Styel added Start-----------------------------
		$this->start_controls_section(
			'imgbox_style',
			[
				'label' => esc_html__('Imgbox Style', 'quiety-core'),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'imgbox_title_color',
			[
				'label' => esc_html__('Title Color', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .step-card-36 .title_style__, {{WRAPPER}} .title_style__' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'imgbox_title_typography',
				'selector' => '{{WRAPPER}} .step-card-36 .title_style__, {{WRAPPER}} .title_style__',
			]
		);
		$this->add_control(
			'imgbox_subtitle_color',
			[
				'label' => esc_html__('Subtitle Color', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .step-card-36 .subtitle_style__, {{WRAPPER}} .subtitle_style__' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'imgbox_subtitle_typography',
				'selector' => '{{WRAPPER}} .step-card-36 .subtitle_style__, {{WRAPPER}} .subtitle_style__',
			]
		);
		$this->end_controls_section();
		//Styel added End-----------------------------
	}


	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$layout = $settings['layout'];
		extract($settings);

		require __DIR__ . '/templates/image-box/' . $layout . '.php';
	}
}
