<?php
namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

use Elementor\{Controls_Manager,
    Group_Control_Background,
    Group_Control_Box_Shadow,
    Widget_Base,
    Group_Control_Typography,
    Repeater,
    Utils};

class quiety_image_carousel extends Widget_Base {

    public function get_name() {
        return 'quiety_image_carousel';
    }

    public function get_title() {
        return esc_html__( 'Quiety Image Carousel', 'quiety-core' );
    }

    public function get_icon() {
        return 'eicon-media-carousel';
    }

    public function get_categories() {
        return [ 'quiety-elements' ];
    }

    /**
     * Name: register_controls
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function register_controls() {
        $this-> elementor_content_control();
        $this-> elementor_style_control();
    }


    /**
     * Name: quiety_elementor_content_control
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function elementor_content_control() {


        //==================== Select Layout ==========================//
        $this->start_controls_section(
            'select_layout', [
                'label' => __( 'Layout', 'quiety-core' ),
            ]
        );

        $this->add_control(
            'layout', [
                'label'   => esc_html__( 'Layout', 'quiety-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__( '01: Carousel Slider', 'quiety-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section(); //End Layout


        //==================== Image Carousel ==========================//
        $this->start_controls_section(
            'sec_image_carousel', [
                'label' => __( 'Gallery Image', 'quiety-core' ),
            ]
        );

        $carousel_gallery = new \Elementor\Repeater();
        $carousel_gallery->add_control(
            'align_items', [
                'type'    => Controls_Manager::HIDDEN,
            ]
        );

        $carousel_gallery->add_control(
            'image', [
                'label'   => esc_html__( 'Image', 'quiety-core' ),
                'type'    => Controls_Manager::MEDIA,
            ]
        );

        $carousel_gallery->add_control(
            'btn_label', [
                'label'   => esc_html__( 'Button Label', 'quiety-core' ),
                'type'    => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'View Details',
            ]
        );

        $carousel_gallery->add_control(
            'btn_url', [
                'label'   => esc_html__( 'Button URL', 'quiety-core' ),
                'type'    => Controls_Manager::URL,
                'default' => [
                    'url' => '#'
                ],
            ]
        );

        $this->add_control(
            'image_carousel', [
                'label'   => esc_html__( 'Add Image', 'quiety-core' ),
                'type'    => Controls_Manager::REPEATER,
                'fields'  => $carousel_gallery->get_controls(),
                'title_field' => '{{{ align_items }}}',
                'prevent_empty' => false
            ]
        );

        $this->end_controls_section(); //End Client Logos

    }


    /**
     * Name: quiety_elementor_style_control
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function elementor_style_control() {


        //=============================== Slider Control Section =========================//
        $this->start_controls_section(
            'slider_control_sec', [
                'label' => esc_html__( 'Slider Control', 'quiety-core' )
            ]
        );
        $this->add_control( 'navigation', [
            'label'        => esc_html__( 'Navigation', 'quiety-core' ),
            'type'         => Controls_Manager::SWITCHER,
            'label_on'     => esc_html__( 'Show', 'quiety-core' ),
            'label_off'    => esc_html__( 'Hide', 'quiety-core' ),
            'return_value' => 'yes',
            'default'      => 'yes'
        ] );


        $this->add_control( 'loop', [
            'label'        => esc_html__( 'Loop', 'quiety-core' ),
            'type'         => Controls_Manager::SWITCHER,
            'label_on'     => esc_html__( 'On', 'quiety-core' ),
            'label_off'    => esc_html__( 'Off', 'quiety-core' ),
            'return_value' => 'yes',
            'default'      => 'yes'
        ] );

        $this->add_control( 'speed', [
            'label'   => __( 'Speed', 'quiety-core' ),
            'type'    => Controls_Manager::NUMBER,
            'default' => 700,
        ] );

        $this->add_control( 'autoplay', [
            'label'        => esc_html__( 'Autoplay', 'quiety-core' ),
            'type'         => Controls_Manager::SWITCHER,
            'label_on'     => esc_html__( 'On', 'quiety-core' ),
            'label_off'    => esc_html__( 'Off', 'quiety-core' ),
            'return_value' => 'yes',
            'default'      => 'yes'
        ] );

        $this->add_control( 'autoplay_time', [
            'label'   => __( 'Autoplay Time', 'quiety-core' ),
            'type'    => Controls_Manager::NUMBER,
            'default' => 3000,
            'condition' => [
                'autoplay' => 'yes'
            ]
        ] );

        $this->add_control(
            'slide_per_view_desktop', [
                'label'     => esc_html__( 'Display Items [Desktop]', 'quiety-core' ),
                'type'      => Controls_Manager::NUMBER,

            ]
        );
        $this->add_control(
            'show_items_tablet', [
                'label'     => esc_html__( 'Display Items [Tablet]', 'quiety-core' ),
                'type'      => Controls_Manager::NUMBER,

            ]
        );
        $this->add_control(
            'show_items_mobile', [
                'label'     => esc_html__( 'Display Items [Mobile]', 'quiety-core' ),
                'type'      => Controls_Manager::NUMBER,
                'default'	=> 1
            ]
        );
        $this->add_control(
            'space_between', [
                'label' => __( 'Item Space', 'quiety-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ]
                ],
                'default' => [
                    'size' => 24,
                ]
            ]
        );
        

        $this->end_controls_section(); //End Slider Control Section

    }


    /**
     * Name: render
     * Desc: Widgets Render
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function render() {
        $settings     = $this->get_settings_for_display();
        extract( $settings );

        //=============== Template Parts ================//
        require __DIR__ . '/templates/image-carousel/layout-'.$layout.'.php';

    }

}