<?php

namespace Quiety\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\{Group_Control_Image_Size,
	Utils,
	Widget_Base,
	Controls_Manager

};

class Quiety_Job extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-job-box';
	}

	public function get_title() {
		return __( 'Quiety Job', 'quiety-core' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-photo-library';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {

		//select option start ------------------------------------------------
		$this->start_controls_section(
			'style_section',
			[
				'label' => esc_html__( 'Job Style', 'quiety-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'layout',
			[
				'label' => esc_html__( 'Select Style', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1' => esc_html__( 'Style 01', 'quiety-core' ),
					'2' => esc_html__( 'Style 02', 'quiety-core' ),
					'3' => esc_html__( 'Style 03', 'quiety-core' ),
				]
			]
		);
		$this->end_controls_section();

		//select option close -----------------------------------------

		$this->start_controls_section( 'section_query', [
			'label' => __( 'Job', 'quiety-core' ),
		] );

		$this->add_control( 'thumbnail_default_size', [
			'label'        => esc_html__( 'Use Default Thumbnail Size', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'default'      => '1',
			'return_value' => '1',
			'separator'    => 'before',
		] );

		$this->add_group_control( Group_Control_Image_Size::get_type(), [
			'name'      => 'thumbnail',
			'default'   => 'full',
			'condition' => [
				'thumbnail_default_size!' => '1',
			],
		] );


		$this->add_control( 'ids', [
			'label'       => __( 'Enter Work IDs', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => '',
			'label_block' => true,
			'description' => __( "Enter Work ids to show, separated by a comma. Leave empty to show all.", 'quiety-core' )

		] );
		$this->add_control( 'ids_not', [
			'label'       => __( 'Or Work IDs to Exclude', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => '',
			'label_block' => true,
			'description' => __( "Enter Work ids to exclude, separated by a comma (,). Use if the field above is empty.", 'quiety-core' )

		] );

		$this->add_control( 'order_by', [
			'label'       => __( 'Order by', 'quiety-core' ),
			'type'        => Controls_Manager::SELECT,
			'options'     => [
				'date'          => esc_html__( 'Date', 'quiety-core' ),
				'ID'            => esc_html__( 'ID', 'quiety-core' ),
				'author'        => esc_html__( 'Author', 'quiety-core' ),
				'title'         => esc_html__( 'Title', 'quiety-core' ),
				'modified'      => esc_html__( 'Modified', 'quiety-core' ),
				'rand'          => esc_html__( 'Random', 'quiety-core' ),
				'comment_count' => esc_html__( 'Comment Count', 'quiety-core' ),
				'menu_order'    => esc_html__( 'Menu Order', 'quiety-core' ),
			],
			'default'     => 'date',
			'separator'   => 'before',
			'description' => esc_html__( "Select how to sort retrieved posts. More at ", 'quiety-core' ) . '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex</a>.',
		] );

		$this->add_control( 'order', [
			'label'       => __( 'Sort Order', 'quiety-core' ),
			'type'        => Controls_Manager::SELECT,
			'options'     => [
				'ASC'  => esc_html__( 'Ascending', 'quiety-core' ),
				'DESC' => esc_html__( 'Descending', 'quiety-core' ),
			],
			'default'     => 'DESC',
			'separator'   => 'before',
			'description' => esc_html__( "Select Ascending or Descending order. More at", 'quiety-core' ) . '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex</a>.',
		] );

		$this->add_control( 'posts_per_page', [
			'label'       => __( 'Work to show', 'quiety-core' ),
			'type'        => Controls_Manager::NUMBER,
			'default'     => '4',
			'description' => esc_html__( "Number of work to show (-1 for all).", 'quiety-core' ),
			'min'         => 1,
		] );

		$this->end_controls_section();
	}

	protected function render() {

		$settings = $this->get_settings();
		extract($settings);

		$this->add_render_attribute( 'wrapper', 'class', [
			'tt-job-post-wrapper'
		] );

		$args  = array(
			'hide_empty' => true,
			'taxonomy'   => 'quiety_job_cat',
		);
		$terms = get_terms( $args );
		include __DIR__ . '/templates/job/layout-'.$layout.'.php';
		?>

		
		<!-- /.tt-job-post-wrapper -->

	<?php }

}
