<?php

namespace Quiety\Widgets;

if (!defined('ABSPATH')) exit;

use Elementor\{
	Controls_Manager,
	Group_Control_Box_Shadow,
	Group_Control_Typography,
	Repeater,
	Widget_Base,
	Utils
};


class Quiety_Logo_Carousel extends Widget_Base
{

	public function get_name()
	{
		return 'tt-logo-carousel';
	}

	public function get_title()
	{
		return esc_html__('Quiety Logo Carousel', 'quiety-core');
	}

	public function get_icon()
	{
		return 'eicon-carousel';
	}

	public function get_categories()
	{
		return ['tt-elements'];
	}

	protected function register_controls()
	{

		$this->start_controls_section(
			'layout_section',
			[
				'label' => esc_html__('Layout Section', 'quiety-core'),
			]
		);

		$this->add_control('layout', [
			'type'    => Controls_Manager::SELECT,
			'label'   => __('Layout', 'quiety-core'),
			'default' => 'style-one',
			'options' => [
				'style-one' => __('Style One', 'quiety-core'),
				'style-two' => __('Style Two', 'quiety-core'),
				'style-three' => __('Style Three', 'quiety-core'),
			],
		]);
		$this->end_controls_section();

		//layout 1 2 repeater start -----------------------------------
		$this->start_controls_section(
			'section_logo',
			[
				'label' => esc_html__('Logo Carousel', 'quiety-core'),
				'condition' => [
					'layout!' => "style-three",
				],
			]
		);
		$repeater = new Repeater();

		$repeater->add_control(
			'image',
			[
				'label' => __('Logo', 'quiety-core'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],

			]
		);

		$repeater->add_control(
			'link',
			[
				'label' => __('Link', 'quiety-core'),
				'type' => Controls_Manager::URL,
				'placeholder' => __('https://your-link.com', 'quiety-core'),
				'show_external' => true,
				'default' => [
					'url' => '#',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);

		$repeater->add_control(
			'name',
			[
				'label' => __('Title', 'quiety-core'),
				'type' => Controls_Manager::TEXT,
				'default' => __('Brand Name', 'quiety-core'),
				'placeholder' => __('Type brand name here', 'quiety-core'),
			]
		);


		$this->add_control(
			'logos',
			[
				'label' => __('Logo List', 'quiety-core'),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'image' => [
							'url' => Utils::get_placeholder_image_src(),
						],
						'name' => __('Brand Name', 'quiety-core')

					],
					[
						'image' =>  [
							'url' => Utils::get_placeholder_image_src(),
							'name' => __('Brand Name', 'quiety-core')
						]
					],
					[
						'image' =>  [
							'url' => Utils::get_placeholder_image_src(),
							'name' => __('Brand Name', 'quiety-core')
						]
					],
					[
						'image' =>  [
							'url' => Utils::get_placeholder_image_src(),
							'name' => __('Brand Name', 'quiety-core')
						]
					],
					[
						'image' =>  [
							'url' => Utils::get_placeholder_image_src(),
							'name' => __('Brand Name', 'quiety-core')
						]
					],
				],
				'title_field' => '{{{ name }}}',
			]
		);

		$this->end_controls_section();
		//layout 1 2  repeater end ------------------------------------------


		// layout 3 repeater start ---------------------------------------------------
		$this->start_controls_section(
			'lay3_section',
			[
				'label' => esc_html__('Content', 'quiety-core'),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => [
					'layout!' => ["style-one", "style-two"],
				],
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'select_option',
			[
				'label' => esc_html__('Slect', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'title',
				'options' => [
					'title' => esc_html__('Title', 'quiety-core'),
					'image' => esc_html__('Image', 'quiety-core'),
				],
			]
		);
		$repeater->add_control(
			'lay3_title',
			[
				'label' => esc_html__('Title', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__('TEMPLATE', 'quiety-core'),
				'label_block' => true,
				'condition' => [
					'select_option' => 'title',
				]
			]
		);
		$repeater->add_control(
			'lay3_image',
			[
				'label' => esc_html__('Choose Image', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'select_option' => 'image',
				]
			]
		);
		$this->add_control(
			'lay3_list',
			[
				'label' => esc_html__('Repeater List', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'lay3_title' => esc_html__('TEMPLATE', 'quiety-core'),
					],
				],
				'title_field' => '{{{ lay3_title }}}',

			]
		);
		$this->end_controls_section();
		//layout 3 repeater end ---------------------------------------------


		// Slider Control
		//=====================
		$this->start_controls_section('settingd_section', [
			'label' => esc_html__('Slider Control', 'quiety-core'),
			'condition' => [
				'layout!' => 'style-three'
			]
		]);

		$this->add_control(
			'perview',
			[
				'label' => __('Desktop Per View', 'quiety-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 5,
			]
		);

		$this->add_control(
			'perview_tablet',
			[
				'label' => __('Tablet Per View', 'quiety-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 3,
			]
		);

		$this->add_control(
			'perview_mobile',
			[
				'label' => __('Mobile Per View', 'quiety-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 2,
			]
		);

		$this->add_control(
			'loop',
			[
				'label' => esc_html__('Loop', 'quiety-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('On', 'quiety-core'),
				'label_off' => esc_html__('Off', 'quiety-core'),
				'return_value' => 'true',
				'default' => 'yes'
			]
		);

		$this->add_control(
			'speed',
			[
				'label' => __('Speed', 'quiety-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 700,
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label' => esc_html__('Autoplay', 'quiety-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('On', 'quiety-core'),
				'label_off' => esc_html__('Off', 'quiety-core'),
				'return_value' => 'true',
				'default' => 'yes'
			]
		);

		$this->add_control(
			'autoplay_time',
			[
				'label' => __('Autoplay Time', 'quiety-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 3000,
			]
		);

		$this->add_control(
			'item_space',
			[
				'label' => __('Item Space', 'quiety-core'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
						'step' => 1,
					]
				],
				'default' => [
					'size' => 24,
				]
			]
		);
		$this->end_controls_section();


		//Slider control start -----------------------------------------------------
		$this->start_controls_section(
			'carousel_speed_section',
			[
				'label' => esc_html__( 'Speed Control', 'quiety-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => [
					'layout!' => ["style-one", "style-two"],
				],
			]
		);
		$this->add_control(
			'carousel_speed_control',
			[
				'label' => esc_html__( 'Speed', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'slow',
				'options' => [
					'fast' => esc_html__( 'Fast', 'quiety-core' ),
					'slow' => esc_html__( 'Slow', 'quiety-core' ),
				],
			]
		);
		$this->add_control(
			'carousel_speed_position_control',
			[
				'label' => esc_html__( 'Position', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'left',
				'options' => [
					'right' => esc_html__( 'Right', 'quiety-core' ),
					'left' => esc_html__( 'Left', 'quiety-core' ),
				],
			]
		);
		$this->end_controls_section();
		//Slider control end -----------------------------------------------------


		//Style section start ------------------------------------
		$this->start_controls_section(
			'style_section',
			[
				'label' => esc_html__( 'Style', 'quiety-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [
					'layout' => 'style-three',
				]
			]
		);
		
		$this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .title_color_style__' => 'color: {{VALUE}}',
				]
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'selector' => '{{WRAPPER}} .title_color_style__',
			]
		);
		$this->end_controls_section();
		
		//Style section end ----------------------------------


	}

	protected function render()
	{

		$settings = $this->get_settings_for_display();
		extract($settings);
		$logos = $settings['logos'];


		if ($layout == 'style-one' || $layout == 'style-two') { ?>
			<div class="tt-logo-carousel">
				<div class="swiper overflow-hidden tt-client-logo"
					<?php
					echo quiety_swiper_attrebutes(
						$perview,
						$loop,
						$autoplay,
						$autoplay_time,
						$speed,
						$item_space['size'],
						$perview_tablet,
						$perview_mobile
					) ?> >
					<div class="swiper-wrapper">
						<?php if (is_array($logos)) :
							foreach ($logos as $logo) : ?>
								<?php if ($logo['image'] != '') {
									$img = $logo['image']['url'];
								} ?>
								<div class="swiper-slide">
									<div class="client-logo text-center" title="<?php echo esc_attr($logo['name']); ?>">
										<?php if (!empty($img)) : ?>
											<?php if (!empty($logo['link']['url'])) : ?>
												<a href="<?php echo esc_url($logo['link']['url']); ?>">
												<?php endif; ?>
												<img src="<?php echo esc_url($img) ?>" alt="<?php echo esc_attr__('Brand logo', 'quiety-core') ?>">
												<?php if (!empty($logo['link']['url'])) : ?>
												</a>
											<?php endif; ?>
										<?php endif; ?>
									</div>
								</div>
								<!-- /.swiper-slide -->
						<?php
							endforeach;
						endif;
						?>
					</div>
					<!-- /.swiper-wrapper -->
				</div>
				<!-- /.swiper-container -->
			</div>
		<?php
		} 
		elseif ($layout == 'style-three') { ?>
			<div class="scroller-x" data-direction="<?php echo esc_attr($settings['carousel_speed_position_control'])?>" data-speed="<?php echo esc_attr($settings['carousel_speed_control']) ?>">
				<ul class="list-unstyled p-0 m-0 d-flex gap-4 scroller-x__list align-items-center">
					<?php
					foreach ($lay3_list as $item) {
						if ($item['select_option'] == 'title' && !empty($item['lay3_title'])) { ?>
							<li>
								<span class="d-inline-block fw-semibold h6 about-title title_color_style__">
									<?php echo esc_html($item['lay3_title']) ?>
								</span>
							</li>
						<?php
						} elseif ($item['select_option'] == 'image' && !empty($item['lay3_image']['id'])) { ?>
							<li>
								<?php echo wp_get_attachment_image($item['lay3_image']['id'], 'full', '', ["class" => "img-fluid"]) ?>
							</li>
					<?php
						}
					}
					?>
				</ul>
			</div>
		<?php
		}
		
	}

}
