<?php
namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

use Elementor\{Controls_Manager,
    Group_Control_Background,
    Group_Control_Box_Shadow,
    Widget_Base,
    Group_Control_Typography,
    Repeater,
    Utils};

class quiety_moving_image extends Widget_Base {

    public function get_name() {
        return 'quiety_moving_image';
    }

    public function get_title() {
        return esc_html__( 'Quiety Moving Image', 'quiety-core' );
    }

    public function get_icon() {
        return 'eicon-logo';
    }

    public function get_categories() {
        return [ 'quiety-elements' ];
    }

    /**
     * Name: register_controls
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function register_controls() {
        $this-> elementor_content_control();
        $this-> elementor_style_control();
    }


    /**
     * Name: quiety_elementor_content_control
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function elementor_content_control() {
        $this->start_controls_section(
			'img_moving_section',
			[
				'label' => esc_html__( 'Moving Image', 'quiety-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'moving_title',
			[
				'label' => esc_html__( 'Title', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Default title', 'quiety-core' ),
				'placeholder' => esc_html__( 'Type your title here', 'quiety-core' ),
                'label_block' => true,
			]
		);
        $this->add_control(
			'arrow_image',
			[
				'label' => esc_html__( 'Arrow Image', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->end_controls_section();

        // style added start ----------------------------------------
        
        $this->start_controls_section(
			'style_section',
			[
				'label' => esc_html__( 'Style', 'quiety-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} span.circle-btn__text span' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'bg_color',
			[
				'label' => esc_html__( 'Background Color', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.circle-btn.mx-auto' => 'background: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'selector' => '{{WRAPPER}} span.circle-btn__text span',
			]
		);
		$this->end_controls_section();
        // style section end ------------------------------------------------

    }


    /**
     * Name: quiety_elementor_style_control
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function elementor_style_control() {


    }


    /**
     * Name: render
     * Desc: Widgets Render
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function render() {
        $settings     = $this->get_settings_for_display();
        extract( $settings );

        //=============== Template Parts ================//
        require __DIR__ . '/templates/moving-image/moving-image.php';

    }

}