<?php

namespace Quiety\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\{Controls_Manager, Group_Control_Background, Group_Control_Box_Shadow, Repeater, Utils, Widget_Base};

class Quiety_Parallax_Image extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-parallax-image';
	}

	public function get_title() {
		return __( 'Quiety Parallax Image', 'quiety-core' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-image';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	public function get_script_depends() {
		return [
			'parallax-scroll'
		];
	}

	protected function register_controls() {

		$this->start_controls_section( 'primary_section_content', [
			'label' => __( 'Primary Image', 'quiety-core' ),
		] );

		$this->add_control(
			'layout',
			[
				'label' => __( 'Layout', 'quiety-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'one',
				'options' => [
					'one'  => __( 'Layout 1', 'quiety-core' ),
					'two' => __( 'Layout 2', 'quiety-core' ),
				],
			]
		);

		$this->add_control( 'image', [
			'label'     => __( 'Choose Image', 'quiety-core' ),
			'type'      => Controls_Manager::MEDIA,
			'default'   => [
				'url' => plugin_dir_url(__DIR__ ) . 'assets/images/widget-5.png',
			],
			'condition' => [ 'layout' => 'one' ]
		] );

		$this->add_control( 'image_main', [
			'label'     => __( 'Choose Image', 'quiety-core' ),
			'type'      => Controls_Manager::MEDIA,
			'default'   => [
				'url' => plugin_dir_url(__DIR__ ) . 'assets/images/app-two.png',
			],
			'condition' => [ 'layout' => 'two' ]
		] );

		$this->add_responsive_control(
			'image_wrapper_padding',
			[
				'label' => __( 'Wrapper Padding', 'quiety-padding' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .parallax-image' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'image_box_shadow',
				'label' => __( 'Box Shadow', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .parallax-image .image-one img',
			]
		);

		$this->add_control(
			'skewed',
			[
				'label' => __( 'Skewed Enable', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'quiety-core' ),
				'label_off' => __( 'Off', 'quiety-core' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [ 'layout' => 'one' ]
			]
		);

		$this->end_controls_section();

		// Secondary Image
		//======================
		$this->start_controls_section( 'parallax_section_content', [
			'label' => __( 'Secondary Image', 'quiety-core' ),
			'condition' => [ 'layout' => 'one' ]
		] );

		$this->add_control( 'image_two', [
			'label'     => __( 'Choose Second Image', 'quiety-core' ),
			'type'      => Controls_Manager::MEDIA,
			'default'   => [
				'url' => plugin_dir_url(__DIR__ ) . 'assets/images/widget-3.png',
			],
 		] );

		$this->add_responsive_control( 'parallax_factor', [
			'label'       => esc_html__( 'Parallax Factor', 'quiety-core' ),
			'type'        => Controls_Manager::NUMBER,
			'min'         => - 300,
			'max'         => 300,
			'step'        => 10,
			'default'     => - 50,
			'description' => esc_html__( 'Set elements offset and speed. It can be positive (100) or negative (-100). Less means slower.', 'quiety-core' ),
			'separator' => 'before'

		] );

		$this->add_responsive_control( 'animation_name', [
			'label'   => esc_html__( 'Animation', 'quiety-core' ),
			'type'    => Controls_Manager::SELECT2,
			'default' => 'fadeIn',
			'options' => [
				''                   => 'none',
				'bounce'             => 'bounce',
				'flash'              => 'flash',
				'pulse'              => 'pulse',
				'fadeIn'             => 'fadeIn',
				'fadeInDown'         => 'fadeInDown',
				'fadeInDownBig'      => 'fadeInDownBig',
				'fadeInLeft'         => 'fadeInLeft',
				'fadeInRight'        => 'fadeInRight',
				'fadeInLeftBig'      => 'fadeInLeftBig',
				'fadeInRightBig'     => 'fadeInRightBig',
				'fadeInUp'           => 'fadeInUp',
				'fadeInUpBig'        => 'fadeInUpBig',
				'flip'               => 'flip',
				'flipInX'            => 'flipInX',
				'flipInY'            => 'flipInY',
				'flipOutX'           => 'flipOutX',
				'flipOutY'           => 'flipOutY',
				'rotateIn'           => 'rotateIn',
				'rotateInDownLeft'   => 'rotateInDownLeft',
				'rotateInDownRight'  => 'rotateInDownRight',
				'rotateInUpLeft'     => 'rotateInUpLeft',
				'rotateInUpRight'    => 'rotateInUpRight',
				'rotateOut'          => 'rotateOut',
				'rotateOutDownLeft'  => 'rotateOutDownLeft',
				'rotateOutDownRight' => 'rotateOutDownRight',
				'rotateOutUpLeft'    => 'rotateOutUpLeft',
				'rotateOutUpRight'   => 'rotateOutUpRight',
				'zoomIn'             => 'zoomIn',
				'zoomInDown'         => 'zoomInDown',
				'zoomInLeft'         => 'zoomInLeft',
				'zoomInRight'        => 'zoomInRight',
				'zoomInUp'           => 'zoomInUp',
				'zoomOut'            => 'zoomOut',
				'zoomOutDown'        => 'zoomOutDown',
				'zoomOutLeft'        => 'zoomOutLeft',
				'zoomOutUp'          => 'zoomOutUp',
			]
		] );

		$this->add_control( 'animation_delay', [
			'label' => __( 'Animation Delay (ms)', 'quiety-core' ),
			'type'  => Controls_Manager::NUMBER,
			'min'   => 100,
			'max'   => 2000,
			'step'  => 100,
		] );

		$this->add_control( 'alt_text', [
			'label'       => __( 'Alt Text', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'placeholder' => __( 'alt test', 'quiety-core' ),
			'default'     => __( 'Quiety', 'quiety-core' ),
		] );

		$this->add_control(
			'positioning_horizontal',
			[
				'label' => __( 'Positioning Horizontal', 'quiety-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'quiety-core' ),
						'icon' => 'eicon-h-align-left',
					],
					'right' => [
						'title' => __( 'Right', 'quiety-core' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => 'left',
				'separator' => 'before'
			]
		);


		$this->add_responsive_control( 'position_left', [
			'label'       => esc_html__( 'Left Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [
					'min' => - 100,
					'max' => 100,
				],
				'px' => [
					'min'  => - 200,
					'max'  => 1000,
					'step' => 5,
				],
			],
			'default'     => [
				'unit' => '%',
			],
			'description' => esc_html__( 'Set figure horizontal offset from left.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-two" => 'left: {{SIZE}}{{UNIT}}; right: auto;',
			],
			'condition' => [
				'positioning_horizontal' => 'left'
			]
		] );

		$this->add_responsive_control( 'position_right', [
			'label'       => esc_html__( 'Right Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [
					'min' => - 100,
					'max' => 100,
				],
				'px' => [
					'min'  => - 200,
					'max'  => 1000,
					'step' => 5,
				],
			],
			'default'     => [
				'unit' => '%',
			],
			'description' => esc_html__( 'Set figure horizontal offset from right.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-two" => 'right: {{SIZE}}{{UNIT}}; left: auto;',
			],
			'condition' => [
				'positioning_horizontal' => 'right'
			],
		] );

		$this->add_control(
			'positioning_vertical',
			[
				'label' => __( 'Positioning Vertical', 'quiety-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'top' => [
						'title' => __( 'Top', 'quiety-core' ),
						'icon' => 'eicon-v-align-top',
					],
					'bottom' => [
						'title' => __( 'Bottom', 'quiety-core' ),
						'icon' => 'eicon-v-align-bottom',
					],

				],
				'default' => 'top',
				'separator' => 'before'
			]
		);

		$this->add_responsive_control( 'position_top', [
			'label'       => esc_html__( 'Top Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [ 'min' => - 100, 'max' => 100 ],
				'px' => [ 'min' => - 200, 'max' => 1000, 'step' => 5 ],
			],
			'default'     => [ 'unit' => '%' ],
			'description' => esc_html__( 'Set figure vertical offset from top.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-two" => 'top: {{SIZE}}{{UNIT}}; bottom: auto;',
			],
			'condition' => [
				'positioning_vertical' => 'top'
			]
		] );

		$this->add_responsive_control( 'position_bottom', [
			'label'       => esc_html__( 'Bottom Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [ 'min' => - 100, 'max' => 100 ],
				'px' => [ 'min' => - 200, 'max' => 1000, 'step' => 5 ],
			],
			'default'     => [ 'unit' => '%' ],
			'description' => esc_html__( 'Set figure vertical offset from bottom.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-two" => 'bottom: {{SIZE}}{{UNIT}}; top: auto',
			],
			'condition' => [
				'positioning_vertical' => 'bottom'
			]
		] );

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow',
				'label' => __( 'Box Shadow', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .image-two img',
			]
		);

		$this->add_control(
			'border_radius',
			[
				'label' => __( 'Border Radius', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .image-two img, {{WRAPPER}} .parallax-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control( 'wrapper_width', [
			'label'       => esc_html__( 'Image wrapper width', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [ 'min' => 5, 'max' => 100 ],
				'px' => [ 'min' => 80, 'max' => 500, 'step' => 5 ],
			],
			'default'     => [ 'unit' => 'px' ],
			'description' => esc_html__( 'Set Image wrapper max width.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-two" => 'width: {{SIZE}}{{UNIT}}',
			],
		] );

		$this->add_control( 'shape_horiizontal', [
			'label'      => __( 'Position Horizontal', 'quiety-core' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'range'      => [
				'px' => [
					'min'  => - 0,
					'max'  => 1000,
					'step' => 5,
				],
				'%'  => [
					'min' => - 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .shape-image' => 'left: {{SIZE}}{{UNIT}};',
			],
			'condition' => [
				'shape_bg_switcher' => 'yes'
			]
		] );

		$this->end_controls_section();







		// Image Two
		//======================
		$this->start_controls_section( 'parallax_section_image_two', [
			'label' => __( 'Image Two', 'quiety-core' ),
			'condition' => [ 'layout' => 'two' ]
		] );

		$this->add_control( 'image_three', [
			'label'     => __( 'Choose Second Image', 'quiety-core' ),
			'type'      => Controls_Manager::MEDIA,
			'default'   => [
				'url' => plugin_dir_url(__DIR__ ) . 'assets/images/app1.png',
			],
		] );

		$this->add_responsive_control( 'parallax_factor_one', [
			'label'       => esc_html__( 'Parallax Factor', 'quiety-core' ),
			'type'        => Controls_Manager::NUMBER,
			'min'         => - 300,
			'max'         => 300,
			'step'        => 10,
			'default'     => - 50,
			'description' => esc_html__( 'Set elements offset and speed. It can be positive (100) or negative (-100). Less means slower.', 'quiety-core' ),
			'separator' => 'before'

		] );

		$this->add_responsive_control( 'animation_name_two', [
			'label'   => esc_html__( 'Animation', 'quiety-core' ),
			'type'    => Controls_Manager::SELECT2,
			'default' => 'fadeIn',
			'options' => [
				''                   => 'none',
				'bounce'             => 'bounce',
				'flash'              => 'flash',
				'pulse'              => 'pulse',
				'fadeIn'             => 'fadeIn',
				'fadeInDown'         => 'fadeInDown',
				'fadeInDownBig'      => 'fadeInDownBig',
				'fadeInLeft'         => 'fadeInLeft',
				'fadeInRight'        => 'fadeInRight',
				'fadeInLeftBig'      => 'fadeInLeftBig',
				'fadeInRightBig'     => 'fadeInRightBig',
				'fadeInUp'           => 'fadeInUp',
				'fadeInUpBig'        => 'fadeInUpBig',
				'flip'               => 'flip',
				'flipInX'            => 'flipInX',
				'flipInY'            => 'flipInY',
				'flipOutX'           => 'flipOutX',
				'flipOutY'           => 'flipOutY',
				'rotateIn'           => 'rotateIn',
				'rotateInDownLeft'   => 'rotateInDownLeft',
				'rotateInDownRight'  => 'rotateInDownRight',
				'rotateInUpLeft'     => 'rotateInUpLeft',
				'rotateInUpRight'    => 'rotateInUpRight',
				'rotateOut'          => 'rotateOut',
				'rotateOutDownLeft'  => 'rotateOutDownLeft',
				'rotateOutDownRight' => 'rotateOutDownRight',
				'rotateOutUpLeft'    => 'rotateOutUpLeft',
				'rotateOutUpRight'   => 'rotateOutUpRight',
				'zoomIn'             => 'zoomIn',
				'zoomInDown'         => 'zoomInDown',
				'zoomInLeft'         => 'zoomInLeft',
				'zoomInRight'        => 'zoomInRight',
				'zoomInUp'           => 'zoomInUp',
				'zoomOut'            => 'zoomOut',
				'zoomOutDown'        => 'zoomOutDown',
				'zoomOutLeft'        => 'zoomOutLeft',
				'zoomOutUp'          => 'zoomOutUp',
			]
		] );

		$this->add_control( 'animation_delay_two', [
			'label' => __( 'Animation Delay (ms)', 'quiety-core' ),
			'type'  => Controls_Manager::NUMBER,
			'min'   => 100,
			'max'   => 2000,
			'step'  => 100,
		] );

		$this->add_control( 'alt_text_two', [
			'label'       => __( 'Alt Text', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'placeholder' => __( 'alt test', 'quiety-core' ),
			'default'     => __( 'Quiety', 'quiety-core' ),
		] );

		$this->add_control(
			'positioning_horizontal_two',
			[
				'label' => __( 'Positioning Horizontal', 'quiety-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'quiety-core' ),
						'icon' => 'eicon-h-align-left',
					],
					'right' => [
						'title' => __( 'Right', 'quiety-core' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => 'left',
				'separator' => 'before'
			]
		);

		$this->add_responsive_control( 'position_left_two', [
			'label'       => esc_html__( 'Left Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [
					'min' => - 100,
					'max' => 100,
				],
				'px' => [
					'min'  => - 200,
					'max'  => 1000,
					'step' => 5,
				],
			],
			'default'     => [
				'unit' => '%',
			],
			'description' => esc_html__( 'Set figure horizontal offset from left.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-two" => 'left: {{SIZE}}{{UNIT}}; right: auto;',
			],
			'condition' => [
				'positioning_horizontal_two' => 'left'
			]
		] );

		$this->add_responsive_control( 'position_right_two', [
			'label'       => esc_html__( 'Right Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [
					'min' => - 100,
					'max' => 100,
				],
				'px' => [
					'min'  => - 200,
					'max'  => 1000,
					'step' => 5,
				],
			],
			'default'     => [
				'unit' => '%',
			],
			'description' => esc_html__( 'Set figure horizontal offset from right.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-two" => 'right: {{SIZE}}{{UNIT}}; left: auto;',
			],
			'condition' => [
				'positioning_horizontal_two' => 'right'
			],
		] );

		$this->add_control(
			'positioning_vertical_two',
			[
				'label' => __( 'Positioning Vertical', 'quiety-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'top' => [
						'title' => __( 'Top', 'quiety-core' ),
						'icon' => 'eicon-v-align-top',
					],
					'bottom' => [
						'title' => __( 'Bottom', 'quiety-core' ),
						'icon' => 'eicon-v-align-bottom',
					],

				],
				'default' => 'top',
				'separator' => 'before'
			]
		);

		$this->add_responsive_control( 'position_top_two', [
			'label'       => esc_html__( 'Top Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [ 'min' => - 100, 'max' => 100 ],
				'px' => [ 'min' => - 200, 'max' => 1000, 'step' => 5 ],
			],
			'default'     => [ 'unit' => '%' ],
			'description' => esc_html__( 'Set figure vertical offset from top.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-two" => 'top: {{SIZE}}{{UNIT}}; bottom: auto;',
			],
			'condition' => [
				'positioning_vertical_two' => 'top'
			]
		] );

		$this->add_responsive_control( 'position_bottom_two', [
			'label'       => esc_html__( 'Bottom Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [ 'min' => - 100, 'max' => 100 ],
				'px' => [ 'min' => - 200, 'max' => 1000, 'step' => 5 ],
			],
			'default'     => [ 'unit' => '%' ],
			'description' => esc_html__( 'Set figure vertical offset from bottom.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-two" => 'bottom: {{SIZE}}{{UNIT}}; top: auto',
			],
			'condition' => [
				'positioning_vertical_two' => 'bottom'
			]
		] );

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow_two',
				'label' => __( 'Box Shadow', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .image-two img',
			]
		);

		$this->add_control(
			'border_radius_two',
			[
				'label' => __( 'Border Radius', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .image-two img, {{WRAPPER}} .parallax-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control( 'wrapper_width_two', [
			'label'       => esc_html__( 'Image wrapper width', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [ 'min' => 5, 'max' => 100 ],
				'px' => [ 'min' => 80, 'max' => 500, 'step' => 5 ],
			],
			'default'     => [ 'unit' => 'px' ],
			'description' => esc_html__( 'Set Image wrapper max width.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-two" => 'width: {{SIZE}}{{UNIT}}',
			],
		] );

		$this->add_control( 'shape_horizontal_two', [
			'label'      => __( 'Position Horizontal', 'quiety-core' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'range'      => [
				'px' => [
					'min'  => 0,
					'max'  => 1000,
					'step' => 5,
				],
				'%'  => [
					'min' => 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .shape-image' => 'left: {{SIZE}}{{UNIT}};',
			],
			'condition' => [
				'shape_bg_switcher' => 'yes'
			]
		] );

		$this->end_controls_section();




		// Image Three
		//======================
		$this->start_controls_section( 'parallax_section_image_three', [
			'label' => __( 'Image Three', 'quiety-core' ),
			'condition' => [ 'layout' => 'two' ]
		] );

		$this->add_control( 'image_four', [
			'label'     => __( 'Choose Second Image', 'quiety-core' ),
			'type'      => Controls_Manager::MEDIA,
			'default'   => [
				'url' => plugin_dir_url(__DIR__ ) . 'assets/images/app2.png',
			],
		] );

		$this->add_responsive_control( 'parallax_factor_two', [
			'label'       => esc_html__( 'Parallax Factor', 'quiety-core' ),
			'type'        => Controls_Manager::NUMBER,
			'min'         => - 300,
			'max'         => 300,
			'step'        => 10,
			'default'     => - 50,
			'description' => esc_html__( 'Set elements offset and speed. It can be positive (100) or negative (-100). Less means slower.', 'quiety-core' ),
			'separator' => 'before'

		] );

		$this->add_responsive_control( 'animation_name_three', [
			'label'   => esc_html__( 'Animation', 'quiety-core' ),
			'type'    => Controls_Manager::SELECT2,
			'default' => 'fadeIn',
			'options' => [
				''                   => 'none',
				'bounce'             => 'bounce',
				'flash'              => 'flash',
				'pulse'              => 'pulse',
				'fadeIn'             => 'fadeIn',
				'fadeInDown'         => 'fadeInDown',
				'fadeInDownBig'      => 'fadeInDownBig',
				'fadeInLeft'         => 'fadeInLeft',
				'fadeInRight'        => 'fadeInRight',
				'fadeInLeftBig'      => 'fadeInLeftBig',
				'fadeInRightBig'     => 'fadeInRightBig',
				'fadeInUp'           => 'fadeInUp',
				'fadeInUpBig'        => 'fadeInUpBig',
				'flip'               => 'flip',
				'flipInX'            => 'flipInX',
				'flipInY'            => 'flipInY',
				'flipOutX'           => 'flipOutX',
				'flipOutY'           => 'flipOutY',
				'rotateIn'           => 'rotateIn',
				'rotateInDownLeft'   => 'rotateInDownLeft',
				'rotateInDownRight'  => 'rotateInDownRight',
				'rotateInUpLeft'     => 'rotateInUpLeft',
				'rotateInUpRight'    => 'rotateInUpRight',
				'rotateOut'          => 'rotateOut',
				'rotateOutDownLeft'  => 'rotateOutDownLeft',
				'rotateOutDownRight' => 'rotateOutDownRight',
				'rotateOutUpLeft'    => 'rotateOutUpLeft',
				'rotateOutUpRight'   => 'rotateOutUpRight',
				'zoomIn'             => 'zoomIn',
				'zoomInDown'         => 'zoomInDown',
				'zoomInLeft'         => 'zoomInLeft',
				'zoomInRight'        => 'zoomInRight',
				'zoomInUp'           => 'zoomInUp',
				'zoomOut'            => 'zoomOut',
				'zoomOutDown'        => 'zoomOutDown',
				'zoomOutLeft'        => 'zoomOutLeft',
				'zoomOutUp'          => 'zoomOutUp',
			]
		] );

		$this->add_control( 'animation_delay_three', [
			'label' => __( 'Animation Delay (ms)', 'quiety-core' ),
			'type'  => Controls_Manager::NUMBER,
			'min'   => 100,
			'max'   => 2000,
			'step'  => 100,
		] );

		$this->add_control( 'alt_text_three', [
			'label'       => __( 'Alt Text', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'placeholder' => __( 'alt test', 'quiety-core' ),
			'default'     => __( 'Quiety', 'quiety-core' ),
		] );

		$this->add_control(
			'positioning_horizontal_three',
			[
				'label' => __( 'Positioning Horizontal', 'quiety-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'quiety-core' ),
						'icon' => 'eicon-h-align-left',
					],
					'right' => [
						'title' => __( 'Right', 'quiety-core' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => 'left',
				'separator' => 'before'
			]
		);

		$this->add_responsive_control( 'position_left_three', [
			'label'       => esc_html__( 'Left Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [
					'min' => - 100,
					'max' => 100,
				],
				'px' => [
					'min'  => - 200,
					'max'  => 1000,
					'step' => 5,
				],
			],
			'default'     => [
				'unit' => '%',
			],
			'description' => esc_html__( 'Set figure horizontal offset from left.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-three" => 'left: {{SIZE}}{{UNIT}}; right: auto;',
			],
			'condition' => [
				'positioning_horizontal_three' => 'left'
			]
		] );

		$this->add_responsive_control( 'position_right_three', [
			'label'       => esc_html__( 'Right Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [
					'min' => - 100,
					'max' => 100,
				],
				'px' => [
					'min'  => - 200,
					'max'  => 1000,
					'step' => 5,
				],
			],
			'default'     => [
				'unit' => '%',
			],
			'description' => esc_html__( 'Set figure horizontal offset from right.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-three" => 'right: {{SIZE}}{{UNIT}}; left: auto;',
			],
			'condition' => [
				'positioning_horizontal_three' => 'right'
			],
		] );

		$this->add_control(
			'positioning_vertical_three',
			[
				'label' => __( 'Positioning Vertical', 'quiety-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'top' => [
						'title' => __( 'Top', 'quiety-core' ),
						'icon' => 'eicon-v-align-top',
					],
					'bottom' => [
						'title' => __( 'Bottom', 'quiety-core' ),
						'icon' => 'eicon-v-align-bottom',
					],

				],
				'default' => 'top',
				'separator' => 'before'
			]
		);

		$this->add_responsive_control( 'position_top_three', [
			'label'       => esc_html__( 'Top Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [ 'min' => - 100, 'max' => 100 ],
				'px' => [ 'min' => - 200, 'max' => 1000, 'step' => 5 ],
			],
			'default'     => [ 'unit' => '%' ],
			'description' => esc_html__( 'Set figure vertical offset from top.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-three" => 'top: {{SIZE}}{{UNIT}}; bottom: auto;',
			],
			'condition' => [
				'positioning_vertical_three' => 'top'
			]
		] );

		$this->add_responsive_control( 'position_bottom_three', [
			'label'       => esc_html__( 'Bottom Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [ 'min' => - 100, 'max' => 100 ],
				'px' => [ 'min' => - 200, 'max' => 1000, 'step' => 5 ],
			],
			'default'     => [ 'unit' => '%' ],
			'description' => esc_html__( 'Set figure vertical offset from bottom.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-three" => 'bottom: {{SIZE}}{{UNIT}}; top: auto',
			],
			'condition' => [
				'positioning_vertical_three' => 'bottom'
			]
		] );

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow_three',
				'label' => __( 'Box Shadow', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .image-three img',
			]
		);

		$this->add_control(
			'border_radius_three',
			[
				'label' => __( 'Border Radius', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .image-three img, {{WRAPPER}} .parallax-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control( 'wrapper_width_three', [
			'label'       => esc_html__( 'Image wrapper width', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [ 'min' => 5, 'max' => 100 ],
				'px' => [ 'min' => 80, 'max' => 500, 'step' => 5 ],
			],
			'default'     => [ 'unit' => 'px' ],
			'description' => esc_html__( 'Set Image wrapper max width.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-three" => 'width: {{SIZE}}{{UNIT}}',
			],
		] );

		$this->add_control( 'shape_horiizontal_three', [
			'label'      => __( 'Position Horizontal', 'quiety-core' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'range'      => [
				'px' => [
					'min'  => - 0,
					'max'  => 1000,
					'step' => 5,
				],
				'%'  => [
					'min' => - 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .shape-image' => 'left: {{SIZE}}{{UNIT}};',
			],
			'condition' => [
				'shape_bg_switcher' => 'yes'
			]
		] );

		$this->end_controls_section();




		// Image Four
		//======================
		$this->start_controls_section( 'parallax_section_image_four', [
			'label' => __( 'Image Four', 'quiety-core' ),
			'condition' => [ 'layout' => 'two' ]
		] );

		$this->add_control( 'image_five', [
			'label'     => __( 'Choose Image', 'quiety-core' ),
			'type'      => Controls_Manager::MEDIA,
			'default'   => [
				'url' => plugin_dir_url(__DIR__ ) . 'assets/images/app3.png',
			],
		] );

		$this->add_responsive_control( 'parallax_factor_three', [
			'label'       => esc_html__( 'Parallax Factor', 'quiety-core' ),
			'type'        => Controls_Manager::NUMBER,
			'min'         => - 300,
			'max'         => 300,
			'step'        => 10,
			'default'     => - 50,
			'description' => esc_html__( 'Set elements offset and speed. It can be positive (100) or negative (-100). Less means slower.', 'quiety-core' ),
			'separator' => 'before'

		] );

		$this->add_responsive_control( 'animation_name_four', [
			'label'   => esc_html__( 'Animation', 'quiety-core' ),
			'type'    => Controls_Manager::SELECT2,
			'default' => 'fadeIn',
			'options' => [
				''                   => 'none',
				'bounce'             => 'bounce',
				'flash'              => 'flash',
				'pulse'              => 'pulse',
				'fadeIn'             => 'fadeIn',
				'fadeInDown'         => 'fadeInDown',
				'fadeInDownBig'      => 'fadeInDownBig',
				'fadeInLeft'         => 'fadeInLeft',
				'fadeInRight'        => 'fadeInRight',
				'fadeInLeftBig'      => 'fadeInLeftBig',
				'fadeInRightBig'     => 'fadeInRightBig',
				'fadeInUp'           => 'fadeInUp',
				'fadeInUpBig'        => 'fadeInUpBig',
				'flip'               => 'flip',
				'flipInX'            => 'flipInX',
				'flipInY'            => 'flipInY',
				'flipOutX'           => 'flipOutX',
				'flipOutY'           => 'flipOutY',
				'rotateIn'           => 'rotateIn',
				'rotateInDownLeft'   => 'rotateInDownLeft',
				'rotateInDownRight'  => 'rotateInDownRight',
				'rotateInUpLeft'     => 'rotateInUpLeft',
				'rotateInUpRight'    => 'rotateInUpRight',
				'rotateOut'          => 'rotateOut',
				'rotateOutDownLeft'  => 'rotateOutDownLeft',
				'rotateOutDownRight' => 'rotateOutDownRight',
				'rotateOutUpLeft'    => 'rotateOutUpLeft',
				'rotateOutUpRight'   => 'rotateOutUpRight',
				'zoomIn'             => 'zoomIn',
				'zoomInDown'         => 'zoomInDown',
				'zoomInLeft'         => 'zoomInLeft',
				'zoomInRight'        => 'zoomInRight',
				'zoomInUp'           => 'zoomInUp',
				'zoomOut'            => 'zoomOut',
				'zoomOutDown'        => 'zoomOutDown',
				'zoomOutLeft'        => 'zoomOutLeft',
				'zoomOutUp'          => 'zoomOutUp',
			]
		] );

		$this->add_control( 'animation_delay_four', [
			'label' => __( 'Animation Delay (ms)', 'quiety-core' ),
			'type'  => Controls_Manager::NUMBER,
			'min'   => 100,
			'max'   => 2000,
			'step'  => 100,
		] );

		$this->add_control( 'alt_text_four', [
			'label'       => __( 'Alt Text', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'placeholder' => __( 'alt test', 'quiety-core' ),
			'default'     => __( 'Quiety', 'quiety-core' ),
		] );

		$this->add_control(
			'positioning_horizontal_four',
			[
				'label' => __( 'Positioning Horizontal', 'quiety-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'quiety-core' ),
						'icon' => 'eicon-h-align-left',
					],
					'right' => [
						'title' => __( 'Right', 'quiety-core' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => 'left',
				'separator' => 'before'
			]
		);

		$this->add_responsive_control( 'position_left_four', [
			'label'       => esc_html__( 'Left Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [
					'min' => - 100,
					'max' => 100,
				],
				'px' => [
					'min'  => - 200,
					'max'  => 1000,
					'step' => 5,
				],
			],
			'default'     => [
				'unit' => '%',
			],
			'description' => esc_html__( 'Set figure horizontal offset from left.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-four" => 'left: {{SIZE}}{{UNIT}}; right: auto;',
			],
			'condition' => [
				'positioning_horizontal_three' => 'left'
			]
		] );

		$this->add_responsive_control( 'position_right_four', [
			'label'       => esc_html__( 'Right Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [
					'min' => - 100,
					'max' => 100,
				],
				'px' => [
					'min'  => - 200,
					'max'  => 1000,
					'step' => 5,
				],
			],
			'default'     => [
				'unit' => '%',
			],
			'description' => esc_html__( 'Set figure horizontal offset from right.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-four" => 'right: {{SIZE}}{{UNIT}}; left: auto;',
			],
			'condition' => [
				'positioning_horizontal_three' => 'right'
			],
		] );

		$this->add_control(
			'positioning_vertical_four',
			[
				'label' => __( 'Positioning Vertical', 'quiety-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'top' => [
						'title' => __( 'Top', 'quiety-core' ),
						'icon' => 'eicon-v-align-top',
					],
					'bottom' => [
						'title' => __( 'Bottom', 'quiety-core' ),
						'icon' => 'eicon-v-align-bottom',
					],

				],
				'default' => 'top',
				'separator' => 'before'
			]
		);

		$this->add_responsive_control( 'position_top_four', [
			'label'       => esc_html__( 'Top Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [ 'min' => - 100, 'max' => 100 ],
				'px' => [ 'min' => - 200, 'max' => 1000, 'step' => 5 ],
			],
			'default'     => [ 'unit' => '%' ],
			'description' => esc_html__( 'Set figure vertical offset from top.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-four" => 'top: {{SIZE}}{{UNIT}}; bottom: auto;',
			],
			'condition' => [
				'positioning_vertical_three' => 'top'
			]
		] );

		$this->add_responsive_control( 'position_bottom_four', [
			'label'       => esc_html__( 'Bottom Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [ 'min' => - 100, 'max' => 100 ],
				'px' => [ 'min' => - 200, 'max' => 1000, 'step' => 5 ],
			],
			'default'     => [ 'unit' => '%' ],
			'description' => esc_html__( 'Set figure vertical offset from bottom.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-four" => 'bottom: {{SIZE}}{{UNIT}}; top: auto',
			],
			'condition' => [
				'positioning_vertical_three' => 'bottom'
			]
		] );

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow_four',
				'label' => __( 'Box Shadow', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .image-four img',
			]
		);

		$this->add_control(
			'border_radius_four',
			[
				'label' => __( 'Border Radius', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .image-four img, {{WRAPPER}} .parallax-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control( 'wrapper_width_four', [
			'label'       => esc_html__( 'Image wrapper width', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [ 'min' => 5, 'max' => 100 ],
				'px' => [ 'min' => 80, 'max' => 500, 'step' => 5 ],
			],
			'default'     => [ 'unit' => 'px' ],
			'description' => esc_html__( 'Set Image wrapper max width.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .image-four" => 'width: {{SIZE}}{{UNIT}}',
			],
		] );

		$this->add_control( 'shape_horiizontal_four', [
			'label'      => __( 'Position Horizontal', 'quiety-core' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'range'      => [
				'px' => [
					'min'  => - 0,
					'max'  => 1000,
					'step' => 5,
				],
				'%'  => [
					'min' => - 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .shape-image' => 'left: {{SIZE}}{{UNIT}};',
			],
			'condition' => [
				'shape_bg_switcher' => 'yes'
			]
		] );

		$this->end_controls_section();


		$this->start_controls_section( 'bg_section', [
			'label' => __( 'Shape Image', 'quiety-core' ),
		] );

		$this->add_control( 'shape', [
			'label'     => __( 'Choose Image', 'quiety-core' ),
			'type'      => Controls_Manager::MEDIA,
			'default'   => [
				'url' => plugin_dir_url(__DIR__ ) . 'assets/images/dot.png',
			],
		] );

		$this->add_control(
			'bg_positioning_horizontal',
			[
				'label' => __( 'Positioning Horizontal', 'quiety-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'quiety-core' ),
						'icon' => 'eicon-h-align-left',
					],
					'right' => [
						'title' => __( 'Right', 'quiety-core' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => 'left',
				'separator' => 'before'
			]
		);

		$this->add_responsive_control( 'bg_position_left', [
			'label'       => esc_html__( 'Left Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [
					'min' => - 100,
					'max' => 100,
				],
				'px' => [
					'min'  => - 200,
					'max'  => 1000,
					'step' => 5,
				],
			],
			'default'     => [
				'unit' => '%',
			],
			'description' => esc_html__( 'Set figure horizontal offset from left.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .dot_shape" => 'left: {{SIZE}}{{UNIT}}; right: auto;',
			],
			'condition' => [
				'bg_positioning_horizontal' => 'left'
			]
		] );

		$this->add_responsive_control( 'bg_position_right', [
			'label'       => esc_html__( 'Right Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [
					'min' => - 100,
					'max' => 100,
				],
				'px' => [
					'min'  => - 200,
					'max'  => 1000,
					'step' => 5,
				],
			],
			'default'     => [
				'unit' => '%',
			],
			'description' => esc_html__( 'Set figure horizontal offset from right.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .dot_shape" => 'right: {{SIZE}}{{UNIT}}; left: auto;',
			],
			'condition' => [
				'bg_positioning_horizontal' => 'right'
			],
		] );

		$this->add_control(
			'bg_positioning_vertical',
			[
				'label' => __( 'Positioning Vertical', 'quiety-core' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'top' => [
						'title' => __( 'Top', 'quiety-core' ),
						'icon' => 'eicon-v-align-top',
					],
					'bottom' => [
						'title' => __( 'Bottom', 'quiety-core' ),
						'icon' => 'eicon-v-align-bottom',
					],

				],
				'default' => 'top',
				'separator' => 'before'
			]
		);

		$this->add_responsive_control( 'bg_position_top', [
			'label'       => esc_html__( 'Top Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [ 'min' => - 100, 'max' => 100 ],
				'px' => [ 'min' => - 200, 'max' => 1000, 'step' => 5 ],
			],
			'default'     => [ 'unit' => '%' ],
			'description' => esc_html__( 'Set figure vertical offset from top.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .dot_shape" => 'top: {{SIZE}}{{UNIT}}; bottom: auto;',
			],
			'condition' => [
				'bg_positioning_vertical' => 'top'
			]
		] );

		$this->add_responsive_control( 'bg_position_bottom', [
			'label'       => esc_html__( 'Bottom Offset', 'quiety-core' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ '%', 'px' ],
			'range'       => [
				'%'  => [ 'min' => - 100, 'max' => 100 ],
				'px' => [ 'min' => - 200, 'max' => 1000, 'step' => 5 ],
			],
			'default'     => [ 'unit' => '%' ],
			'description' => esc_html__( 'Set figure vertical offset from bottom.', 'quiety-core' ),
			'selectors'   => [
				"{{WRAPPER}} .dot_shape" => 'bottom: {{SIZE}}{{UNIT}}; top: auto',
			],
			'condition' => [
				'bg_positioning_vertical' => 'bottom'
			]
		] );

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => __( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient'],
				'exclude' => ['image'],
				'selector' => '{{WRAPPER}} .tt-parallax__image .parallax-image	',
			]
		);

		$this->add_responsive_control(
			'wrapper_padding',
			[
				'label' => __( 'Wrapper Padding', 'quiety-padding' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .tt-parallax__image' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings();
		$this->add_render_attribute( 'wrapper', 'class', 'tt-parallax__image' );

		if ( $settings['layout'] == 'two' ) {
			$this->add_render_attribute( 'wrapper', 'class', 'tt-parallax__image--two' );
		}
		?>

		<?php if ( $settings['layout'] == 'one') : ?>
			<div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
				<div class="parallax-image">
					<?php if ( ! empty( $settings['image']['url'] ) ) : ?>
						<div class="image-one <?php echo $settings['skewed'] == 'yes' ? 'image_skew' : ''; ?>">
							<img src="<?php echo esc_url( $settings['image']['url'] ); ?>" alt="<?php echo esc_attr__( 'Shape Image', 'quiety-core' ) ?>">
						</div>
						<!-- /.image-one -->
					<?php endif; ?>
				</div>

				<?php if ( ! empty( $settings['image_two']['url'] ) ) : ?>
					<div class="image-two">
						<img src="<?php echo esc_url( $settings['image_two']['url'] ) ?>" class="wow <?php echo esc_html($settings['animation_name']); ?>" data-parallax='{"y": <?php echo esc_attr( $settings['parallax_factor'] ); ?>}' alt="<?php echo esc_attr__( 'Shape Image', 'quiety-core' ) ?>">
					</div>
					<!-- /.image-two -->
				<?php endif; ?>

				<?php if ( ! empty( $settings['shape']['url'] ) ) : ?>
					<div class="dot_shape">
						<img src="<?php echo esc_url( $settings['shape']['url'] ) ?>" class="wow" alt="<?php echo esc_attr__( 'Shape Image', 'quiety-core' ) ?>">
					</div>
					<!-- /.image-two -->
				<?php endif; ?>
			</div>
			<!-- /.tt-parallax__image -->
		<?php elseif ($settings['layout'] == 'two') : ?>
			<div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
				<div class="parallax-image-two">
					<?php if ( ! empty( $settings['image_main']['url'] ) ) : ?>
						<div class="image-one">
							<img src="<?php echo esc_url( $settings['image_main']['url'] ); ?>" alt="<?php echo esc_attr__( 'Shape Image', 'quiety-core' ) ?>">
						</div>
						<!-- /.image-one -->
					<?php endif; ?>
				</div>

				<?php if ( ! empty( $settings['image_three']['url'] ) ) : ?>
					<div class="image-two">
						<img src="<?php echo esc_url( $settings['image_three']['url'] ) ?>" class="wow <?php echo esc_html($settings['animation_name_two']); ?>" data-parallax='{"y": <?php echo esc_attr( $settings['parallax_factor_one'] ); ?>}' alt="<?php echo esc_attr( $settings['alt_text_two'] ); ?>">
					</div>
					<!-- /.image-two -->
				<?php endif; ?>

				<?php if ( ! empty( $settings['image_four']['url'] ) ) : ?>
					<div class="image-three">
						<img src="<?php echo esc_url( $settings['image_four']['url'] ) ?>" class="wow <?php echo esc_html($settings['animation_name_three']); ?>" data-parallax='{"y": <?php echo esc_attr( $settings['parallax_factor_two'] ); ?>}' alt="<?php echo esc_attr( $settings['alt_text_three'] ); ?>">
					</div>
					<!-- /.image-two -->
				<?php endif; ?>

				<?php if ( ! empty( $settings['image_five']['url'] ) ) : ?>
					<div class="image-four">
						<img src="<?php echo esc_url( $settings['image_five']['url'] ) ?>" class="wow <?php echo esc_html($settings['animation_name_four']); ?>" data-parallax='{"y": <?php echo esc_attr( $settings['parallax_factor_three'] ); ?>}' alt="<?php echo esc_attr( $settings['alt_text_three'] ); ?>">
					</div>
					<!-- /.image-two -->
				<?php endif; ?>

				<?php if ( ! empty( $settings['shape']['url'] ) ) : ?>
					<div class="dot_shape">
						<img src="<?php echo esc_url( $settings['shape']['url'] ) ?>" class="wow" alt="<?php echo esc_attr__( 'Shape Image', 'quiety-core' ) ?>">
					</div>
					<!-- /.image-two -->
				<?php endif; ?>
			</div>
		<?php endif;
	}
}
