<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Controls_Manager, Group_Control_Typography, Widget_Base};


class Quiety_Popup_Video extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tt-popup-video';
	}


	public function get_title() {
		return __( 'Quiety Popup Video', 'quiety-core' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-play';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

    /**
     * Name: register_controls
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: themetags
     */
    protected function register_controls() {
        $this-> elementor_content_control();
        $this-> elementor_style_control();
    }

    /**
     * Name: elementor_content_control
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: themetags
     */
    public function elementor_content_control() {

        $this->start_controls_section(
            'section_content', [
                'label' => __( 'Popup Video Button', 'quiety-core' ),
            ]
        );

        // Video Layout
        $this->add_control(
            'layout', [
                'label' => __( 'Heading Layout', 'quiety-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => __( 'Default', 'quiety-core' ),
                    '2' => __( 'Text with Icon', 'quiety-core' ),
                ],
                'default' => '1',
                'separator' => 'after'
            ]
        );

        $this->add_control(
            'video_text', [
                'label'       => __( 'Video Text', 'quiety-core' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'How It Work',
                'condition' => [
                    'layout'  => '2'
                ]
            ]
        );

        $this->add_control(
            'video_link', [
                'label'       => __( 'Video Link', 'quiety-core' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true
            ]
        );

        $this->add_responsive_control(
            'text_align', [
                'label' => __( 'Alignment', 'quiety-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __( 'Left', 'quiety-core' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'quiety-core' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => __( 'Right', 'quiety-core' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'left',
                'selectors' => [
                    '{{WRAPPER}} .play-button-wrapper' => 'text-align: {{VALUE}};'
                ],
                'toggle' => true,
            ]
        );

        $this->end_controls_section(); //End Video

    }


    /**
     * Name: elementor_style_control
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @landpagy
     * Author: themetags
     */
    public function elementor_style_control () {


        //====================== Video Icon =================//
        $this->start_controls_section(
            'button_style_section', [
                'label' => __( 'Icon', 'quiety-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'icon_color', [
                'label' => __( 'Color', 'quiety-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .popup-video-btn' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .popup-youtube i' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
			'icon_size',
			[
				'label' => esc_html__( 'Icon Size', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .popup-youtube i' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);
        $this->add_control(
            'icon_bg', [
                'label' => __( 'Background', 'quiety-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .popup-video-btn, {{WRAPPER}} .popup-youtube i' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .popup-video-btn:before, {{WRAPPER}} .popup-video-btn:after' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'hover_options', [
                'label' => __( 'Hover', 'plugin-name' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );


        $this->add_control(
            'icon_color_hover', [
                'label' => __( 'Color', 'quiety-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .popup-video-btn:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .popup-youtube:hover i' => 'color: {{VALUE}}',
                ],
            ]
        );


        $this->add_control(
            'icon_bg_hover', [
                'label' => __( 'Background', 'quiety-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .popup-video-btn:hover' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .popup-youtube:hover i' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .popup-video-btn:hover:before, {{WRAPPER}} .popup-video-btn:hover:after' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_width', [
                'label' => esc_html__( 'Icon Width', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .popup-youtube i' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'layout' => '2'
                ],
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'icon_border_radius', [
                'label' => esc_html__( 'Border Radius', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .popup-youtube i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_control(
			'width',
			[
				'label' => esc_html__( 'Background Area', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .popup-video-btn' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .popup-video-btn:before' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
				],
			]
		);

        $this->end_controls_section(); //End Video


        //====================== Video Text =================//
        $this->start_controls_section(
            'style_video_text', [
                'label' => __( 'Text', 'quiety-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => '2'
                ]
            ]
        );

        $this->add_control(
            'text_color', [
                'label' => __( 'Color', 'quiety-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .popup-youtube span' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name' => 'text_typo',
                'selector' => '{{WRAPPER}} .popup-youtube span',
            ]
        );

        $this->end_controls_section(); //End Video Text

    }

    /**
     * Name: render
     * Desc: Widgets Render
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
	protected function render( ) {
		$settings = $this->get_settings_for_display();
        extract($settings);
		$link_video = $settings['video_link'] ? $settings['video_link'] : '';

        if ( !empty($layout === '1') ) {
            ?>
            <div class="play-button-wrapper">
                <a class="popup-video-btn popup-video popup-youtube" href="<?php echo esc_url( $link_video ) ?>"><i class="fas fa-play"></i></a>
            </div>
            <?php
        }
        if ( !empty($layout === '2') ) {
            ?>
            <div class="play-button-wrapper">
                <a href="<?php echo esc_url( $link_video ) ?>" class="video-icon popup-youtube">
                    <i class="fas fa-play d-inline-flex justify-content-center align-items-center"></i>
                    <span class="ms-2 fs-md fw-bold"><?php echo esc_html($settings['video_text']) ?></span>
                </a>
            </div>
            <?php
        }
	}
}