<?php

namespace Quiety\Widgets;

use Elementor\{Controls_Manager, Group_Control_Box_Shadow, Widget_Base, Group_Control_Typography};

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Quiety_Portfolio extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-portfolios';
	}

	public function get_title() {
		return __( 'Quiety Portfolio', 'quiety-core' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-photo-library';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section('section_layout', [
			'label' => __('Layout', 'quiety-core'),
		]);
		$this->add_control('layout', [
			'label'   => __('Select Layout', 'quiety-core'),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'grid-1'	=> __('Grid 1', 'quiety-core'),
				'grid-2'	=> __('Grid 2', 'quiety-core'),
				'grid-3'	=> __('Grid 3', 'quiety-core'),
				'grid-4'	=> __('Grid 4', 'quiety-core'),
				'grid-5'	=> __('Grid 5', 'quiety-core'),

			],
			'default' => 'grid-1',
		]);
		$this->end_controls_section();

		$this->start_controls_section('intro_title_section', [
			'label' => __('Intro Title', 'quiety-core'),
			'condition' => [
				'layout' => 'grid-2'
			]
		]);
		$this->add_control('intro_title', [
			'label'       => __('Title Text', 'quiety-core'),
			'type'        => Controls_Manager::TEXTAREA,
			'default'     => '',
			'label_block' => true,
			'description' => __("Enter text within {Title} for highlited color", 'quiety-core')

		]);
		$this->end_controls_section();


		$this->start_controls_section( 'section_query', [
			'label' => __( 'Portfolio', 'quiety-core' ),
		] );

		$this->add_control( 'column', [
			'label'   => __( 'Columns', 'quiety-core' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'2' => __( 'Two Column', 'quiety-core' ),
				'4'  => __( 'Three Column', 'quiety-core' ),
				'3'  => __( 'Four Column', 'quiety-core' ),	
			],
			'condition' => [
				'layout!' => 'grid-2'
			],
			
			'default' => '2 ',
		] );
		$this->add_control('select_cat', [
			'label'   => esc_html__('Select Category', 'quiety-core'),
			'type'    => Controls_Manager::SELECT2,
			'multiple' => true,	
			'label_block' => true,
			'options' => quiety_cat_array('portfolio_cat'),
		]);
		$this->add_control( 'ids', [
			'label'       => __( 'Enter Work IDs', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => '',
			'label_block' => true,
			'description' => __( "Enter Work ids to show, separated by a comma. Leave empty to show all.", 'quiety-core' )

		] );
		$this->add_control( 'ids_not', [
			'label'       => __( 'Or Work IDs to Exclude', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => '',
			'label_block' => true,
			'description' => __( "Enter Work ids to exclude, separated by a comma (,). Use if the field above is empty.", 'quiety-core' )

		] );

		$this->add_control( 'order_by', [
			'label'       => __( 'Order by', 'quiety-core' ),
			'type'        => Controls_Manager::SELECT,
			'options'     => [
				'date'          => esc_html__( 'Date', 'quiety-core' ),
				'ID'            => esc_html__( 'ID', 'quiety-core' ),
				'author'        => esc_html__( 'Author', 'quiety-core' ),
				'title'         => esc_html__( 'Title', 'quiety-core' ),
				'modified'      => esc_html__( 'Modified', 'quiety-core' ),
				'rand'          => esc_html__( 'Random', 'quiety-core' ),
				'comment_count' => esc_html__( 'Comment Count', 'quiety-core' ),
				'menu_order'    => esc_html__( 'Menu Order', 'quiety-core' ),
			],
			'default'     => 'date',
			'separator'   => 'before',
			'description' => esc_html__( "Select how to sort retrieved posts. More at ", 'quiety-core' ) . '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex</a>.',
		] );

		$this->add_control( 'order', [
			'label'       => __( 'Sort Order', 'quiety-core' ),
			'type'        => Controls_Manager::SELECT,
			'options'     => [
				'ASC'  => esc_html__( 'Ascending', 'quiety-core' ),
				'DESC' => esc_html__( 'Descending', 'quiety-core' ),
			],
			'default'     => 'DESC',
			'separator'   => 'before',
			'description' => esc_html__( "Select Ascending or Descending order. More at", 'quiety-core' ) . '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex</a>.',
		] );

		$this->add_control( 'posts_per_page', [
			'label'       => __( 'Work to show', 'quiety-core' ),
			'type'        => Controls_Manager::NUMBER,
			'default'     => '6',
			'description' => esc_html__( "Number of work to show (-1 for all).", 'quiety-core' ),
			'min'         => 1,
		] );
		$this->add_control(
			'portfolio_readmore_btn',
			[
				'label' => esc_html__( 'Read More Button', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Read More', 'quiety-core' ),
				'placeholder' => esc_html__( 'Read More', 'quiety-core' ),
			]
		);


		$this->end_controls_section();

	}

	protected function render() {

		$settings = $this->get_settings_for_display();
		extract( $settings );

		include_once __DIR__ . '/templates/portfolio/style-' . $layout . '.php';

	}
}
