<?php

namespace Quiety\Widgets;

if (!defined('ABSPATH')) {
    exit;
}

use Elementor\{
    Controls_Manager,
    Group_Control_Background,
    Group_Control_Border,
    Group_Control_Box_Shadow,
    Widget_Base,
    Group_Control_Typography,
    Repeater,
    Utils,
    WP_Query
};

class quiety_portfolio_massonry extends Widget_Base
{

    public function get_name()
    {
        return 'quiety-portfolio-massonry';
    }

    public function get_title()
    {
        return __('Quiety Masonry Portfolio', 'quiety-core');
    }

    public function get_icon()
    {
        return 'eicon-layout-settings';
    }

    public function get_categories()
    {
        return ['tt-elements'];
    }

    protected function register_controls()
    {
        $this->content_controls();
        $this->style_controls();
    }

    public function content_controls()
    {

        $this->start_controls_section('select_layout', [
            'label' => esc_html__('Select Layout', 'quiety-core'),
        ]);

        $this->add_control(
            'layout',
            [
                'label' => __('Porfolio Masonry', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '1',
                'options' => [
                    '1'  => __('01: Layout', 'quiety-core'),
                    '2'  => __('02: Layout', 'quiety-core')
                ],
            ]
        );
        $this->end_controls_section(); //End Layout


        $this->start_controls_section( 'metro_layout', [
			'label' => __( 'Portfolio Masonry', 'quiety-core' ),
		] );

        $layout_repeater = new \Elementor\Repeater();
        $layout_repeater->add_control(
            'align_items', [
                'label'   => esc_html__( 'Item Size', 'rave-core' ),
                'type'    => Controls_Manager::HIDDEN,
            ]
        );

        $layout_repeater->add_control(
            'size', [
                'label'   => esc_html__( 'Item Size', 'rave-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'col-lg-4 col-md-6',
                'options' => [
                    'col-lg-6 col-md-6' => __( '50%', 'rave-core' ),
                    'col-lg-4 col-md-6' => __( '33%', 'rave-core' ),
                    'col-lg-3 col-md-3' => __( '25%', 'rave-core' ),
                ],
            ]
        );

        $this->add_control(
            'grid_metro_layout3', [
                'label'       => esc_html__( 'Metro Layout', 'rave-core' ),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $layout_repeater->get_controls(),
                'title_field' => '{{{ align_items }}}',
                'prevent_empty' => false,
                
            ]
        );
        $this->end_controls_section();



        $this->start_controls_section('section_filter', [
            'label' => esc_html__('Portfolio Filter', 'quiety-core'),
        ]);

        $this->add_control('show_count', [
            'label'   => esc_html__('Post count', 'quiety-core'),
            'type'    => Controls_Manager::NUMBER,
            'default' => 6
        ]);

        $this->add_control(
            'cats',
            [
                'label' => esc_html__('Category', 'quiety-core'),
                'type'      => Controls_Manager::SELECT2,
                'options'   => \Quiety_Helper::get_the_category_array('portfolio_cat'),
                'label_block' => true,
                'multiple'  => true,
            ]
        );

        $this->add_control(
            'order',
            [
                'label' => esc_html__('Order', 'quiety-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'ASC' => 'ASC',
                    'DESC' => 'DESC'
                ],
                'default' => 'ASC'
            ]
        );

        $this->add_control(
            'orderby',
            [
                'label' => esc_html__('Order By', 'quiety-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'none' => 'None',
                    'ID' => 'ID',
                    'author' => 'Author',
                    'title' => 'Title',
                    'name' => 'Name (by post slug)',
                    'date' => 'Date',
                    'rand' => 'Random',
                ],
                'default' => 'none'
            ]
        );

        $this->add_control(
            'title_length',
            [
                'label' => esc_html__('Title Length', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::NUMBER,
            ]
        );

        $this->add_control(
            'excerpt_length',
            [
                'label' => esc_html__('Excerpt Word Length', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 15,
            ]
        );

        $this->add_control(
            'exclude',
            [
                'label' => esc_html__('Exclude Blog', 'quiety-core'),
                'description' => esc_html__('Enter the Listting post IDs to hide/exclude. Input the multiple ID with comma separated', 'quiety-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->end_controls_section();

    }

    public function style_controls()
    {
        return;
    }

    protected function render()
    { 
        $settings = $this->get_settings();
        extract( $settings );
        $layout_class = $layout == '2' ? 'portfolio_masonry_2' : '';
        $border_radius = $layout == '2' ? 'rounded-4' : 'rounded';
        ?>

        <div class="row g-4 justify-content-center masonry_grid <?php echo esc_attr($layout_class) ?>">
            <?php
            $args = [
                'post_type' => 'portfolio',
                'post_status' => 'publish',
            ];

            if (!empty($show_count)) {
                $args['posts_per_page'] = $show_count;
            }

            if (!empty($order)) {
                $args['order'] = $order;
            }

            if (!empty($orderby)) {
                $args['orderby'] = $orderby;
            }

            if (!empty($exclude)) {
                $args['post__not_in'] = $exclude;
            }

            if (!empty($cats && $cats != '')) {
                $args['tax_query'] = [
                    [
                        'taxonomy'  => 'portfolio_cat',
                        'field'     => 'slug',
                        'terms'     => $cats,
                    ]
                ];
            }

            $portfolios = new \WP_Query($args);

            if (!empty($settings['grid_metro_layout3'])) {
                $metro_layout = [];
                foreach ($settings['grid_metro_layout3'] as $key => $value) {
                    $metro_layout[] = $value['size'];
                }
            } else {
                $metro_layout = array(
                    'col-lg-8 col-md-12',
                    'col-lg-4 col-md-6',
                    'col-lg-4 col-md-6',
                    'col-lg-4 col-md-6',
                    'col-lg-4 col-md-6',
                );
            }
            if (count($metro_layout) < 1) {
                return;
            }

            $metro_layout_count = count($metro_layout);
            $metro_item_count = 0;
            $count = $portfolios->post_count;
            while ($portfolios->have_posts()) : $portfolios->the_post();
                $cats = get_the_terms(get_the_ID(), 'portfolio_cat');
                $size   = $metro_layout[$metro_item_count];
                $ratio  = explode(' ', $size);
                $column_class = $ratio ? $ratio[0] : $ratio[1];
                
                
            ?>
                <div class="<?php echo esc_attr( $column_class )?> grid_item">
                    <div class="sc-portfolio-card position-relative overflow-hidden active <?php echo esc_attr($border_radius) ?>">
                        <?php the_post_thumbnail($ratio[0]) ?>
                        <div class="pf-content-box bg-white p-4 <?php echo esc_attr($border_radius) ?>">
                            <?php 
                            if( $cats ){
                                echo '<a href="javascript:void(0)" class="cat_wrap d-inline-block badge bg-primary-soft ">'. Quiety_Core_Helper()->get_first_category('portfolio_cat') .'</a>';
                            }
                            ?>                            
                            <a href="<?php the_permalink() ?>" class="portfolio_title">
                                <h5 class="mb-0 mt-3 sc-heading-color"><?php echo wp_trim_words(get_the_title(), 3, '') ?></h5>
                            </a>
                        </div>
                    </div>
                </div>
                
                <?php
                $metro_item_count++;
            endwhile;
            wp_reset_postdata();
            ?>

        </div>

<?php }
}
