<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Group_Control_Background,
	Group_Control_Box_Shadow,
	Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Group_Control_Border,
    Repeater, 
	WP_Query};

class quiety_portfolio_slider extends Widget_Base {

	public function get_name() {
		return 'quiety_portfolio_slider';
	}

	public function get_title() {
		return __( 'Quiety Portfolio Slider', 'quiety-core');
	}

	public function get_icon() {
		return 'eicon-slideshow';
	}

	public function get_categories() {
		return [ 'quiety_elements' ];
	}

	protected function register_controls() {
		$this-> content_controls();
		$this-> style_controls();
	}

	public function content_controls() {
		$this->start_controls_section(
			'portfolio_content', 
			[
				'label' => esc_html__('Portfolio Content', 'quiety-core'), 
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'button_text', 
			[
				'label' => esc_html__( 'Button Text', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Explore More', 'quiety-core' ),
			]
			
		);


		$this->end_controls_section();

		//===================== Slider Control ======================//
		$this->start_controls_section('sec_slider_control', [
			'label' => esc_html__('Slider Control', 'quiety-core')
		]);

		$this->add_control('loop', [
			'label'        => esc_html__('Loop', 'quiety-core'),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__('On', 'quiety-core'),
			'label_off'    => esc_html__('Off', 'quiety-core'),
			'return_value' => 'yes',
			'default'      => 'yes'
		]);

		$this->add_control('speed', [
			'label'   => __('Speed', 'quiety-core'),
			'type'    => Controls_Manager::NUMBER,
			'default' => 700,
		]);

		$this->add_control('autoplay', [
			'label'        => esc_html__('Autoplay', 'quiety-core'),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__('On', 'quiety-core'),
			'label_off'    => esc_html__('Off', 'quiety-core'),
			'return_value' => 'yes',
			'default'      => 'yes'
		]);

		$this->add_control('autoplay_time', [
			'label'   => __('Autoplay Time', 'quiety-core'),
			'type'    => Controls_Manager::NUMBER,
			'default' => 3000,
			'condition' => [
				'autoplay' => 'yes'
			]
		]);

		$this->add_control(
			'show_items_desktop',
			[
				'label'     => esc_html__('Display Items [Desktop]', 'quiety-core'),
				'type'      => Controls_Manager::NUMBER,

			]
		);
		$this->add_control(
			'show_items_tablet',
			[
				'label'     => esc_html__('Display Items [Tablet]', 'quiety-core'),
				'type'      => Controls_Manager::NUMBER,

			]
		);
		$this->add_control(
			'show_items_mobile',
			[
				'label'     => esc_html__('Display Items [Mobile]', 'quiety-core'),
				'type'      => Controls_Manager::NUMBER,
				'default'	=> 1
			]
		);
		$this->add_control(
			'item_space',
			[
				'label' => __('Item Space', 'quiety-core'),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
						'step' => 1,
					]
				],
				'default' => [
					'size' => 24,
				]
			]
		);

		$this->end_controls_section();
	}

	public function style_controls() {
		return;
	}

	protected function render() { 
		
		$settings = $this->get_settings_for_display();
		extract($settings);

		
		
		?>
		

		<div class="dg-portfolio-slider pt-5 swiper overflow-hidden"
			<?php 
			echo quiety_swiper_attrebutes( 
				$show_items_desktop, 
				$loop, 
				$autoplay, 
				$autoplay_time, 
				$speed, 
				$item_space['size'], 
				$show_items_tablet, 
				$show_items_mobile,
				'bullets',
				'.dg-portfolio-slider-control'						
			) ?> >
			<div class="swiper-wrapper">

				<?php $args = array(
					'post_type'     => 'portfolio',
					'post_per_page' => -1,
				);
				
				$loop = new \WP_Query($args);

				

				while ( $loop->have_posts() ) {
					$loop->the_post(); ?>

					<div class="swiper-slide dg-portfolio-single bg-white rounded">
						<div class="thunbmanil overflow-hidden rounded-top mb-4">
							<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail(); ?></a>
						</div>
						<div class="dg-portfolio-item-content">
							<?php $terms = get_the_terms(get_the_ID(), 'portfolio_cat'); 

								if(!empty($terms)) {
									foreach($terms as $term) { ?>
										<a href="<?php echo get_term_link($term->term_id, 'portfolio_cat'); ?>" class="d-inline-block text-dark badge bg-warning-soft"><?php echo $term->name; ?></a>
									<?php }
								}
							?>

							
							<a href="<?php the_permalink(); ?>">
								<h5 class="mt-3 mb-4"><?php the_title(); ?></h5>
							</a>
							<a href="<?php the_permalink(); ?>" class="read-more-link text-decoration-none"><?php echo esc_html($settings['button_text']); ?> <i class="fas fa-arrow-right ms-2"></i></a>
						</div>
					</div>
				
				<?php }

					wp_reset_postdata();
				?>

				


			</div>
			<div class="dg-portfolio-slider-control dg-slider-control mt-40 text-center"></div>
		</div>

	<?php }

}