<?php


namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Controls_Manager,
	Group_Control_Background,
	Group_Control_Box_Shadow,
	Widget_Base,
	Group_Control_Typography,
	Repeater,
	Utils
};

class quiety_pricing_title extends Widget_Base {
    public function get_name() {
        return 'quiety-pricing-title';
    }

    public function get_title() {
        return esc_html__('Quiety Pricing Title', 'quiety-core');
    }

    public function get_icon() {
        return 'eicon-price-list';
    }

    public function get_categories() {
        return ['tt-elements'];
    }

    protected function  register_controls() {
        $this->register_content_controls();
        $this->register_style_controls();
    }

    public function register_content_controls() {
        $this->start_controls_section(
			'quiety_pricing_title',
			[
				'label'  => __('Title', 'quiety-core'),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]		
		); 

        $this->add_control(
			'pricing_amount',
			[
				'label' => esc_html__( 'Pricing Amount', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( '12', 'quiety-core' ),
			]
		);

        $this->add_control(
			'pricing_currency',
			[
				'label' => esc_html__( 'Pricing Currency', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( '$', 'quiety-core' ),
			]
		);

        $this->add_control(
			'pricing_duration',
			[
				'label' => esc_html__( 'Pricing Duration', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'month', 'quiety-core' ),
			]
		);


        $this->end_controls_section();
    }
    
    public function register_style_controls() {
        $this->start_controls_section(
			'title_style', 
			[
				'label'  => __('Title Style', 'quiety-core'),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

        $this->add_control(
			'text_align',
			[
				'label' => esc_html__( 'Alignment', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'quiety-core' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'quiety-core' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'quiety-core' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'toggle' => true,
				'selectors' => [
					'{{WRAPPER}} .hd-pricing-title' => 'text-align: {{VALUE}};',
				],
			]
		);

        $this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hd-pricing-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .hd-pricing-title sup' => 'color: {{VALUE}}',
					'{{WRAPPER}} .hd-pricing-title span' => 'color: {{VALUE}}',
				],
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'currency_typography',
                'label' => 'Currency Typography',
				'selector' => '{{WRAPPER}} .hd-pricing-title sup',
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
                'label' => 'Title Typography',
				'selector' => '{{WRAPPER}} .hd-pricing-title',
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'meta_typography',
                'label' => 'Meta Typography',
				'selector' => '{{WRAPPER}} .hd-pricing-title span',
			]
		);

        $this->end_controls_section();
    }

    protected function render() {

        $settings = $this->get_settings_for_display(); ?>

        <h2 class="hd-pricing-title"><sup><?php echo $settings['pricing_currency'];  ?></sup><?php echo $settings['pricing_amount']; ?><span>/<?php echo $settings['pricing_duration']; ?></span></h2>


    <?php }
}