<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Controls_Manager,
	Widget_Base,
	Group_Control_Typography,
	Repeater,
	Utils
};

class Quiety_Tab2 extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * @since 1.0.0
	 */
	public function get_name() {
		return 'quiety_tab2';
	}

	/**
	 * Get widget title.
	 *
	 * @since 1.0.0
	 */
	public function get_title() {
		return __( 'Quiety Tab2', 'quiety-core' );
	}

	/**
	 * Get widget icon.
	 *
	 * @since 1.0.0
	 */
	public function get_icon() {
		return 'eicon-tabs';
	}

	/**
	 * Get widget categories.
	 *
	 * @since 1.0.0
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	/**
	 * Get widget keywords.
	 *
	 * Retrieve the list of keywords the widget belongs to.
	 *
	 * @since 1.0.0
	 */
	public function get_keywords() {
		return [ 'Tab', 'quiety member' ];
	}

	/**
	 * Register widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		//============================================
		// START TEAME CONTENT
		//============================================
		$this->start_controls_section( 'tab_content', [
			'label' => __( 'Tab', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_CONTENT,
		] );

		$this->add_control( 'layout', [
			'label'   => __( 'Layout', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => 'layout-1',
			'options' => [
				'layout-1'     => __( 'Layout One', 'quiety-core' ),
				'layout-2'     => __( 'Layout Two', 'quiety-core' ),
			],
		] );
        $this->end_controls_section();

        // Repeater start -------------------------------
        $this->start_controls_section(
			'tab_section',
			[
				'label' => esc_html__( 'Tab Content', 'quiety-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => [
					'layout' => 'layout-1'
				],
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'tab_title',
			[
				'label' => esc_html__( 'Tab Title', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'List Title' , 'quiety-core' ),
				'label_block' => true,
			]
		);
        $repeater->add_control(
			'tab_image',
			[
				'label' => esc_html__( 'Tab Image', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'tab_item',
			[
				'label' => esc_html__( 'Tab Item', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'tab_title' => esc_html__( 'Home', 'quiety-core' ),
					],
				],
				'title_field' => '{{{ tab_title }}}',
			]
		);
		$this->end_controls_section();
        //Repeater end -----------------------------------

		//Repeater for 2 start-------------------------------------------
		$this->start_controls_section(
			'tab2_section',
			[
				'label' => esc_html__( 'Content', 'quiety-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => [
					'layout' => 'layout-2'
				],
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'list_title',
			[
				'label' => esc_html__( 'Tab Title', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'List Title' , 'quiety-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'author_image',
			[
				'label' => esc_html__( 'Author Image', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);
		$repeater->add_control(
			'author_name',
			[
				'label' => esc_html__( 'Author Name', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Default title', 'quiety-core' ),
				'placeholder' => esc_html__( 'Type your title here', 'quiety-core' ),
			]
		);
		$repeater->add_control(
			'author_designation',
			[
				'label' => esc_html__( 'Author Designation', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Default title', 'quiety-core' ),
				'placeholder' => esc_html__( 'Type your title here', 'quiety-core' ),
			]
		);
		$repeater->add_control(
			'tab_work_title',
			[
				'label' => esc_html__( 'Work Time', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Open to work', 'quiety-core' ),
				'placeholder' => esc_html__( 'Type your title here', 'quiety-core' ),
			]
		);
		$repeater->add_control(
			'tab_location',
			[
				'label' => esc_html__( 'Location', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Dhaka', 'quiety-core' ),
				'placeholder' => esc_html__( 'Type your title here', 'quiety-core' ),
			]
		);
		$repeater->add_control(
            'list_items', [
                'label' => esc_html__( 'Tags List', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => esc_html__('Website', 'quiety-core'),
            ]
        );
		$repeater->add_control(
			'tab_btn',
			[
				'label' => esc_html__( 'Button', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'View Profile', 'quiety-core' ),
				'placeholder' => esc_html__( 'Type your title here', 'quiety-core' ),
			]
		);
		$repeater->add_control(
			'tab_btn_url',
			[
				'label' => esc_html__( 'Button URL', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'options' => [ 'url', 'is_external', 'nofollow' ],
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
					// 'custom_attributes' => '',
				],
				'label_block' => true,
			]
		);
		$this->add_control(
			'tab2_item',
			[
				'label' => esc_html__( 'Repeater List', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'author_name' => esc_html__( 'Oliver Harry', 'quiety-core' ),
						'author_designation' => esc_html__( 'Sr. executive', 'quiety-core' ),
					],
				],
				'title_field' => '{{{ author_name }}}',
			]
		);
		$this->end_controls_section();

		//Repeater for 2 end-------------------------------------------

        //Styel added Start-----------------------------
        $this->start_controls_section(
			'title_style_section',
			[
				'label' => esc_html__( 'Title Style', 'quiety-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'tabtitle_color',
			[
				'label' => esc_html__( 'Title Color', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .nav-pills_ .title_style__' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'tabtitle_typography',
				'selector' => '{{WRAPPER}} .nav-pills_ .title_style__',
			]
		);
		$this->end_controls_section();
        //Styel added End-----------------------------

	}


	protected function render() {
		$settings = $this->get_settings_for_display();
		$layout = $settings['layout'];
        extract($settings);

		require __DIR__ . '/templates/tab/'. $layout . '.php';
	}

}