<?php

namespace Quiety\Widgets;

if (!defined('ABSPATH')) {
    exit;
}

use Elementor\{
    Group_Control_Background,
    Group_Control_Box_Shadow,
    Widget_Base,
    Controls_Manager,
    Group_Control_Typography,
    Group_Control_Border,
    Repeater
};


class quiety_tab_content extends Widget_Base
{

    public function get_name()
    {
        return 'quiety_tab_content';
    }

    public function get_title()
    {
        return __('Quiety Tab Content', 'quiety-core');
    }

    public function get_icon()
    {
        return 'eicon-tabs';
    }

    public function get_categories()
    {
        return ['quiety-elements'];
    }


    /**
     * Name: register_controls
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function register_controls()
    {
        $this->quiety_elementor_content_control();
        $this->quiety_elementor_style_control();
    }

    /**
     * Name: quiety_elementor_content_control
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function quiety_elementor_content_control()
    {

        $this->start_controls_section('section_tab_content', [
            'label' => __('Content', 'quiety-core'),
        ]);

        $repeater = new Repeater();

        $repeater->add_control('tab_title', [
            'label'       => __('Title', 'quiety-core'),
            'type'        => Controls_Manager::TEXT,
            'default'     => __('List Title', 'quiety-core'),
            'label_block' => true,
        ]);

        $repeater->add_control('tab_content', [
            'label'      => __('Content', 'quiety-core'),
            'type'       => Controls_Manager::WYSIWYG,
            'default'    => __('List Content', 'quiety-core'),
            'show_label' => false,
        ]);

        $repeater->add_control(
            'show_icon',
            [
                'label' => __('Show Icon', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'your-plugin'),
                'label_off' => __('Hide', 'your-plugin'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $repeater->add_control('tab_icon', [
            'label'     => __('Icon', 'quiety-core'),
            'type'      => Controls_Manager::ICONS,
            'default'   => [
                'value'   => 'fas fa-star',
                'library' => 'solid',
            ],
            'condition' => ['show_icon' => 'yes']
        ]);


        $this->add_control('tt_tabs', [
            'label'       => __('Tab List', 'quiety-core'),
            'type'        => Controls_Manager::REPEATER,
            'fields'      => $repeater->get_controls(),
            'default'     => [
                [
                    'tab_title'   => __('Is SEO a risky and time consuming proposition?', 'quiety-core'),
                    'tab_content' => __('There are many variations of passages of Lorem Ipsum available but the majority suffered is alteration in that  words which don\'t look even slightly believable. If you are Lorem Ipsum you need to be sure there isn\'t anything ready too much embarrassing.', 'quiety-core'),
                ],
                [
                    'tab_title'   => __('How to choose a perfect digital marketing plan?', 'quiety-core'),
                    'tab_content' => __('There are many variations of passages of Lorem Ipsum available but the majority suffered is alteration in that  words which don\'t look even slightly believable. If you are Lorem Ipsum you need to be sure there isn\'t anything ready too much embarrassing.', 'quiety-core'),
                ],
                [
                    'tab_title'   => __('Is it feasible to go for a complete website audit?', 'quiety-core'),
                    'tab_content' => __('There are many variations of passages of Lorem Ipsum available but the majority suffered is alteration in that  words which don\'t look even slightly believable. If you are Lorem Ipsum you need to be sure there isn\'t anything ready too much embarrassing.', 'quiety-core'),
                ],
                [
                    'tab_title'   => __('How to go about with a bespoke SMO strategy?', 'quiety-core'),
                    'tab_content' => __('There are many variations of passages of Lorem Ipsum available but the majority suffered is alteration in that  words which don\'t look even slightly believable. If you are Lorem Ipsum you need to be sure there isn\'t anything ready too much embarrassing.', 'quiety-core'),
                ],
                [
                    'tab_title'   => __('Is internet marketing expensive?', 'quiety-core'),
                    'tab_content' => __('There are many variations of passages of Lorem Ipsum available but the majority suffered is alteration in that  words which don\'t look even slightly believable. If you are Lorem Ipsum you need to be sure there isn\'t anything ready too much embarrassing.', 'quiety-core'),
                ],
            ],
            'title_field' => '{{{ tab_title }}}',
        ]);

        $this->end_controls_section();
    }


    /**
     * Name: quiety_elementor_style_control
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function quiety_elementor_style_control()
    {
    }


    /**
     * Name: render
     * Desc: Widgets Render
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        extract($settings);
        $unique_id = $this->get_id();
?>


        <div class="faq_tag_wraper d-flex ">
            <div class="nav flex-column nav-pills me-5" id="v-pills-tab" role="tablist" aria-orientation="vertical">
                <?php
                if (!empty($tt_tabs)) {
                    foreach ($tt_tabs as $key => $tab) {
                        $active = $key == 0 ? 'active' : '';
                        $svg = '<svg class="arrow_right_ me-2" width="26" height="18" viewBox="0 0 26 18" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M15.0135 17.5157C14.6906 17.1928 14.5356 16.8027 14.5485 16.3453C14.5614 15.8879 14.7299 15.4978 15.0538 15.1749L19.6144 10.6143H1.61436C1.15696 10.6143 0.773279 10.4594 0.463324 10.1494C0.153369 9.83946 -0.00107065 9.45632 5.58597e-06 9C5.58597e-06 8.5426 0.154983 8.15892 0.464938 7.84897C0.774894 7.53901 1.15803 7.38457 1.61436 7.38565H19.6144L15.0135 2.78475C14.6906 2.46188 14.5292 2.07821 14.5292 1.63372C14.5292 1.18924 14.6906 0.806098 15.0135 0.484304C15.3363 0.161435 15.72 0 16.1645 0C16.609 0 16.9921 0.161435 17.3139 0.484304L24.6996 7.86996C24.861 8.03139 24.9756 8.20628 25.0434 8.39462C25.1112 8.58296 25.1446 8.78475 25.1435 9C25.1435 9.21525 25.1096 9.41704 25.0418 9.60538C24.974 9.79372 24.8599 9.96861 24.6996 10.13L17.2735 17.5561C16.9776 17.852 16.6079 18 16.1645 18C15.7211 18 15.3374 17.8386 15.0135 17.5157Z" fill="black"/></svg>';
                        echo '<button class="tab_title ' . esc_attr($active) . '" id="v-pills-home-tab" data-bs-toggle="pill" data-bs-target="#tab_' . esc_attr($unique_id) . '_' . $key . '" type="button" role="tab" aria-controls="v-pills-home" aria-selected="true"><span>' . $svg . esc_html($tab['tab_title']) . '</span></button>';
                    }
                }
                ?>
            </div>
            <div class="tab-content" id="v-pills-tabContent">
                <?php
                if (!empty($tt_tabs)) {
                    foreach ($tt_tabs as $key => $tab) {
                        $active_show = $key == 0 ? 'show active' : '';
                        echo '<div class="tab-pane fade ' . esc_attr($active_show) . '" id="tab_' . esc_attr($unique_id) . '_' . $key . '" role="tabpanel" aria-labelledby="v-pills-home-tab">' . wp_kses_post($tab['tab_content']) . '</div>';
                    }
                }
                ?>
            </div>
        </div>


<?php
    }
}
