<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Group_Control_Background,
	Group_Control_Box_Shadow,
	Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Group_Control_Border, 
    Repeater};


class quiety_table_features extends Widget_Base {

	public function get_name() {
		return 'quiety_table_features';
	}

	public function get_title() {
		return __( 'Quiety Table Features', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-download-button';
	}

	public function get_categories() {
		return [ 'quiety-elements' ];
	}


    /**
     * Name: register_controls
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function register_controls() {
        $this-> quiety_elementor_content_control();
        $this-> quiety_elementor_style_control();
    }

    /**
     * Name: quiety_elementor_content_control
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function quiety_elementor_content_control() {
        
        //====================== Table Features ======================//
        $this->start_controls_section( 'table_features_sec', [
            'label' => __( 'Table Features', 'quiety-core' ),
        ]);

        $this->add_control( 'tab_title', [
            'label'       => __( 'Title', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'	  => __('Web Hosting Features', 'quiety-core')
        ] );

	    $this->add_control(
		    'is_collapse', [
			    'label' => esc_html__( 'Collapse Show/Hide', 'quiety-core' ),
			    'type' => \Elementor\Controls_Manager::SWITCHER,
			    'label_on' => esc_html__( 'Show', 'quiety-core' ),
			    'label_off' => esc_html__( 'Hide', 'quiety-core' ),
			    'return_value' => 'yes',
			    'default' => 'no',
			    'separator' => 'after'
		    ]
	    );

	    //=== Table Item Repeater 02
	    $table2 = new Repeater();
	    $table2->add_control( 'feature_title', [
		    'label'       => __( 'Title', 'quiety-core' ),
		    'type'        => Controls_Manager::TEXT,
		    'default'	  => __('Disk Space', 'quiety-core')
	    ] );

	    // Content 01
	    $table2->add_control(
		    'content1_style', [
			    'label' => esc_html__( 'Content 01 Style', 'plugin-name' ),
			    'type' => \Elementor\Controls_Manager::SELECT,
			    'default' => 'text',
			    'options' => [
				    'text'  => esc_html__( 'Text', 'plugin-name' ),
				    'icon' => esc_html__( 'Icon', 'plugin-name' ),
			    ],
			    'separator' => 'before'
		    ]
	    );

	    $table2->add_control( 'feature_content1', [
		    'label'       => __( 'Content', 'quiety-core' ),
		    'type'        => Controls_Manager::TEXT,
		    'default'	  => __('30GB', 'quiety-core'),
		    'condition'   => [
			    'content1_style' => 'text'
		    ],
	    ] );

	    $table2->add_control( 'feature_icon1', [
		    'label'   => __( 'Icon', 'quiety-core' ),
		    'type'    => Controls_Manager::ICONS,
		    'default' => [
			    'value'   => 'fas fa-check',
			    'library' => 'solid',
		    ],
		    'condition'   => [
			    'content1_style' => 'icon'
		    ]
	    ] );

	    // Content 02
	    $table2->add_control(
		    'content2_style', [
			    'label' => esc_html__( 'Content 02 Style', 'plugin-name' ),
			    'type' => \Elementor\Controls_Manager::SELECT,
			    'default' => 'text',
			    'options' => [
				    'text'  => esc_html__( 'Text', 'plugin-name' ),
				    'icon' => esc_html__( 'Icon', 'plugin-name' ),
			    ],
			    'separator' => 'before'
		    ]
	    );

	    $table2->add_control( 'feature_content2', [
		    'label'       => __( 'Content', 'quiety-core' ),
		    'type'        => Controls_Manager::TEXT,
		    'default'	  => __('90GB', 'quiety-core'),
		    'condition'   => [
			    'content2_style' => 'text'
		    ],
	    ] );

	    $table2->add_control( 'feature_icon2', [
		    'label'   => __( 'Icon', 'quiety-core' ),
		    'type'    => Controls_Manager::ICONS,
		    'default' => [
			    'value'   => 'fas fa-check',
			    'library' => 'solid',
		    ],
		    'condition'   => [
			    'content2_style' => 'icon'
		    ]
	    ] );

	    // Content 03
	    $table2->add_control(
		    'content3_style', [
			    'label' => esc_html__( 'Content 03 Style', 'plugin-name' ),
			    'type' => \Elementor\Controls_Manager::SELECT,
			    'default' => 'text',
			    'options' => [
				    'text'  => esc_html__( 'Text', 'plugin-name' ),
				    'icon' => esc_html__( 'Icon', 'plugin-name' ),
			    ],
			    'separator' => 'before'
		    ]
	    );

	    $table2->add_control( 'feature_content3', [
		    'label'       => __( '150GB', 'quiety-core' ),
		    'type'        => Controls_Manager::TEXT,
		    'default'	  => __('30GB', 'quiety-core'),
		    'condition'   => [
			    'content3_style' => 'text'
		    ],
	    ] );

	    $table2->add_control( 'feature_icon3', [
		    'label'   => __( 'Icon', 'quiety-core' ),
		    'type'    => Controls_Manager::ICONS,
		    'default' => [
			    'value'   => 'fas fa-check',
			    'library' => 'solid',
		    ],
		    'condition'   => [
			    'content3_style' => 'icon'
		    ]
	    ] );

	    // Content 04
	    $table2->add_control(
		    'content4_style', [
			    'label' => esc_html__( 'Content 04 Style', 'plugin-name' ),
			    'type' => \Elementor\Controls_Manager::SELECT,
			    'default' => 'text',
			    'options' => [
				    'text'  => esc_html__( 'Text', 'plugin-name' ),
				    'icon' => esc_html__( 'Icon', 'plugin-name' ),
			    ],
			    'separator' => 'before'
		    ]
	    );

	    $table2->add_control( 'feature_content4', [
		    'label'       => __( '150GB', 'quiety-core' ),
		    'type'        => Controls_Manager::TEXT,
		    'default'	  => __('30GB', 'quiety-core'),
		    'condition'   => [
			    'content4_style' => 'text'
		    ],
	    ] );

	    $table2->add_control( 'feature_icon4', [
		    'label'   => __( 'Icon', 'quiety-core' ),
		    'type'    => Controls_Manager::ICONS,
		    'default' => [
			    'value'   => 'fas fa-check',
			    'library' => 'solid',
		    ],
		    'condition'   => [
			    'content4_style' => 'icon'
		    ]
	    ] );

	    $this->add_control( 'table_features2', [
		    'label'       => __( 'Add Features Content', 'quiety-core' ),
		    'type'        => \Elementor\Controls_Manager::REPEATER,
		    'fields'      => $table2->get_controls(),
		    'title_field' => '{{{ feature_title }}}',
	    ] );

        $this->end_controls_section(); // Table Features
    }


    /**
     * Name: quiety_elementor_style_control
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function quiety_elementor_style_control() {

        //===================== Table Title =====================//
        $this->start_controls_section( 'style_tab_title', [
            'label' => __( 'Tab Title', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_control( 'tab_title_color', [
            'label'     => __( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .accordion-button' => 'color: {{VALUE}};',
            ],
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'     => 'tab_title_typo',
            'label'    => __( 'Typography', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .accordion-button',
        ] );

        $this->end_controls_section(); //End Table Tab Title


        //===================== Table Features Content =====================//
        $this->start_controls_section( 'style_table_features', [
            'label' => __( 'Table Features', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_control( 'feature_content_color', [
            'label'     => __( 'Text Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .rs-info-table td' => 'color: {{VALUE}};',
                '{{WRAPPER}} .cd-table td' => 'color: {{VALUE}};',
            ],
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'     => 'feature_content_typo',
            'selector' => '
                {{WRAPPER}} .rs-info-table td,
                {{WRAPPER}} .cd-table td
            ',
        ] );

        $this->end_controls_section(); //End Table Features Content


        //===================== Table Features Content =====================//
        $this->start_controls_section( 'style_bg_sec', [
            'label' => __( 'Background', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_control( 'box_bg_color', [
            'label'     => __( 'Box Background Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .rs-table .accordion-item .accordion-header a' => 'background-color: {{VALUE}};',
            ],
        ] );

        $this->end_controls_section(); //End Table Features Content

    }

    /**
     * Name: render
     * Desc: Widgets Render
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
	protected function render() {
		$settings = $this->get_settings_for_display();
		extract( $settings );
        $unique_Id = wp_unique_id('quiety-');

		$is_collapse = $settings['is_collapse']; ?>



<div class="crm_pricing_feature_accordion accordion bg-white" id="crm_pricing_accordion-<?php echo esc_attr($unique_Id) ?>">
	<div class="accordion-item border-0">
		<?php if ( !empty($settings['tab_title'])) : ?>
            <div class="accordion-header">
                <a href="#<?php echo esc_attr($unique_Id) ?>" data-bs-toggle="collapse" aria-expanded="false" class="collapsed">
                    <?php echo esc_html($settings['tab_title']) ?>
                </a>
            </div>
		<?php endif; ?>
		<div class="accordion-collapse <?php echo esc_attr($is_collapse == 'yes' ? 'collapse show' : 'collapse' ) ?> " id="<?php echo esc_attr($unique_Id) ?>" data-bs-parent="#crm_pricing_accordion-<?php echo esc_attr($unique_Id) ?>">
			<div class="accordion-body p-0">
				<div class="crm_pricing_feature_table table-responsive">
					<table class="table border-0">
						<tbody>
						<?php
						if ( !empty($table_features2) ) {
							foreach ( $table_features2 as $table ) {
								?>
                                <tr>
									<?php
									if ( !empty($table['feature_title']) ) {
										echo '<td class="crm_pricing_features_name fw-semibold">'.esc_html($table['feature_title']).'</td>';
									}

									//Content 01
									if ( !empty($table['feature_content1'] ) && $table['content1_style'] == 'text' )  {
										echo '<td class="crm_pricing_feature_check text-center">'.quiety_kses_post($table['feature_content1']).'</td>';
									}
									if ( !empty($table['feature_icon1']['value']) && $table['content1_style']== 'icon' ) { ?>
                                        <td class="crm_pricing_feature_check text-center">
											<?php \Elementor\Icons_Manager::render_icon( $table['feature_icon1'] ) ?>
                                        </td>
										<?php
									}

									//Content 02
									if ( !empty($table['feature_content2'] ) && $table['content2_style'] == 'text' ) {
										echo '<td class="crm_pricing_feature_check text-center">'.quiety_kses_post($table['feature_content2']).'</td>';
									}
									if ( !empty($table['feature_icon2']['value'] ) && $table['content2_style'] == 'icon' ) { ?>
                                        <td class="crm_pricing_feature_check text-center">
											<?php \Elementor\Icons_Manager::render_icon( $table['feature_icon2'] ) ?>
                                        </td>
										<?php
									}

									//Content 03
									if ( !empty($table['feature_content3'] ) && $table['content3_style'] == 'text' ) {
										echo '<td class="crm_pricing_feature_check text-center">'.quiety_kses_post($table['feature_content3']).'</td>';
									}
									if ( !empty($table['feature_icon3']['value'] ) && $table['content3_style'] == 'icon' ) { ?>
                                        <td class="crm_pricing_feature_check text-center">
											<?php \Elementor\Icons_Manager::render_icon( $table['feature_icon3'] ) ?>
                                        </td>
										<?php
									}

									//Content 04
									if ( !empty($table['feature_content4'] ) && $table['content4_style'] == 'text'  ) {
										echo '<td class="crm_pricing_feature_check text-center">'.quiety_kses_post($table['feature_content4']).'</td>';
									}
									
									if ( !empty($table['feature_icon4']['value'] ) && $table['content4_style'] == 'icon' ) { ?>
                                        <td class="crm_pricing_feature_check text-center">
											<?php \Elementor\Icons_Manager::render_icon( $table['feature_icon4'] ) ?>
                                        </td>
										<?php
									}
									?>
                                </tr>
								<?php
							}
						}
						?>
						</tbody>
                    </table>
				</div>
			</div>
		</div>
	</div>
</div>

	<?php }
}