<?php

namespace Quiety\Widgets;

if (!defined('ABSPATH')) {
    exit;
}

use Elementor\{
    Group_Control_Background,
    Group_Control_Box_Shadow,
    Widget_Base,
    Controls_Manager,
    Group_Control_Typography,
    Group_Control_Border,
    Repeater
};


class quiety_table_title extends Widget_Base
{

    public function get_name()
    {
        return 'quiety_table_title';
    }

    public function get_title()
    {
        return __('Quiety Table Title', 'quiety-core');
    }

    public function get_icon()
    {
        return 'eicon-table';
    }

    public function get_categories()
    {
        return ['quiety-elements'];
    }


    /**
     * Name: register_controls
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function register_controls()
    {
        $this->quiety_elementor_content_control();
        $this->quiety_elementor_style_control();
    }

    /**
     * Name: quiety_elementor_content_control
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function quiety_elementor_content_control()
    {

        //====================== Table Title  ======================//
        $this->start_controls_section('table_title_sec', [
            'label' => __('Table Title', 'quiety-core'),
        ]);

        $this->add_control('features_title', [
            'label'       => __('Features Title', 'quiety-core'),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'      => __('All Plan Features', 'quiety-core')
        ]);

        $this->add_control('features_discount', [
            'label'       => __('Features Discount', 'quiety-core'),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'      => __('Get 30% Off', 'quiety-core'),
        ]);

        $this->add_control(
            'pricing_switcher_switch',
            [
                'label' => esc_html__('Show Pricing Switcher', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'quiety-core'),
                'label_off' => esc_html__('Hide', 'quiety-core'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control('tab_title_01', [
            'label'       => __('Tab Title 01', 'quiety-core'),
            'type'        => Controls_Manager::TEXT,
            'default'      => __('Monthly', 'quiety-core'),
            'condition' => [
                'pricing_switcher_switch' => 'yes'
            ]
        ]);

        $this->add_control('tab_title_02', [
            'label'       => __('Tab Title 02', 'quiety-core'),
            'type'        => Controls_Manager::TEXT,
            'default'      => __('Yearly', 'quiety-core'),
            'condition' => [
                'pricing_switcher_switch' => 'yes'
            ]
        ]);

        $this->add_control('shape', [
            'label'       => __('Shape Image', 'quiety-core'),
            'type'        => Controls_Manager::MEDIA,
        ]);

        $this->end_controls_section(); //Table Title


        //====================== Table Contents ======================//
        $this->start_controls_section('table_contents_sec', [
            'label' => __('Table Contents', 'quiety-core'),
        ]);


        //============= Table Title 01
        $table2 = new Repeater();
        $table2->add_control('title', [
            'label'       => __('Title', 'quiety-core'),
            'type'        => Controls_Manager::TEXT,
            'default'      => __('Standard', 'quiety-core')
        ]);

        $table2->add_control('price_monthly', [
            'label'       => __('Price Monthly', 'quiety-core'),
            'type'        => Controls_Manager::TEXT,
            'default'      => __('$12.50', 'quiety-core'),
        ]);
        
        $table2->add_control('price_yearly', [
            'label'       => __('Price Yearly', 'quiety-core'),
            'type'        => Controls_Manager::TEXT,
            'default'      => __('$99.99', 'quiety-core'),
        ]);

        $table2->add_control('duration', [
            'label'       => __('Duration', 'quiety-core'),
            'type'        => Controls_Manager::TEXT,
            'default'      => __('/user/month billed annually', 'quiety-core'),
        ]);

        $table2->add_control('btn_title', [
            'label'       => __('Button Title', 'quiety-core'),
            'type'        => Controls_Manager::TEXT,
            'default'      => __('Try For Free', 'quiety-core'),
            'separator'   => 'before'
        ]);

        $table2->add_control('btn_url', [
            'label'       => __('Button URL', 'quiety-core'),
            'type'        => Controls_Manager::URL,
            'default'      => [
                'url'     => '#'
            ]
        ]);

        $this->add_control('table_features2', [
            'label'       => __('Add Content', 'quiety-core'),
            'type'        => \Elementor\Controls_Manager::REPEATER,
            'fields'      => $table2->get_controls(),
            'title_field' => '{{{ title }}}',
        ]);

        $this->end_controls_section(); // Table Features Contents
    }


    /**
     * Name: quiety_elementor_style_control
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function quiety_elementor_style_control()
    {

        //===================== Table Title =====================//
        $this->start_controls_section('style_features_title', [
            'label' => __('Tab Title', 'quiety-core'),
            'tab'   => Controls_Manager::TAB_STYLE,
        ]);

        $this->add_control('features_title_color', [
            'label'     => __('Color', 'quiety-core'),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .title' => 'color: {{VALUE}};',
            ],
        ]);

        $this->add_group_control(Group_Control_Typography::get_type(), [
            'name'     => 'features_title_typo',
            'label'    => __('Typography', 'quiety-core'),
            'selector' => '{{WRAPPER}} .title',
        ]);

        $this->end_controls_section(); //End Table Tab Title

        //===================== Table Title =====================//
        $this->start_controls_section('style_table_features', [
            'label' => __('Table Features', 'quiety-core'),
            'tab'   => Controls_Manager::TAB_STYLE,
        ]);

        // Plan Title Options
        $this->add_control('item_title_color_opation', [
            'label'     => __('Title', 'quiety-core'),
            'type'      => Controls_Manager::HEADING,
        ]);

        $this->add_control('item_title_color', [
            'label'     => __('Text Color', 'quiety-core'),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .plan-title' => 'color: {{VALUE}};',
            ],
        ]);

        $this->add_group_control(Group_Control_Typography::get_type(), [
            'name'     => 'item_title_typo',
            'selector' => '{{WRAPPER}} .plan-title',
        ]);

        $this->end_controls_section();


        //===================== Button =====================//
        $this->start_controls_section('style_btn_sec', [
            'label' => __('Button', 'quiety-core'),
            'tab'   => Controls_Manager::TAB_STYLE,
        ]);

        $this->add_control('item_btn_normal_color', [
            'label'     => __('Text Color', 'quiety-core'),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .template-btn' => 'color: {{VALUE}};',
            ],
        ]);

        $this->add_control('item_btn_hover_color', [
            'label'     => __('Text Hover Color', 'quiety-core'),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .template-btn:hover' => 'color: {{VALUE}};',
            ],
        ]);

        $this->end_controls_section(); // End

    }


    /**
     * Name: render
     * Desc: Widgets Render
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        extract($settings); 
        $pricing_switch = $pricing_switcher_switch == 'yes' ? '' : 'no_pricing_switch';
        ?>


        <div class="crm-pricing-table table-responsive bg-white">
            <table class="table <?php echo esc_attr($pricing_switch) ?>">
                <tr>
                    <?php
                    if (!empty($settings['features_title'])) { ?>
                        <th class="crm-pricing-switch-wrapper position-relative">
                            <span class="title"><?php echo esc_html($settings['features_title']) ?></span>
                            <span class="crm-offer-badge"><?php echo esc_html($settings['features_discount']) ?></span>
                            <?php 
                            if($pricing_switcher_switch == 'yes' ){ ?>
                                <div class="crm-pricing-switch mt-3">
                                    <button class="crm-monthly"><?php echo esc_html($settings['tab_title_01']) ?></button>
                                    <span class="crm-switch">
                                        <input type="checkbox" class="crm-checkbox-switch" checked>
                                        <span class="crm-switch-dot"></span>
                                    </span>
                                    <button class="crm-yearly"><?php echo esc_html($settings['tab_title_02']) ?></button>
                                </div>
                                <?php 
                            }
                            echo wp_get_attachment_image($settings['shape']['id'], 'full', '', ['class' => 'arrow-shape']) ?>
                        </th>
                        <?php
                    }
                    if (!empty($table_features2)) {
                        foreach ($table_features2 as $table) {
                            if (!empty($table['title'])) { ?>
                                <th class="text-center crm-package-wrapper">
                                    <?php
                                    if (!empty($table['title'])) {
                                        echo '<span class="title-sm">' . esc_html($table['title']) . '</span>';
                                    }
                                    if (!empty($table['price_yearly'])) {
                                        echo '<span class="crm-package-price crm_yearly_price">' . esc_html($table['price_yearly']) . '</span>';
                                    }
                                    if (!empty($table['price_monthly'])) {
                                        echo '<span class="crm-package-price crm_monthly_price">' . esc_html($table['price_monthly']) . '</span>';
                                    }
                                    if (!empty($table['duration'])) {
                                        echo '<p class="mb-3 crm-package-subtitle">' . esc_html($table['duration']) . '</p>';
                                    }

                                    if (!empty($table['btn_title'])) { ?>
                                        <a href="<?php echo esc_url($table['btn_url']['url']) ?>" class="btn btn-sm crm-package-btn">
                                            <?php echo esc_html($table['btn_title']) ?>
                                        </a>
                                    <?php
                                    } ?>
                                </th>
                            <?php
                            }
                        }
                    }
                    ?>
                </tr>
            </table>
        </div>

    <?php 
    }
}
