<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Controls_Manager,
	Widget_Base,
	Group_Control_Typography,
	Repeater,
	Utils
};

class quiety_team_filter extends Widget_Base {
    
    public function get_name() {
        return 'quiety_team_filter';
    }

    public function get_title() {
        return __('Quiety Team Filter', 'quiety-core');
    }

    public function get_icon() {
        return 'eicon-person';
    }

    public function get_categories() {
		return [ 'tt-elements' ];
	}

    public function get_keywords() {
		return [ 'Team', 'quiety member', 'team filter' ];

	}

    protected function register_controls() {
        $this->content_controls();
        $this->content_styles();
    }

    public function content_controls() {
        $this->start_controls_section(
            'quiety-team-filter-nav', 
            [
                'label'  => __('Filter Menu', 'quiety-core'),
                'tab'    => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'filter-nav', 
            [
                'label'  => __('Filter Nav', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name' => 'nav_label',
						'label' => esc_html__( 'Label', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::TEXT,
						'default' => esc_html__( 'Founders' , 'quiety-core' ),
                        'label_block' => true,

                    ],
                    [
                        'name' => 'nav_id',
						'label' => esc_html__( 'Unique ID', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::TEXT,
						'default' => '',
                        'label_block' => true,
                        'description'  => __('Place an Id, example [developers]'),
                    ], 
                    [
                        'name' => 'nav_icon',
						'label' => esc_html__( 'Icon', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::ICONS,
                        'label_block' => true, 
                        'default' => [
                            'value' => 'fas fa-circle',
                            'library' => 'fa-solid',
                        ],
                    ], 
                    [
                        'name'  => 'active_btn',
                        'label' => esc_html__( 'Active Button?', 'quiety-core' ),
                        'type' => \Elementor\Controls_Manager::SWITCHER,
                        'return_value' => 'yes',
                        'default' => 'no',
                    ],
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'quiety-team-repeater', 
            [
                'label'  => __('Team Members', 'quiety-core'),
                'tab'    => Controls_Manager::TAB_CONTENT,
            ]
        );


        $this->add_control(
            'team-members', 
            [
                'label'  => __('Filter Nav', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name' => 'image',
						'label' => esc_html__( 'Image', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::MEDIA,
						'default' => [
                            'url' => \Elementor\Utils::get_placeholder_image_src(),
                        ]
                    ],
                    [
                        'name' => 'name',
						'label' => esc_html__( 'Name', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::TEXT,
                        'label_block' => true, 
						'default' => __('Forest Collman', 'quiety-core'),
                    ],
                    [
                        'name' => 'designation',
						'label' => esc_html__( 'Designation', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::TEXT,
                        'label_block' => true, 
						'default' => __('WordPress Developer', 'quiety-core'),
                    ],
                    [
                        'name' => 'designation_id',
						'label' => esc_html__( 'Designation ID', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::TEXT,
						'default' => '',
                        'description' => __('Place an ID. Example [wp-developers], this ID should be the same as Nav ID'),
                    ],
                    [
                        'name' => 'social_facebook',
						'label' => esc_html__( 'Facebook', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::ICONS,
                    ],
                    [
                        'name' => 'social_facebook_url',
						'label' => esc_html__( 'Facebook URL', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::TEXT,
                    ],
                    [
                        'name' => 'social_linkedin',
						'label' => esc_html__( 'Linkedin', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::ICONS,
                    ],
                    [
                        'name' => 'social_linkedin_url',
						'label' => esc_html__( 'Linkedin URL', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::TEXT,
                    ],
                    [
                        'name' => 'social_twitter',
						'label' => esc_html__( 'Twitter', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::ICONS,
                    ],
                    [
                        'name' => 'social_twitter_url',
						'label' => esc_html__( 'Twitter URL', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::TEXT,
                    ],
                    [
                        'name' => 'social_github',
						'label' => esc_html__( 'Github', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::ICONS,
                    ],
                    [
                        'name' => 'social_github_url',
						'label' => esc_html__( 'Github URL', 'quiety-core' ),
						'type' => \Elementor\Controls_Manager::TEXT,
                    ],
                    
                ]
            ]
        );


        
        $this->end_controls_section();
    }

    public function content_styles() {
        return;
    }

    protected function render() {
        $settings = $this->get_settings_for_display(); ?>

        <div class="sc-team-filter">
            <div class="text-center">
                <ul class="nav nav-tabs border-0 d-inline-flex sc-team-filter-nav rounded justify-content-center">


                <?php if($settings['filter-nav']) : 

                        foreach( $settings['filter-nav'] as $filter_nav ) { ?>
                            <li>
                                <a href="#<?php echo esc_attr( $filter_nav['nav_id'] ); ?>" data-bs-toggle="tab" class="<?php if( $filter_nav['active_btn'] == 'yes' ) : echo esc_attr('active'); endif; ?>">
                                    <span class="me-2">
                                        <?php \Elementor\Icons_Manager::render_icon( $filter_nav['nav_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                                    </span>
                                    <?php echo esc_html($filter_nav['nav_label']); ?>
                                </a>
                            </li>
                        <?php }
                
                
                endif; ?>


                </ul>
                <div class="tab-content mt-5">

                    <?php if( $settings['filter-nav'] ) : 
                        
                        foreach($settings['filter-nav'] as $filter_nav_item) { ?>
                            <div class="tab-pane fade <?php if($filter_nav_item['active_btn'] == 'yes') : echo esc_attr('active show'); endif; ?>" id="<?php echo esc_attr($filter_nav_item['nav_id']); ?>">
                                <div class="row g-4 justify-content-center">
                                    <?php if($settings['team-members']) :

                                        foreach( $settings['team-members'] as $team ) : 
                                            if ( $team['designation_id'] == $filter_nav_item['nav_id'] ) { ?>
                                                    


                                                <div class="col-xl-3 col-lg-4 col-sm-6">
                                                    <div class="sc-team-card bg-white rounded text-center rounded">
                                                        <div class="thumbnail d-inline-block position-relative z-1">
                                                            <?php echo wp_get_attachment_image($team['image']['id'], 'full', '', array( 'class' => 'img-fluid' )); ?>
                                                        </div>
                                                        <h5 class="mt-4 mb-2"><?php echo esc_html($team['name']); ?></h5>
                                                        <span class="d-inline-block mb-4 text-dg-color fs-sm"><?php echo esc_html($team['designation']); ?></span>
                                                        <div class="sc-team-social d-flex justify-content-center align-items-center flex-wrap">
                                                            <a href="<?php echo esc_url($team['social_facebook_url']); ?>"><?php \Elementor\Icons_Manager::render_icon( $team['social_facebook'], [ 'aria-hidden' => 'true' ] ); ?></a>
                                                            <a href="<?php echo esc_url($team['social_linkedin_url']); ?>"><?php \Elementor\Icons_Manager::render_icon( $team['social_linkedin'], [ 'aria-hidden' => 'true' ] ); ?></a>
                                                            <a href="<?php echo esc_url($team['social_twitter_url']); ?>"><?php \Elementor\Icons_Manager::render_icon( $team['social_twitter'], [ 'aria-hidden' => 'true' ] ); ?></a>
                                                            <a href="<?php echo esc_url($team['social_github_url']); ?>"><?php \Elementor\Icons_Manager::render_icon( $team['social_github'], [ 'aria-hidden' => 'true' ] ); ?></a>
                                                        </div>
                                                    </div>
                                                </div>






                                            <?php } ?>
                                        <?php endforeach;


                                    endif; ?>

                                </div>
                                                   
                            </div>
                        <?php }
                        
                        
                    endif;  ?>
                </div>
            </div>
        </div>


    <?php }



}