<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Group_Control_Background,
	Group_Control_Box_Shadow,
	Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Group_Control_Border,
    Repeater};

class quiety_team_slider extends Widget_Base {

    public function get_name() {
		return 'quiety_team_slider';
	}

	public function get_title() {
		return __( 'Quiety Team Slider', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-slider-album';
	}

	public function get_categories() {
		return [ 'quiety-elements' ];
	}

    protected function register_controls() {
        $this-> content_controls();
        $this->style_controls();
    }

    public function content_controls() {

        $this->start_controls_section( 'team_slider', [
		    'label' => __( 'Team Slider', 'quiety-core' ),
	    ]);

            $this->add_control(
                'list',
                [
                    'label' => esc_html__( 'Team Single', 'quiety-core' ),
                    'type' => \Elementor\Controls_Manager::REPEATER,
                    'fields' => [
                        [
                            'name' => 'image',
                            'label' => esc_html__( 'Single Image', 'quiety-core' ),
                            'type' => \Elementor\Controls_Manager::MEDIA,
                            'default' => [
                                'url' => \Elementor\Utils::get_placeholder_image_src(),
                            ],
                        ],

                        [
                            'name' => 'name',
                            'label' => esc_html__( 'Name', 'quiety-core' ),
                            'type' => \Elementor\Controls_Manager::TEXTAREA,
                            'default' => esc_html__( 'Forrest Collman', 'quiety-core' ),
                        ],

                        [
                            'name' => 'designation',
                            'label' => esc_html__( 'Designation', 'quiety-core' ),
                            'type' => \Elementor\Controls_Manager::TEXT,
                            'label_block' => true,
                            'default' => esc_html__( 'Forrest Collman', 'quiety-core' ),
                        ],


                    ]
                ]
            );


        $this->end_controls_section();

        //===================== Slider Control ======================//
        $this->start_controls_section('sec_slider_control', [
            'label' => esc_html__('Slider Control', 'quiety-core')
        ]);

        $this->add_control('loop', [
            'label'        => esc_html__('Loop', 'quiety-core'),
            'type'         => Controls_Manager::SWITCHER,
            'label_on'     => esc_html__('On', 'quiety-core'),
            'label_off'    => esc_html__('Off', 'quiety-core'),
            'return_value' => 'yes',
            'default'      => 'yes'
        ]);

        $this->add_control('speed', [
            'label'   => __('Speed', 'quiety-core'),
            'type'    => Controls_Manager::NUMBER,
            'default' => 700,
        ]);

        $this->add_control('autoplay', [
            'label'        => esc_html__('Autoplay', 'quiety-core'),
            'type'         => Controls_Manager::SWITCHER,
            'label_on'     => esc_html__('On', 'quiety-core'),
            'label_off'    => esc_html__('Off', 'quiety-core'),
            'return_value' => 'yes',
            'default'      => 'yes'
        ]);

        $this->add_control('autoplay_time', [
            'label'   => __('Autoplay Time', 'quiety-core'),
            'type'    => Controls_Manager::NUMBER,
            'default' => 3000,
            'condition' => [
                'autoplay' => 'yes'
            ]
        ]);

        $this->add_control(
            'show_items_desktop',
            [
                'label'     => esc_html__('Display Items [Desktop]', 'quiety-core'),
                'type'      => Controls_Manager::NUMBER,

            ]
        );
        $this->add_control(
            'show_items_tablet',
            [
                'label'     => esc_html__('Display Items [Tablet]', 'quiety-core'),
                'type'      => Controls_Manager::NUMBER,

            ]
        );
        $this->add_control(
            'show_items_mobile',
            [
                'label'     => esc_html__('Display Items [Mobile]', 'quiety-core'),
                'type'      => Controls_Manager::NUMBER,
                'default'    => 1
            ]
        );
        $this->add_control(
            'item_space',
            [
                'label' => __('Item Space', 'quiety-core'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ]
                ],
                'default' => [
                    'size' => 24,
                ]
            ]
        );

        $this->end_controls_section();

    }

    public function style_controls() {
        return;
    }

    protected function render() { 

        $settings = $this->get_settings_for_display(); 
        extract($settings); ?> 

            <div class="dg-team-slider swiper overflow-hidden"
                <?php 
                echo quiety_swiper_attrebutes( 
                    $show_items_desktop,
                    $loop, 
                    $autoplay, 
                    $autoplay_time, 
                    $speed, 
                    $item_space['size'], 
                    $show_items_tablet, 
                    $show_items_mobile,
                    'bullets',
                    '.dg-team-slider-controls'
                ) ?> >
                <div class="swiper-wrapper">

                <?php if( $settings['list'] ) {
                    foreach ($settings['list'] as $item) { ?>

                    <div class="dg-team-single swiper-slide rounded-3 position-relative overflow-hidden">
                        <img src="<?php echo esc_url($item['image']['url']); ?>" alt="team" class="img-fluid">
                        <div class="designation-box bg-white rounded-3 text-center">
                            <h6 class="heading-dg-color mb-0"><?php echo esc_html($item['name']); ?></h6>
                            <span class="fs-sm d-block"><?php echo esc_html($item['designation']); ?></span>
                        </div>
                    </div>

                    <?php }
                } ?>
                </div>
                <div class="dg-team-slider-controls dg-slider-control d-flex align-items-center justify-content-center mt-40"></div>
            </div>
        <?php 
    }
}