<?php

namespace Quiety\Widgets;

if (! defined('ABSPATH')) {
    exit;
}

use Elementor\{
    Controls_Manager,
    Group_Control_Background,
    Group_Control_Box_Shadow,
    Widget_Base,
    Group_Control_Typography,
    Repeater,
    Utils
};

class Quiety_Testimonial extends Widget_Base
{

    public function get_name()
    {
        return 'tt-testimonial';
    }

    public function get_title()
    {
        return esc_html__('Quiety Testimonial', 'quiety-core');
    }

    public function get_icon()
    {
        return 'eicon-testimonial';
    }

    public function get_categories()
    {
        return ['tt-elements'];
    }

    /**
     * Name: register_controls
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function register_controls()
    {
        $this->elementor_content_control();
        $this->elementor_style_control();
    }

    /**
     * Name: quiety_elementor_content_control
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function elementor_content_control()
    {

        //========================= Select Layout ========================//
        $this->start_controls_section('select_layout', [
            'label' => esc_html__('Select Layout', 'quiety-core'),
        ]);

        $this->add_control(
            'layout',
            [
                'label' => __('Testimonial Style', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '1',
                'options' => [
                    '1'  => __('01: Layout', 'quiety-core'),
                    '2'  => __('02: Layout', 'quiety-core'),
                    '4'  => __('03: Layout', 'quiety-core'),
                    '5'  => __('04: Layout', 'quiety-core'),
                    '05' => __('05: Layout', 'quiety-core'),
                    '06' => __('06: Layout', 'quiety-core'),
                    '07' => __('07: Layout', 'quiety-core'),
                    '08' => __('08: Carousel Slider', 'quiety-core'),
                    '09' => __('09: Carousel Slider', 'quiety-core'),
                    '10' => __('10: Layout', 'quiety-core'),
                    '11' => __('11: Layout', 'quiety-core'),
                    '12' => __('12: Layout', 'quiety-core'),
                    '13' => __('13: Layout', 'quiety-core'),
                    '14' => __('14: Layout', 'quiety-core'),
                    '15' => __('15: Layout', 'quiety-core'),
                    '16' => __('16: Layout', 'quiety-core'),
                    '17' => __('17: Layout', 'quiety-core'),
                    '18' => __('18: Layout', 'quiety-core'),
                ],
            ]
        );

        $this->end_controls_section(); //End Layout


        //===================== Section Contents ======================//

        // this heading only fory layout 17 Start------------------------------
        $this->start_controls_section(
            'heading_section',
            [
                'label' => esc_html__('Heading', 'quiety-core'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => '17',
                ]
            ]
        );
        $this->add_control(
            'heading_title',
            [
                'label' => esc_html__('Heading Title', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => esc_html__('Default title', 'quiety-core'),
                'placeholder' => esc_html__('Type your title here', 'quiety-core'),
                'description' => esc_html__("if you need to different color you can just wrap span tag with need text.", "quiety-core"),
            ]
        );
        $this->end_controls_section();
        // this heading only fory layout 17 End------------------------------

        // This layout for 18 start ================
        $this->start_controls_section(
            'lay18_section',
            [
                'label' => esc_html__('Content', 'quiety-core'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
                'condition' => [
                'layout' => '18',
                ]
            ]
        );
        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'aut_img',
            [
                'label' => esc_html__('Author Image', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $repeater->add_control('lay18_location_list', [
            'label'       => __('Location Name', 'quiety-core'),
            'type'        => Controls_Manager::TEXTAREA,
        ]);
        $repeater->add_control(
            'aut_name',
            [
                'label' => esc_html__('Author Name', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('Nina Nesdoly', 'quiety-core'),
                'placeholder' => esc_html__('Type your title here', 'quiety-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'aut_designation',
            [
                'label' => esc_html__('Author Designation', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('Digital Maketer', 'quiety-core'),
                'placeholder' => esc_html__('Type your title here', 'quiety-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lay18_list',
            [
                'label' => esc_html__('Repeater List', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'aut_name' => esc_html__('Nina Nesdoly', 'quiety-core'),
                        'aut_designation' => esc_html__('Digital Maketer', 'quiety-core'),
                    ],
                ],
                'title_field' => '{{{ aut_name }}}',
            ]
        );

        $this->end_controls_section();

        // This layout for 18 end ================


        $this->start_controls_section('sec_contents', [
            'label' => esc_html__('Contents', 'quiety-core'),
            'condition' => [
                'layout' => ['09']
            ]
        ]);

        $this->add_control('upper_title', [
            'label'       => __('Upper Title', 'quiety-core'),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => 'Customer Feedback',
        ]);

        $this->add_control('title', [
            'label'       => __('Title', 'quiety-core'),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => 'Why People Want to Used Quiety!',
        ]);

        $this->add_control('content', [
            'label'       => __('Content', 'quiety-core'),
            'type'        => Controls_Manager::TEXTAREA,
            'separator'   => 'before'
        ]);

        $this->end_controls_section(); //End Section Contents


        //========================= Testimonial ===========================//
        $this->start_controls_section('section_tab_style', [
            'label' => esc_html__('Testimonial', 'quiety-core'),
            'condition' => [
                'layout!' => ['16', '18'],
            ]
        ]);

        $this->add_control(
            'dg-testimonial',
            [
                'label'  => __('Testimonial Items', 'quiety-core'),
                'type'   => \Elementor\Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'  => 'company_logo',
                        'label' => __('Company Logo', 'quiety-core'),
                        'type'  => \Elementor\Controls_Manager::MEDIA,
                        'default' => [
                            'url' => \Elementor\Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'name'  => 'qt_feedback_content',
                        'label' => __('Content', 'quiety-core'),
                        'type'  => \Elementor\Controls_Manager::TEXTAREA,
                    ],
                    [
                        'name'  => 'qt_client_image',
                        'label' => __('Client Image', 'quiety-core'),
                        'type'  => \Elementor\Controls_Manager::MEDIA,
                        'default' => [
                            'url' => \Elementor\Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'name'  => 'qt_client_name',
                        'label' => __('Client`s Name', 'quiety-core'),
                        'type'  => \Elementor\Controls_Manager::TEXT,
                        'label_block' => true,
                    ],
                    [
                        'name'  => 'qt_client_designation',
                        'label' => __('Client`s Designation', 'quiety-core'),
                        'type'  => \Elementor\Controls_Manager::TEXT,
                        'label_block' => true,
                    ],
                    [
                        'name'  => 'qt_item_serial',
                        'label' => __('Item Serial', 'quiety-core'),
                        'type'  => \Elementor\Controls_Manager::TEXT,
                    ],
                ],
                'condition' => [
                    'layout'  => ['10']
                ],
            ]
        );

        $this->add_control('enable_quote', [
            'label'        => esc_html__('Show Quote Icon', 'quiety-core'),
            'type'         => Controls_Manager::SWITCHER,
            'label_on'     => esc_html__('Show', 'quiety-core'),
            'label_off'    => esc_html__('Hide', 'quiety-core'),
            'return_value' => 'yes',
            'default'      => 'yes',
            'condition' => [
                'layout' => ['1', '2', '4', '5', '05', '06']
            ],
        ]);

        $this->add_control('quote_image', [
            'label'   => __('Quote Image', 'quiety-core'),
            'type'    => Controls_Manager::MEDIA,
            'default' => [
                'url' => plugin_dir_url(__DIR__) . '/assets/images/quotes.svg',
            ],
            'condition' => [
                'enable_quote' => 'yes',
                'layout' => ['1', '2', '4', '5', '05', '06']
            ],
        ]);

        //Testimonials Layout 1, 2, 4, 5, 05, 06,
        $repeater = new Repeater();
        $repeater->add_control('image', [
            'label'   => __('Author Image', 'quiety-core'),
            'type'    => Controls_Manager::MEDIA,
            'default' => [
                'url' => Utils::get_placeholder_image_src(),
            ]
        ]);
        $repeater->add_control('company_image', [
            'label'   => __('Company Image', 'quiety-core'),
            'type'    => Controls_Manager::MEDIA,
        ]);

        $repeater->add_control('name', [
            'label'       => __('Name', 'quiety-core'),
            'type'        => Controls_Manager::TEXT,
            'default'     => __('Carrie Roberts', 'quiety-core'),
            'label_block' => true,
        ]);

        $repeater->add_control('designation', [
            'label'       => __('Designation', 'quiety-core'),
            'type'        => Controls_Manager::TEXT,
            'default'     => __('Full-Stack Developer', 'quiety-core'),
            'label_block' => true,
        ]);

        $repeater->add_control('title', [
            'label'       => __('Title', 'quiety-core'),
            'type'        => Controls_Manager::TEXT,
            'default'     => __('35+ minutes per session', 'quiety-core'),
            'label_block' => true,
        ]);

        $repeater->add_control('rating', [
            'label'   => __('Rating Number', 'quiety-core'),
            'type'    => \Elementor\Controls_Manager::SELECT,
            'default' => '50',
            'options' => [
                '10' => __('1 Star', 'quiety-core'),
                '20' => __('2 Star', 'quiety-core'),
                '30' => __('3 Star', 'quiety-core'),
                '40' => __('4 Star', 'quiety-core'),
                '50' => __('5 Star', 'quiety-core'),
            ],
        ]);

        $repeater->add_control('review_content', [
            'label'      => __('Review Content', 'quiety-core'),
            'type'       => Controls_Manager::TEXTAREA,
            'default'    => __('“If you need any help or assistance we\'d be happy to help. Just reply to this email. Trusted by Agency proud to work many well known brands”', 'quiety-core'),
            'show_label' => false,
        ]);

        $this->add_control('testimonials', [
            'label'       => __('Testimonial Items', 'quiety-core'),
            'type'        => Controls_Manager::REPEATER,
            'fields'      => $repeater->get_controls(),
            'default'     => [
                [
                    'image'          => [
                        'url' => Utils::get_placeholder_image_src(),
                    ],
                    'name'           => __('Alexa Loverty', 'quiety-core'),
                    'designation'    => __('Product Designer', 'quiety-core'),
                    'review_content' => __('Pellentesque nec nam aliquam sem. Ultricies lacus sed turpis tincidunt id aliquet risus. Consequat nisl vel pretium lectus quam id. Velit scelerisque in dictum non of the ntconsectetur.', 'quiety-core'),
                ],
                [
                    'image'          => [
                        'url' => Utils::get_placeholder_image_src(),
                    ],
                    'name'           => __('Maxine Butler', 'quiety-core'),
                    'designation'    => __('Manager', 'quiety-core'),
                    'review_content' => __('Pellentesque nec nam aliquam sem. Ultricies lacus sed turpis tincidunt id aliquet risus. Consequat nisl vel pretium lectus quam id. Velit scelerisque in dictum non of the ntconsectetur.', 'quiety-core'),
                ],
                [
                    'image'          => [
                        'url' => Utils::get_placeholder_image_src(),
                    ],
                    'name'           => __('Hugh Saturation', 'quiety-core'),
                    'designation'    => __('UX Designer', 'quiety-core'),
                    'review_content' => __('Pellentesque nec nam aliquam sem. Ultricies lacus sed turpis tincidunt id aliquet risus. Consequat nisl vel pretium lectus quam id. Velit scelerisque in dictum non of the ntconsectetur.', 'quiety-core'),
                ],
            ],
            'title_field' => '{{{ name }}}',
            'condition' => [
                'layout' => ['1', '2', '4', '5', '05', '06', '12', '15', '17']
            ]
        ]); //End Testimonials 1, 2, 4, 5, 05, 06


        // Testimonials Style 07, 08
        $testimonial7 = new Repeater();
        $testimonial7->add_control('image', [
            'label'      => __('Author Image', 'quiety-core'),
            'type'       => Controls_Manager::MEDIA,
        ]);

        $testimonial7->add_control('title', [
            'label'      => __('Title', 'quiety-core'),
            'type'       => Controls_Manager::TEXT,
            'label_block' => true,
            'default'    => 'Agency X helped us to reach our business goals'
        ]);

        $testimonial7->add_control('name', [
            'label'      => __('Author Name', 'quiety-core'),
            'type'       => Controls_Manager::TEXT,
            'default'    => 'Kyle Johnston'
        ]);

        $testimonial7->add_control('designation', [
            'label'      => __('Designation', 'quiety-core'),
            'type'       => Controls_Manager::TEXT,
            'default'    => 'Founder & CEO'
        ]);

        $testimonial7->add_control('review_content', [
            'label'      => __('Review Content', 'quiety-core'),
            'type'       => Controls_Manager::TEXTAREA,
            'show_label' => false,
            'default'    => __('“If you need any help or assistance we\'d be happy to help. Just reply to this email. Trusted by Agency proud to work many well known brands”', 'quiety-core'),
        ]);


        $this->add_control('testimonials7', [
            'label'       => __('Testimonial Items', 'quiety-core'),
            'type'        => Controls_Manager::REPEATER,
            'fields'      => $testimonial7->get_controls(),
            'title_field' => '{{{ name }}}',
            'condition' => [
                'layout' => ['07', '08', '11', '13', '14']
            ]
        ]); //End Layout 07


        // Testimonials Style 09
        $testimonial9 = new Repeater();
        $testimonial9->add_control('image', [
            'label'      => __('Author Image', 'quiety-core'),
            'type'       => Controls_Manager::MEDIA,
        ]);

        $testimonial9->add_control('title', [
            'label'      => __('Title', 'quiety-core'),
            'type'       => Controls_Manager::TEXT,
            'label_block' => true,
            'default'    => 'Agency X helped us to reach our business goals'
        ]);

        $testimonial9->add_control('name', [
            'label'      => __('Author Name', 'quiety-core'),
            'type'       => Controls_Manager::TEXT,
            'default'    => 'Kyle Johnston'
        ]);

        $testimonial9->add_control('review_content', [
            'label'      => __('Review Content', 'quiety-core'),
            'type'       => Controls_Manager::TEXTAREA,
            'show_label' => false,
            'default'    => __('“If you need any help or assistance we\'d be happy to help. Just reply to this email. Trusted by Agency proud to work many well known brands”', 'quiety-core'),
        ]);

        $this->add_control('testimonials9', [
            'label'       => __('Add Item', 'quiety-core'),
            'type'        => Controls_Manager::REPEATER,
            'fields'      => $testimonial9->get_controls(),
            'title_field' => '{{{ name }}}',
            'condition' => [
                'layout' => '09'
            ]
        ]); //End Layout 09

        $this->end_controls_section(); //End Section



        //Testimonials Style 16 Start-----------------
        $this->start_controls_section(
            'testi_lay16',
            [
                'label' => esc_html__('Testimonial', 'quiety-core'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => '16',
                ]
            ]
        );
        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'testi16_image',
            [
                'label' => esc_html__('Choose Image', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );
        $repeater->add_control(
            'cat_title',
            [
                'label' => esc_html__('Category Title', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('Business', 'quiety-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'testi16_title',
            [
                'label' => esc_html__('Title', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('List Title', 'quiety-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'testi16_sales_title',
            [
                'label' => esc_html__('Sales Count', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('Sales: 1532', 'quiety-core'),
                'label_block' => true,
            ]
        );
        $repeater->add_control('rating16', [
            'label'   => __('Rating Number', 'quiety-core'),
            'type'    => \Elementor\Controls_Manager::SELECT,
            'default' => '50',
            'options' => [
                '10' => __('1 Star', 'quiety-core'),
                '20' => __('2 Star', 'quiety-core'),
                '30' => __('3 Star', 'quiety-core'),
                '40' => __('4 Star', 'quiety-core'),
                '50' => __('5 Star', 'quiety-core'),
            ],
        ]);
        $repeater->add_control(
            'testi16_review',
            [
                'label' => esc_html__('Review Title', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('(1.4k Review)', 'quiety-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'testimonial16',
            [
                'label' => esc_html__('Repeater List', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'testi16_title' => esc_html__('Consulting - Business Consultation WordPress Theme', 'quiety-core'),
                    ],
                ],
                'title_field' => '{{{ testi16_title }}}',
                'condition' => [
                    'layout' => '16',
                ]
            ]
        );
        $this->end_controls_section();

        //Testimonials Style 16 End-----------------


        //========================= Featured ===========================//
        $this->start_controls_section('sec_featured_images', [
            'label' => esc_html__('Featured Image', 'quiety-core'),
            'condition' => [
                'layout' => '09'
            ],
        ]);

        $this->add_control('fimage', [
            'label'   => __('Image', 'quiety-core'),
            'type'    => Controls_Manager::MEDIA,
        ]);

        $this->add_control('shape', [
            'label'   => __('Shape', 'quiety-core'),
            'type'    => Controls_Manager::MEDIA,
        ]);

        $this->end_controls_section(); //End Featured Image


        //===================== Slider Control ======================//
        $this->start_controls_section('sec_slider_control', [
            'label' => esc_html__('Slider Control', 'quiety-core'),
            'condition' => [
                'layout' => ['1', '2', '4', '5', '05', '06', '07', '12', '14', '15', '10', '11', '16', '17', '18']
            ]
        ]);

        $this->add_control('navigation', [
            'label'        => esc_html__('Navigation', 'quiety-core'),
            'type'         => Controls_Manager::SWITCHER,
            'label_on'     => esc_html__('Show', 'quiety-core'),
            'label_off'    => esc_html__('Hide', 'quiety-core'),
            'return_value' => 'yes',
            'default'      => 'yes'
        ]);


        $this->add_control('loop', [
            'label'        => esc_html__('Loop', 'quiety-core'),
            'type'         => Controls_Manager::SWITCHER,
            'label_on'     => esc_html__('On', 'quiety-core'),
            'label_off'    => esc_html__('Off', 'quiety-core'),
            'return_value' => 'yes',
            'default'      => 'yes'
        ]);

        $this->add_control('speed', [
            'label'   => __('Speed', 'quiety-core'),
            'type'    => Controls_Manager::NUMBER,
            'default' => 700,
        ]);

        $this->add_control('autoplay', [
            'label'        => esc_html__('Autoplay', 'quiety-core'),
            'type'         => Controls_Manager::SWITCHER,
            'label_on'     => esc_html__('On', 'quiety-core'),
            'label_off'    => esc_html__('Off', 'quiety-core'),
            'return_value' => 'yes',
            'default'      => 'yes'
        ]);

        $this->add_control('autoplay_time', [
            'label'   => __('Autoplay Time', 'quiety-core'),
            'type'    => Controls_Manager::NUMBER,
            'default' => 3000,
            'condition' => [
                'autoplay' => 'yes'
            ]
        ]);

        $this->add_control(
            'show_items_desktop',
            [
                'label'     => esc_html__('Display Items [Desktop]', 'quiety-core'),
                'type'      => Controls_Manager::NUMBER,

            ]
        );
        $this->add_control(
            'show_items_tablet',
            [
                'label'     => esc_html__('Display Items [Tablet]', 'quiety-core'),
                'type'      => Controls_Manager::NUMBER,

            ]
        );
        $this->add_control(
            'show_items_mobile',
            [
                'label'     => esc_html__('Display Items [Mobile]', 'quiety-core'),
                'type'      => Controls_Manager::NUMBER,
                'default'    => 1
            ]
        );
        $this->add_control(
            'item_space',
            [
                'label' => __('Item Space', 'quiety-core'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 1,
                    ]
                ],
                'default' => [
                    'size' => 24,
                ]
            ]
        );

        $this->end_controls_section();
    }


    /**
     * Name: quiety_elementor_style_control
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function elementor_style_control()
    {

        //===================== Item Title =====================//
        $this->start_controls_section('title_style_section', [
            'label' => __('Title', 'quiety-core'),
            'tab'   => Controls_Manager::TAB_STYLE,
        ]);

        $this->add_group_control(Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __('Typography', 'quiety-core'),
            'selector' => '
				{{WRAPPER}} .testimonial-title,
				{{WRAPPER}} .__title,
				{{WRAPPER}} .testimonial .bio-wrapper .name,
				{{WRAPPER}} .title_style__,
				{{WRAPPER}} h2.home-38-title
			',
        ]);

        $this->add_control('title_color', [
            'label'     => __('Color', 'quiety-core'),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .testimonial-title' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
                '{{WRAPPER}} .testimonial .bio-wrapper .name' => 'color: {{VALUE}}',
                '{{WRAPPER}} .title_style__' => 'color: {{VALUE}}',
                '{{WRAPPER}} .home-38-title' => 'color: {{VALUE}}',
            ],
        ]);
        $this->add_control('highlight_color', [
            'label'     => __('Hightlight Color', 'quiety-core'),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .home-38-title span' => 'color: {{VALUE}}',
            ],
        ]);

        $this->end_controls_section(); //End Item Title


        //===================== Author Name =====================//
        $this->start_controls_section('name_section', [
            'label' => __('Name', 'quiety-core'),
            'tab'   => Controls_Manager::TAB_STYLE,
        ]);

        $this->add_group_control(Group_Control_Typography::get_type(), [
            'name'     => 'name_typography',
            'label'    => __('Typography', 'quiety-core'),
            'selector' => '{{WRAPPER}} .name, {{WRAPPER}} .sh-feedback-client .t_author_name, {{WRAPPER}} footer.feedback-slider__footer.name_style__, {{WRAPPER}} .tes_name_style__',
        ]);

        $this->add_control('name_color', [
            'label'     => __('Color', 'quiety-core'),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .name' => 'color: {{VALUE}}',
                '{{WRAPPER}} .sh-feedback-client .t_author_name' => 'color: {{VALUE}}',
                '{{WRAPPER}} .name_style__,  {{WRAPPER}} .tes_name_style__' => 'color: {{VALUE}}',
            ],
        ]);

        $this->end_controls_section(); //End Author Name


        //====================== Designation ===================//
        $this->start_controls_section('designation_section', [
            'label' => __('Designation', 'quiety-core'),
            'tab'   => Controls_Manager::TAB_STYLE,
        ]);

        $this->add_group_control(Group_Control_Typography::get_type(), [
            'name'     => 'desi_typography',
            'label'    => __('Typography', 'quiety-core'),
            'selector' => '
				{{WRAPPER}} .sh-feedback-client .designation,
				{{WRAPPER}} .__designation,
				{{WRAPPER}} .testimonial .bio-wrapper .designation,
				{{WRAPPER}} cite.feedback-slider__cite.designation_style__,
				{{WRAPPER}} .tes_desgi_style__
			',
        ]);

        $this->add_control('desi_color', [
            'label'     => __('Color', 'quiety-core'),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .sh-feedback-client .designation' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__designation' => 'color: {{VALUE}}',
                '{{WRAPPER}} .testimonial .bio-wrapper .designation' => 'color: {{VALUE}}',
                '{{WRAPPER}} .designation_style__' => 'color: {{VALUE}}',
                '{{WRAPPER}} .tes_desgi_style__' => 'color: {{VALUE}}',
            ],
        ]);

        $this->end_controls_section(); //End Designation


        //========================= Review Content ========================//
        $this->start_controls_section('review_section', [
            'label' => __('Review Content', 'quiety-core'),
            'tab'   => Controls_Manager::TAB_STYLE,
        ]);

        $this->add_group_control(Group_Control_Typography::get_type(), [
            'name'     => 'review_typography',
            'label'    => __('Typography', 'quiety-core'),
            'selector' => '
				{{WRAPPER}} .testimonial p,
				{{WRAPPER}} .__review,
				{{WRAPPER}} .sh-feedback-wrapper .review_content,
				{{WRAPPER}} .review_style__,
				{{WRAPPER}} .tes_review_style__
			',
        ]);

        $this->add_control('review_color', [
            'label'     => __('Color', 'quiety-core'),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .testimonial p' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__review' => 'color: {{VALUE}}',
                '{{WRAPPER}} .sh-feedback-wrapper .review_content' => 'color: {{VALUE}}',
                '{{WRAPPER}} .review_style__, {{WRAPPER}} .tes_review_style__' => 'color: {{VALUE}}',
            ],
        ]);

        $this->add_control(
            'rating_space',
            [
                'label' => esc_html__('Ratting Bottom Space', 'plugin-name'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .star-rating' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'layout' => '2'
                ]
            ]
        );

        $this->end_controls_section(); //End Review Content

        // layout 15 button style --------------------------
        $this->start_controls_section(
			'button_style_section',
			[
				'label' => esc_html__( 'Button Style', 'quiety-core' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => '15',
                ]
			]
		);
		$this->start_controls_tabs(
            'style_tabs'
        );
        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'quiety-core' ),
            ]
        );
        $this->add_control(
			'normal_icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .aiart-post-slider.ma-style .aiart-slider-nav i' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'normal_background',
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .aiart-post-slider.ma-style .aiart-slider-nav',
			]
		);
        $this->end_controls_tab();


        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'quiety-core' ),
            ]
        );
        $this->add_control(
			'hover_icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .aiart-post-slider.ma-style .aiart-slider-nav:hover i' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'hover_background',
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .aiart-post-slider.ma-style .aiart-slider-nav:hover',
			]
		);
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
		$this->end_controls_section();

        //========================= Section background style  ========================//

        $this->start_controls_section('section_background_style', [
            'label' => __('Background Style', 'quiety-core'),
            'tab'   => Controls_Manager::TAB_STYLE,
        ]);
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background',
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .dg-feedback-single, {{WRAPPER}} .sec_bg_color, {{WRAPPER}} .ma-feedback-item:hover',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background_hover_color',
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .ma-feedback-item:hover',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'border',
                'selector' => '{{WRAPPER}} .dg-feedback-single',

            ]
        );
        $this->add_control(
            'box_shadow',
            [
                'label' => esc_html__('Box Shadow', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::BOX_SHADOW,
                'selector' => '{{WRAPPER}} .dg-feedback-single',
            ]
        );

        $this->end_controls_section(); //Section background style end --------------------------------------------------------//


        //=========================== Slider Control Style =====================//
        $this->start_controls_section('control_section', [
            'label' => __('Slider  Control', 'quiety-core'),
            'tab'   => Controls_Manager::TAB_STYLE,
            'condition' => [
                'layout' => ['1', '2', '4', '5', '05', '06']
            ]
        ]);

        $this->start_controls_tabs('tabs_nav_style');

        $this->start_controls_tab(
            'tab_nav_normal',
            [
                'label' => __('Normal', 'quiety-core'),
            ]
        );

        $this->add_control('slider_nav_color', [
            'label'     => __('Color', 'quiety-core'),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-testimonial-wrapper .slider-control > div' => 'color: {{VALUE}}',
            ],
        ]);

        $this->add_control('nav_bg_color', [
            'label'     => __('Background Color', 'quiety-core'),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-testimonial-wrapper .slider-control > div' => 'background-color: {{VALUE}}',
            ],
        ]);

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'nav_box_shadow',
                'label' => __('Box Shadow', 'quiety-core'),
                'selector' => '{{WRAPPER}} .tt-testimonial-wrapper .slider-control > div',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_nav_hover',
            [
                'label' => __('Hover', 'quiety-core'),
            ]
        );

        $this->add_control('nav_color_hover', [
            'label'     => __('Color', 'quiety-core'),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-testimonial-wrapper .slider-control > div:hover' => 'color: {{VALUE}}',
            ],
        ]);

        $this->add_control('nav_color_bg_hover', [
            'label'     => __('Background Color', 'quiety-core'),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-testimonial-wrapper .slider-control > div:hover' => 'background-color: {{VALUE}}',
            ],
        ]);

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'nav_box_shadow_hover',
                'label' => __('Box Shadow', 'quiety-core'),
                'selector' => '{{WRAPPER}} .tt-testimonial-wrapper .slider-control > div:hover',
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section(); //End Slider Control Style


        //===================== Slider Control Style ======================//
        $this->start_controls_section('testimonial_section', [
            'label' => __('Testimonial Container', 'quiety-core'),
            'tab'   => Controls_Manager::TAB_STYLE,
            'condition' => [
                'layout' => ['1', '2', '4', '5', '05', '06']
            ]
        ]);

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'testimonial_background',
                'label' => __('Background', 'quiety-core'),
                'types' => ['classic', 'gradient'],
                'exclude' => ['image'],
                'selector' => '
				    {{WRAPPER}} .testimonial,
				    {{WRAPPER}} .testimonial-item
                ',
            ]
        );

        $this->add_control(
            'testimonial_padding',
            [
                'label' => __('Padding', 'quiety-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .testimonial' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .testimonial-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'testimonial_border_radius',
            [
                'label' => __('Border Radius', 'quiety-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .testimonial' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .testimonial-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'testimonial_border',
                'label' => esc_html__('Border', 'plugin-name'),
                'selector' => '
				    {{WRAPPER}} .testimonial,
				    {{WRAPPER}} .testimonial-item
                ',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'testimonial_shadow_hover',
                'label' => __('Box Shadow', 'quiety-core'),
                'selector' => '
				    {{WRAPPER}} .testimonial,
				    {{WRAPPER}} .testimonial-item
                ',
            ]
        );

        $this->end_controls_section(); //End Slider Control Style


        //===================== Slider Section Background ======================//
        $this->start_controls_section('sec_bg_style', [
            'label' => __('Background', 'quiety-core'),
            'tab'   => Controls_Manager::TAB_STYLE,
            'condition' => [
                'layout' => '08'
            ]
        ]);

        $this->add_responsive_control(
            'sec_margin',
            [
                'label' => esc_html__('Margin', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .quiety_sec' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sec_padding',
            [
                'label' => esc_html__('Padding', 'quiety-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors' => [
                    '{{WRAPPER}} .quiety_sec' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'sec_background',
                'label' => esc_html__('Background', 'quiety-core'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .quiety_sec',
            ]
        );

        $this->end_controls_section(); //End Section Background

    }


    /**
     * Name: render
     * Desc: Widgets Render
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function render()
    {
        $settings     = $this->get_settings_for_display();
        extract($settings);

        $testimonials = $settings['testimonials'];
        $layout = $settings['layout'];

        if ($layout != '08') {
            $this->add_render_attribute('wrapper', 'class', [
                'swiper-container',
                'tt-testimonial',
                'overflow-hidden',
            ]);
        }



        if ($layout == '5') {
            $this->add_render_attribute('wrapper', 'class', [
                'swiper-container',
                'tt-testimonial-five',
                'overflow-hidden',
            ]);
        }

        if ($layout == '08') {
            $this->add_render_attribute('wrapper', 'class', [
                'ins-feedback-slider',
                'swiper',
                'overflow-visible mt-4',
                'mt-4'
            ]);
        }

        $this->add_render_attribute('title_text', [
            'class'          => 'section-title wow fadeInUp',
            'data-wow-delay' => '0.3s'
        ]);

        $this->add_render_attribute('sub_title', 'class', 'subtitle wow fadeInUp');

        $this->add_inline_editing_attributes('title_text');
        $this->add_inline_editing_attributes('sub_title');


        $this->add_render_attribute('description_text', [
            'class'          => 'description wow fadeInUp',
            'data-wow-delay' => '0.5s'
        ]);
        $this->add_inline_editing_attributes('description_text');


        $slider_options = $this->get_slider_options($settings);
        $this->add_render_attribute('wrapper', 'data-testi', wp_json_encode($slider_options));


        require __DIR__ . '/templates/testimonial/layout-' . $layout . '.php';
    }

    protected function get_slider_options(array $settings)
    {

        if ($settings['loop'] == 'yes') {
            $slider_options['loop'] = true;
        }
        if (! empty($settings['speed'])) {
            $slider_options['speed'] = $settings['speed'];
        }

        if (! empty($settings['item_space']['size'])) {
            $slider_options['spaceBetween'] = (int) $settings['item_space']['size'];
        }

        if ($settings['autoplay'] == 'yes') {
            $slider_options['autoplay'] = [
                'delay' => $settings['autoplay_time'],
                'disableOnInteraction' => false
            ];
        } else {
            $slider_options['autoplay'] = [
                'delay' => '99999999999',
            ];
        }
        if ($settings['navigation'] == 'yes') {
            $slider_options['navigation'] = [
                'nextEl' => '.testi-next',
                'prevEl' => '.testi-prev'
            ];
        }
        if ($settings['layout'] == '5') {
            $slider_options['pagination'] = [
                'el'        => '.testi-swiper-pagination',
                'clickable' => true,
            ];
        }

        $slider_options['breakpoints'] = [
            '992' => [
                'slidesPerView' => !empty((int) $settings['show_items_desktop']) ? $settings['show_items_desktop'] : '',
            ],
            '767' => [
                'slidesPerView' => !empty((int) $settings['show_items_tablet']) ? $settings['show_items_tablet'] : '',
            ],
            '320' => [
                'slidesPerView' => !empty((int) $settings['show_items_mobile']) ? $settings['show_items_mobile'] : '',
            ],
        ];

        return $slider_options;
    }
}
