<?php
namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Controls_Manager,
	Group_Control_Typography,
	Repeater,
	Widget_Base,
	Utils
};

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Quiety_Testimonial_Two extends Widget_Base {

	public function get_name() {
		return 'tt-testimonial-two';
	}

	public function get_title() {
		return esc_html__( 'Quiety Testimonial Two', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-testimonial';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section( 'section_tab_style', [
			'label' => esc_html__( 'Testimonial', 'quiety-core' ),
		] );


		$repeater = new Repeater();

		$repeater->add_control( 'image', [
			'label'   => __( 'Author Image', 'quiety-core' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => Utils::get_placeholder_image_src(),
			],
		] );


		$repeater->add_control( 'name', [
			'label'       => __( 'Name', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => __( 'Mominul', 'quiety-core' ),
			'label_block' => true,
		] );

		$repeater->add_control( 'designation', [
			'label'       => __( 'Designation', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => __( 'Full-Stack Developer', 'quiety-core' ),
			'label_block' => true,
		] );

		$repeater->add_control( 'review_content', [
			'label'      => __( 'Review Content', 'quiety-core' ),
			'type'       => Controls_Manager::TEXTAREA,
			'show_label' => false,
		] );


		$this->add_control( 'testimonials', [
			'label'       => __( 'Testimonial List', 'quiety-core' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'name'           => __( 'Andrew Garfield', 'quiety-core' ),
					'designation'    => __( 'Ceo & Founder jon stein', 'quiety-core' ),
					'review_content' => __( '‘‘The bee\'s knees pardon me bog tosser my lady lemon squeezy bite your arm off Why you mug cor blimey guvnor bodge argy bargy, boot bamboozled cheers I mush show off pick.”', 'quiety-core' ),
				],
				[
					'name'           => __( 'Avie Beaton ', 'quiety-core' ),
					'designation'    => __( 'Finances', 'quiety-core' ),
					'review_content' => __( '‘‘The bee\'s knees pardon me bog tosser my lady lemon squeezy bite your arm off Why you mug cor blimey guvnor bodge argy bargy, boot bamboozled cheers I mush show off pick.”', 'quiety-core' ),
				],
			],
			'title_field' => '{{{ name }}}',
		] );

		$this->end_controls_section();


		$this->start_controls_section( 'settingd_section', [
			'label' => esc_html__( 'Slider Control', 'quiety-core' ),
		] );

		$this->add_control( 'pagination', [
			'label'        => esc_html__( 'Navigation', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'Show', 'quiety-core' ),
			'label_off'    => esc_html__( 'Hide', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'yes'
		] );


		$this->add_control( 'loop', [
			'label'        => esc_html__( 'Loop', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'On', 'quiety-core' ),
			'label_off'    => esc_html__( 'Off', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'yes'
		] );

		$this->add_control( 'speed', [
			'label'   => __( 'Speed', 'quiety-core' ),
			'type'    => Controls_Manager::NUMBER,
			'default' => 700,
		] );

		$this->add_control( 'autoplay', [
			'label'        => esc_html__( 'Autoplay', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'On', 'quiety-core' ),
			'label_off'    => esc_html__( 'Off', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'yes'
		] );

		$this->add_control( 'autoplay_time', [
			'label'   => __( 'Autoplay Time', 'quiety-core' ),
			'type'    => Controls_Manager::NUMBER,
			'default' => 3000,
		] );

		$this->end_controls_section();


		// Style Sections
		//====================

		$this->start_controls_section( 'name_section', [
			'label' => __( 'Name', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'name_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .testimonial-two__name',
		] );

		$this->add_control( 'name_color', [
			'label'     => __( 'Color', 'plugin-domain' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .testimonial-two__name' => 'color: {{VALUE}}',
			],
		] );

		$this->end_controls_section();


		$this->start_controls_section( 'designation_section', [
			'label' => __( 'Designation', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'desi_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .testimonial-two__designation',
		] );

		$this->add_control( 'desi_color', [
			'label'     => __( 'Color', 'plugin-domain' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .testimonial-two__designation' => 'color: {{VALUE}}',
			],
		] );

		$this->end_controls_section();

		$this->start_controls_section( 'review_section', [
			'label' => __( 'Review Content', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'review_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .testimonial-two__content',
		] );

		$this->add_control( 'review_color', [
			'label'     => __( 'Color', 'plugin-domain' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .testimonial-two__content' => 'color: {{VALUE}}',
			],
		] );

		$this->end_controls_section();
	}

	protected function render() {

		$settings     = $this->get_settings_for_display();
		$testimonials = $settings['testimonials'];
		extract($settings);

		$this->add_render_attribute( 'wrapper', 'class', [
			'swiper-container',
			'tt-testimonial',
			'slider-top'
		] );

		$slider_options = $this->get_slider_options( $settings );

		require __DIR__ . '/templates/testimonial/layout-3.php';

	}

	protected function get_slider_options( array $settings ) {

		// Loop
		if ( $settings['loop'] == 'yes' ) {
			$slider_options['loop'] = true;
		}

		// Speed
		if ( ! empty( $settings['speed'] ) ) {
			$slider_options['speed'] = $settings['speed'];
		}

		if ( $settings['autoplay'] ) {
			$slider_options['autoplay'] = '5000';
		}

		if ( $settings['autoplay'] == 'yes' ) {
			$slider_options['autoplay'] = [
				'delay' => $settings['autoplay_time']
			];
		}

		$slider_options['spaceBetween'] = (int) '30';

		return $slider_options;
	}

}