<?php
namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Controls_Manager,
	Group_Control_Background,
	Group_Control_Box_Shadow,
	Widget_Base,
	Group_Control_Typography,
	Repeater,
	Utils};

class quiety_thumbnail_testimonial extends Widget_Base {
    
    public function get_name() {
        return 'quiety_thumbnail_testimonial';
    }

    public function get_title() {
        return esc_html__('Quiety Thumbnail Testimonial', 'quiety-core');
    }

    public function get_icon() {
        return 'eicon-testimonial';
    }

    public function get_categories() {
        return ['tt-elements'];
    }
    
    public function get_keywords() {
		return [ 'testimonial', 'slider', 'thumbnail', 'feedback' ];
	}

    protected function register_controls() {
        $this->register_content();
        $this->register_style();
    }

    public function register_content() {

        $this->start_controls_section(
            'feedback_slider', 
            [
                'label'  => esc_html__('Feedback Slider', 'quiety-core'), 
                'tab'    => \ELEMENTOR\Controls_Manager::TAB_CONTENT,
            ]
        ); 

        $this->add_control(
            'feedback_slide_single',
            [
                'label'  => esc_html__("Feedback Slider", "quiety-core"), 
                'type'   => \Elementor\Controls_Manager::REPEATER,
                'fields'  => [
                    [
                        'name'  => 'slide_text',
                        'label' => esc_html__('Text', 'quiety-core'),
                        'type'  => \Elementor\Controls_Manager::TEXTAREA,
                        'label_block'  => true,
                        'default'  => esc_html__('“Easily organize your infrastructure with Projects. And with Teams, everyone can get their own account, with just the privileges they need to do their and we are rerunning a jobs. Our hosting costs have decreased by over 90% and we are running at about 25% of our capacity”', 'quiety-core')
                    ],
                    [
                        'name'  => 'slide_title', 
                        'label'  => esc_html__('Title', 'quiety-core'), 
                        'type'   => \ELEMENTOR\Controls_Manager::TEXT,
                        'label_block'  => true,
                        'default' => esc_html__('Jerry G.Sanchez', 'quiety-core'),
                    ],
                    [
                        'name'   => 'slide_stars', 
                        'label'  => esc_html__('Stars', 'quiety-core'), 
                        'type'   => Controls_Manager::NUMBER,
                        'min' => 0,
                        'max' => 5,
                        'step' => 1,
                        'default' => 5,
                    ]

                ],
            ]
        );






        $this->end_controls_section();

        $this->start_controls_section(
            'feedback_thumb_single', 
            [
                'label'  => esc_html__('Thumbs Slider', 'quiety-core'), 
                'tab'    => \ELEMENTOR\Controls_Manager::TAB_CONTENT,
            ]
        ); 

        $this->add_control(
            'feedback_thumbnails',
            [
                'label'  => esc_html__("Feedback Thumbnails", "quiety-core"), 
                'type'   => \Elementor\Controls_Manager::REPEATER,
                'fields'  => [
                    [
                        'name'  => 'thumbnails_single',
                        'label' => esc_html__('Thumbnail', 'quiety-core'),
                        'type'  => \Elementor\Controls_Manager::MEDIA,
                        'default'  => [
                            'url' => \Elementor\Utils::get_placeholder_image_src(),
                        ]
                    ],
                ],
            ]
        );

        $this->end_controls_section();


    }

    public function register_style() {
        $this->start_controls_section(
            'feedback_slider_styles', 
            [
                'label'  => esc_html__('Slider Style', 'quiety-core'),
                'tab'    => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
			'background_color',
			[
				'label' => esc_html__( 'Background Color', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .crm-feedback-box' => 'background-color: {{VALUE}}',
				],
			]
		);

        $this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .crm-feedback-box p' => 'color: {{VALUE}}',
					'{{WRAPPER}} .crm-feedback-box h4' => 'color: {{VALUE}}',
				],
			]
		);

        $this->start_controls_tabs(
            'style_tabs'
        );
        
        $this->start_controls_tab(
            'style_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'quiety-core' ),
            ]
        );

        $this->add_control(
			'arrow_bg',
			[
				'label' => esc_html__( 'Arrow Background', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .crm-fd-slide-control' => 'background-color: {{VALUE}}',
				],
			]
		);

        $this->add_control(
			'arrow_text',
			[
				'label' => esc_html__( 'Arrow Text Color', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .crm-fd-slide-control' => 'color: {{VALUE}}',
				],
			]
		);
        
        $this->end_controls_tab();

        $this->start_controls_tab(
            'style_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'quiety-core' ),
            ]
        );

        $this->add_control(
			'arrow_hover_bg',
			[
				'label' => esc_html__( 'Arrow Background', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .crm-fd-slide-control:hover' => 'background-color: {{VALUE}}',
				],
			]
		);

        $this->add_control(
			'arrow_hover_text',
			[
				'label' => esc_html__( 'Arrow Text Color', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .crm-fd-slide-control:hover' => 'color: {{VALUE}}',
				],
			]
		);

        $this->end_controls_tab();

        
        $this->end_controls_tabs();


        $this->end_controls_section();
    }

    protected function render() { 

        $settings = $this->get_settings_for_display(); 

        if ( $settings['feedback_slide_single'] ) { ?>

            <div class="crm-feedback-box rounded position-relative">
                <div class="crm-feedback-slider swiper-container overflow-hidden">
                    <div class="swiper-wrapper">
                        <?php foreach( $settings['feedback_slide_single'] as $slide_single ) { ?>
                            <div class="crm-feedback-single swiper-slide text-center">
                            <p class="mb-4">“<?php echo esc_html($slide_single['slide_text']); ?>”</p>
                            <h4 class="mb-0"><?php echo esc_html($slide_single['slide_title']); ?></h4>

                            <?php if( !empty( $slide_single['slide_stars'] ) ){
                                    for( $i = 1; $i <= 5; $i++ ){
                                        if( $i <= $slide_single['slide_stars'] ){
                                            echo '<span><i class="fa-solid fa-star"></i></span>';
                                        }
                                        else{
                                            echo '<span><i class="fa-regular fa-star"></i></span>';
                                        }
                                    }
                                }
                            ?>
                        </div>
                        <?php } ?>
                    </div>
                    <div class="crm-next-control"></div>
                    <div class="crm-prev-control"></div>
                </div>

                <?php if ($settings['feedback_thumbnails']) { ?>
                    <div class="crm-feedback-control-slider swiper-container overflow-hidden">
                        <div class="swiper-wrapper">

                            <?php foreach( $settings['feedback_thumbnails'] as $thumbnails ) { ?>

                                <div class="crm-feedback-control-thumb swiper-slide">
                                    <img src="<?php echo $thumbnails['thumbnails_single']['url']; ?>" alt="client" class="img-fluid rounded-circle">
                                 </div>

                                
                            <?php } ?>
                        </div>
                    </div>
                    <div class="crm-next-control-outer crm-fd-slide-control"><i class="fa-solid fa-arrow-right"></i></div>
                    <div class="crm-prev-control-outer crm-fd-slide-control"><i class="fa-solid fa-arrow-left"></i></div>
                <?php } ?>

                
            </div>

        <?php } 

        

    }

}