<?php
/**
 * Quiety_Job custom post type.
 *
 * @package Quiety Core
 * @since   1.0.0
 */

// Prevent loading this file directly
defined( 'ABSPATH' ) || exit;

class Quiety_Job {
	/**
	 * Construct function.
	 *
	 * @return  void
	 */
	function __construct() {
		add_action( 'init', array( __CLASS__, 'quiety_job_init' ) );
		add_filter( 'single_template', array( $this, 'portfolio_single' ) );
	}

	/**
	 * Register a Quiety_Job post type.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/register_post_type
	 */
	public static function quiety_job_init() {
		if ( function_exists( 'quiety_option' ) ) {
			$slug_text = quiety_option( 'job_slug' );
		}

		$slug = ! empty( $slug_text ) ? $slug_text : 'job';

		register_post_type( 'quiety_job', array(
			'public'             => true,
			'publicly_queryable' => true,
			'show_ui'            => true,
			'show_in_menu'       => true,
			'query_var'          => true,
			'rewrite'            => array( 'slug' => $slug ),
			'capability_type'    => 'post',
			'has_archive'        => true,
			'hierarchical'       => true,
			'show_in_rest'       => true,
			'menu_position'      => 20,
			'menu_icon'          => 'dashicons-images-alt2',
			'supports'           => array( 'title', 'editor', 'thumbnail', 'comments' ),
			'labels'             => array(
				'name'               => _x( 'Job', 'quiety-core' ),
				'singular_name'      => _x( 'Job', 'quiety-core' ),
				'menu_name'          => _x( 'Job', 'quiety-core' ),
				'name_admin_bar'     => _x( 'Job', 'quiety-core' ),
				'add_new'            => _x( 'Add New', 'quiety-core' ),
				'add_new_item'       => __( 'Add New Job', 'quiety-core' ),
				'new_item'           => __( 'New Job', 'quiety-core' ),
				'edit_item'          => __( 'Edit Job', 'quiety-core' ),
				'view_item'          => __( 'View Job', 'quiety-core' ),
				'all_items'          => __( 'All Jobs', 'quiety-core' ),
				'search_items'       => __( 'Search Jobs', 'quiety-core' ),
				'parent_item_colon'  => __( 'Parent Jobs:', 'quiety-core' ),
				'not_found'          => __( 'No Job found.', 'quiety-core' ),
				'not_found_in_trash' => __( 'No Job found in Trash.', 'quiety-core' )
			),
		) );

		// Register job category
		register_taxonomy( 'quiety_job_cat', array( 'quiety_job' ), array(
			'hierarchical' => true,
			'show_ui'      => true,
			'show_in_rest' => true,

			'show_admin_column' => true,
			'query_var'         => true,
			'rewrite'           => array( 'slug' => 'job_cat' ),
			'labels'            => array(
				'name'              => _x( 'Categories', 'quiety-core' ),
				'singular_name'     => _x( 'Category', 'quiety-core' ),
				'search_items'      => __( 'Search Categories', 'quiety-core' ),
				'all_items'         => __( 'All Categories', 'quiety-core' ),
				'parent_item'       => __( 'Parent Category', 'quiety-core' ),
				'parent_item_colon' => __( 'Parent Category:', 'quiety-core' ),
				'edit_item'         => __( 'Edit Category', 'quiety-core' ),
				'update_item'       => __( 'Update Category', 'quiety-core' ),
				'add_new_item'      => __( 'Add New Category', 'quiety-core' ),
				'new_item_name'     => __( 'New Category Name', 'quiety-core' ),
				'menu_name'         => __( 'Categories', 'quiety-core' ),
			),
		) );


		//Register job tag
		register_taxonomy( 'quiety_job_tag', 'quiety_job', array(
			'hierarchical'          => true,
			'show_ui'               => true,
			'show_admin_column'     => true,
			'update_count_callback' => '_update_post_term_count',
			'query_var'             => true,
			'rewrite'               => array( 'slug' => 'quiety_job_tag' ),
			'labels'                => array(
				'name'                       => _x( 'Tags', 'quiety-core' ),
				'singular_name'              => _x( 'Tag', 'quiety-core' ),
				'search_items'               => __( 'Search Tags', 'quiety-core' ),
				'popular_items'              => __( 'Popular Tags', 'quiety-core' ),
				'all_items'                  => __( 'All Tags', 'quiety-core' ),
				'parent_item'                => null,
				'parent_item_colon'          => null,
				'edit_item'                  => __( 'Edit Tag', 'quiety-core' ),
				'update_item'                => __( 'Update Tag', 'quiety-core' ),
				'add_new_item'               => __( 'Add New Tag', 'quiety-core' ),
				'new_item_name'              => __( 'New Tag Name', 'quiety-core' ),
				'separate_items_with_commas' => __( 'Separate tag with commas', 'quiety-core' ),
				'add_or_remove_items'        => __( 'Add or remove tag', 'quiety-core' ),
				'choose_from_most_used'      => __( 'Choose from the most used tag', 'quiety-core' ),
				'not_found'                  => __( 'No tag found.', 'quiety-core' ),
				'menu_name'                  => __( 'Tags', 'quiety-core' ),
			),
		) );
	}

	/**
	 * Load single item template file for the job custom post type.
	 *
	 * @param string $template Current template file.
	 *
	 * @return  string
	 */
	function portfolio_single( $template ) {
		global $post;

		if ( $post->post_type == 'quiety_job' ) {
			$template = QUIETY_CORE_DIR . 'inc/post-type/job/views/single.php';
		}

		return $template;
	}


	/**
	 * Define helper function to print related job.
	 *
	 * @return  array
	 */
	public static function related() {

		global $post;
		// Get the good menu tags.
		$cats = get_the_terms( $post, 'quiety_job_cat' );

		if ( $cats ) {
			$cat_ids = array();

			foreach ( $cats as $cat ) {
				$cat_ids[] = $cat->term_id;
			}

			$post_perpage = quiety_option( 'relpost_count' ) ? quiety_option( 'relpost_count' ) : (int) '3';

			$args = array(
				'post_type'      => 'quiety_job',
				'post__not_in'   => array( $post->ID ),
				'posts_per_page' => 3,
				'tax_query'      => array(
					array(
						'taxonomy' => 'quiety_job_cat',
						'field'    => 'id',
						'terms'    => $cat_ids,
					),
				)
			);

			$the_query = new WP_Query( $args );

			?>

			<div class="related-job">
				<div class="container">
					<?php if ( quiety_option( 'related_job' ) || quiety_option( 'port_sub_title' ) !== '' ) { ?>
						<div class="section-heading style-one text-center">
							<?php if ( quiety_option( 'job_title' ) !== "" ) : ?>
								<h2 class="section-title"><?php echo esc_html( quiety_option( 'job_title' ) ) ?> </h2>
							<?php endif; ?>

							<?php if ( ! empty( quiety_option( 'title_description' ) )) :?>
							<p class="description">
								<?php echo wp_kses_post( quiety_option( 'title_description' ) ) ?>
							</p>
						<?php endif; ?>

						</div>
					<?php } ?>
					<div class="row">

						<?php
//						$paged      = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
//						$args       = array(
//							'post_type'      => 'quiety_job',
//							'paged'          => $paged,
//							//							'order'          => $settings['order'],
//							//							'orderby'        => $settings['order_by'],
//							'posts_per_page' => quiety_option( 'job_perpage' ),
//						);
//						$quiety_job = new \WP_Query( $args );


						if ( $the_query->have_posts() ) :
							while ( $the_query->have_posts() ) :
								$the_query->the_post();
								$meta = get_post_meta( get_the_ID(), 'quiety_job_options', true );
								?>

								<div class="col-md-6">
									<div <?php post_class( 'tt-job job-light' ); ?>>
										<p class="tt-job__type">
											<i class="fas fa-briefcase"></i>
											<span class="tt-job__type-text"><?php echo esc_html( $meta['job_type'] ); ?></span>
										</p>

										<h3 class="tt-job__title">
											<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
										</h3>

										<ul class="tt-job__info">
											<li>
												<i class="fas fa-building"></i>
												<span class="tt-job__info-text"><?php echo esc_html( $meta['company_name'] ); ?></span>
											</li>
											<li>
												<i class="fas fa-map-marker-alt"></i>
												<span class="tt-job__info-text"><?php echo esc_html( $meta['company_location'] ); ?></span>
											</li>
											<li>
												<i class="fas fa-wallet"></i>
												<span class="tt-job__info-text"><?php echo esc_html( $meta['salary'] ); ?></span>
											</li>
										</ul>

										<div class="tt-job__categories">
											<?php

											$terms = get_the_terms( get_the_ID(), 'quiety_job_cat' );

											if ( $terms && ! is_wp_error( $terms ) ) :
												foreach ( $terms as $term ) { ?>
													<span class="tt-job__category"><?php echo $term->name; ?></span>
												<?php } ?>
											<?php endif; ?>

										</div>

										<a href="<?php echo esc_url( the_permalink() ) ?>"
												class="tt-btn"><?php echo esc_html__( 'Apply Now', 'quiety-core' ) ?></a>
									</div>
								</div>
								<!-- /.col-md-6 -->
							<?php endwhile;
							wp_reset_postdata();
						endif; ?>
					</div>
				</div>
			</div>
		<?php }
		wp_reset_postdata();
	}
}

$portfolio = new Quiety_Job;