<?php
/**
 * Plugin Name: Quiety Core
 * Plugin URI: https://themeforest.net/user/themetags/portfolio
 * Description: This plugin adds the core features to the Quiety WordPress theme. You must have to install this plugin to get all the features included with the theme.
 * Version: 6.0.0
 * Author: ThemeTags
 * Author URI: https://themeforest.net/user/themetags/portfolio
 * Text domain: quiety-core
 */

if (!defined('ABSPATH'))
	die('-1');

/**
 * Currently plugin version.
 * Start at version 2.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define('QUIETY_CORE_VERSION', '6.0.0');

/**
 * Constant for the plugins
 */
define('QUIETY_PLUGIN_URL', plugins_url() . '/quiety-core/');
define('QUIETY_PLUGIN_ASSETS_URL', plugins_url() . '/quiety-core/assets/');
define('QUIETY_CORE_DIR', plugin_dir_path( __FILE__ ));
define('QUIETY_SCRIPTS', QUIETY_PLUGIN_URL . 'assets/js' );
define('QUIETY_VEND', QUIETY_PLUGIN_URL . 'assets/vendors' );


// Make sure the same class is not loaded twice in free/premium versions.
if (!class_exists('Quiety_Core')) {
	/**
	 * Main Quiety Core Class
	 *
	 * The main class that initiates and runs the Quiety Core plugin.
	 *
	 * @since 1.0.0
	 */
	final class Quiety_Core {
		/**
		 * Quiety Core Version
		 *
		 * Holds the version of the plugin.
		 *
		 * @since 1.0.0
		 * 
		 * @var string The plugin version.
		 */
		const VERSION = '1.0';

		/**
		 * Minimum Elementor Version
		 *
		 * Holds the minimum Elementor version required to run the plugin.
		 *
		 * @since 1.0.0
		 * 
		 * @var string Minimum Elementor version required to run the plugin.
		 */
		const MINIMUM_ELEMENTOR_VERSION = '3.3.0';

		/**
		 * Minimum PHP Version
		 *
		 * Holds the minimum PHP version required to run the plugin.
		 *
		 * @since 2.0.0
		 * 
		 * @var string Minimum PHP version required to run the plugin.
		 */
		const  MINIMUM_PHP_VERSION = '7.3';

		/**
		 * Instance
		 *
		 * Holds a single instance of the `Quiety_Core` class.
		 *
		 * @since 1.0.0
		 *
		 * @access private
		 * @static
		 *
		 * @var Quiety_Core A single instance of the class.
		 */
		private static $_instance = null;

		/**
		 * The loader that's responsible for maintaining and registering all hooks that power
		 * the plugin.
		 *
		 * @since    1.0.0
		 * @access   protected
		 * @var      Quiety_Core    $loader    Maintains and registers all hooks for the plugin.
		 */
		protected $loader;

		/**
		 * Instance
		 *
		 * Ensures only one instance of the class is loaded or can be loaded.
		 *
		 * @return Quiety_Core An instance of the class.
		 * @since 1.0.0
		 *
		 * @access public
		 * @static
		 *
		 */
		public static function instance() {
			if (is_null(self::$_instance)) {
				self::$_instance = new self();
			}

			return self::$_instance;
		}

		/**
		 * Clone
		 *
		 * Disable class cloning.
		 *
		 * @return void
		 * @since 1.0.0
		 *
		 * @access protected
		 *
		 */
		public function __clone() {
			// Cloning instances of the class is forbidden
			_doing_it_wrong(__FUNCTION__, esc_html__('Cheatin&#8217; huh?', 'quiety-core'), '2.0.0');
		}

		/**
		 * Wakeup
		 *
		 * Disable unserializing the class.
		 *
		 * @return void
		 * @since 1.0.0
		 *
		 * @access protected
		 *
		 */
		public function __wakeup() {
			// Unserializing instances of the class is forbidden.
			_doing_it_wrong(__FUNCTION__, esc_html__('Cheatin&#8217; huh?', 'quiety-core'), '2.0.0');
		}

		/**
		 * Constructor
		 *
		 * Initialize the Quiety Core plugins.
		 *
		 * @since 1.0.0
		 *
		 * @access public
		 */
		public function __construct() {
			$this->core_includes();
			$this->init_hooks();
			do_action('quiety_core_loaded');
		}

		/**
		 * Include Files
		 *
		 * Load core files required to run the plugin.
		 *
		 * @since 1.0.0
		 *
		 * @access public
		 */
		public function core_includes()	{
			// Extra
			require_once __DIR__ . '/inc/mailchimp.php';
			require_once __DIR__ . '/inc/extra.php';
			require_once __DIR__ . '/inc/post-type/mega-menu.php';
			require_once __DIR__ . '/inc/post-type/footer.php';
			require_once __DIR__ . '/inc/post-type/job/init.php';
			require_once __DIR__ . '/inc/post-type/support/init.php';
			require_once __DIR__ . '/inc/post-type/portfolio/init.php';

            //Classes functions
            require_once __DIR__ . '/inc/classes/class-plugins-helper.php';

			//Elementor Widgets
			require_once __DIR__ . '/elementor/elementor_init.php';

			// Elementor custom field icons
			require_once __DIR__ . '/elementor/fields/icons.php';
			require_once __DIR__ . '/inc/class-quiety-helper.php';
		}

		/**
		 * Init Hooks
		 *
		 * Hook into actions and filters.
		 *
		 * @since 1.0.0
		 *
		 * @access private
		 */
		private function init_hooks() {
			add_action('init', [$this, 'i18n']);
			add_action('plugins_loaded', [$this, 'init']);
			add_action( 'init', [ $this, 'quiety_gutenberg_block_init' ] );
		}

		/**
		 * Load Textdomain
		 *
		 * Load plugin localization files.
		 *
		 * @since 1.0.0
		 *
		 * @access public
		 */
		public function i18n() {
			load_plugin_textdomain('quiety-core', false, plugin_basename(dirname(__FILE__)) . '/languages');
		}

		/**
		 * Init Quiety Core
		 *
		 * Load the plugin after Elementor (and other plugins) are loaded.
		 *
		 * @since 1.0.0
		 * @since 2.0.0 The logic moved from a standalone function to this class method.
		 *
		 * @access public
		 */
		public function init() {

			if (!did_action('elementor/loaded')) {
				add_action('admin_notices', [$this, 'admin_notice_missing_main_plugin']);
				return;
			}

			// Check for required Elementor version
			if (!version_compare(ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=')) {
				add_action('admin_notices', [$this, 'admin_notice_minimum_elementor_version']);
				return;
			}

			// Check for required PHP version
			if (version_compare(PHP_VERSION, self::MINIMUM_PHP_VERSION, '<')) {
				add_action('admin_notices', [$this, 'admin_notice_minimum_php_version']);
				return;
			}

			// Register Widget Scripts
			add_action( 'elementor/frontend/after_enqueue_styles', [ $this, 'enqueue_widget_styles' ] );
			add_action( 'wp_enqueue_scripts', [ $this, 'quiety_enqueue_style' ] );
			add_action( 'elementor/editor/before_enqueue_scripts', [ $this, 'enqueue_widget_styles' ] );
			add_action( 'wp_enqueue_scripts', [ $this, 'quiety_dequeue' ], 100 );
			add_action( 'enqueue_block_editor_assets', [ $this, 'quiety_block_editor_assets' ] );
			add_action( 'admin_enqueue_scripts', [ $this, 'quiety_admin_enqueue_scripts' ] );
		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have Elementor installed or activated.
		 *
		 * @since 1.1.0
		 * @since 2.0.0 Moved from a standalone function to a class method.
		 *
		 * @access public
		 */
		public function admin_notice_missing_main_plugin() {
			$message = sprintf(
			/* translators: 1: Quiety Core: Elementor */
				esc_html__('"%1$s" requires "%2$s" to be installed and activated.', 'quiety-core'),
				'<strong>' . esc_html__('Quiety Core', 'quiety-core') . '</strong>',
				'<strong>' . esc_html__('Elementor', 'quiety-core') . '</strong>'
			);
			printf('<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message);
		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have a minimum required Elementor version.
		 *
		 * @since 1.1.0
		 * @since 2.0.0 Moved from a standalone function to a class method.
		 *
		 * @access public
		 */
		public function admin_notice_minimum_elementor_version() {
			$message = sprintf(
			/* translators: 1: Quiety Core: Elementor 3: Required Elementor version */
				esc_html__('"%1$s" requires "%2$s" version %3$s or greater.', 'quiety-core'),
				'<strong>' . esc_html__('Quiety Core', 'quiety-core') . '</strong>',
				'<strong>' . esc_html__('Elementor', 'quiety-core') . '</strong>',
				self::MINIMUM_ELEMENTOR_VERSION
			);
			printf('<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message);
		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have a minimum required PHP version.
		 *
		 * @since 2.0.0
		 *
		 * @access public
		 */
		public function admin_notice_minimum_php_version() {
			$message = sprintf(
			/* translators: 1: Quiety Core 2: PHP 3: Required PHP version */
				esc_html__('"%1$s" requires "%2$s" version %3$s or greater.', 'quiety-core'),
				'<strong>' . esc_html__('Quiety Elements', 'quiety-core') . '</strong>',
				'<strong>' . esc_html__('PHP', 'quiety-core') . '</strong>',
				self::MINIMUM_PHP_VERSION
			);
			printf('<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message);
		}

		public function quiety_enqueue_style() {
			wp_enqueue_style('quiety-core-css', plugins_url('assets/css/app.css', __FILE__));
		}

		/**
		 * Register Widget Styles
		 *
		 * Register custom styles required to run Quiety Core.
		 *
		 * @since 2.0.0
		 * @since 1.7.1 The method moved to this class.
		 *
		 * @access public
		 */

		public function enqueue_widget_styles()	{		
			wp_enqueue_style('swiper', QUIETY_VEND . '/swiper/swiper.min.css' );
			wp_enqueue_style('themify-icons', plugins_url('assets/vendors/themify-icon/themify-icons.css', __FILE__));
			wp_enqueue_style('elegant-icons', plugins_url('assets/vendors/components-elegant-icons/css/elegant-icons.min.css', __FILE__));
			wp_enqueue_style('flaticon', plugins_url('assets/vendors/flaticon//css/flaticon.css', __FILE__));
			wp_enqueue_style('feather', plugins_url('assets/vendors/feather/css/feather.css', __FILE__));
		}

		public function quiety_admin_enqueue_scripts() {
			wp_enqueue_style('quiety-gutenberg-block-editor', plugins_url('assets/css/editor.css', __FILE__));
		}


		/**
		 * Dequeue the Elementor Animation CSS.
		 *
		 * Hooked to the wp_print_scripts action, with a late priority (100),
		 * so that it is after the script was enqueued.
		 */

		function quiety_dequeue() {
			add_action('wp_footer', [ $this, 'remove_elementor_animations_css' ]);
		}

		function remove_elementor_animations_css() {
			wp_dequeue_style('e-animations');
			wp_deregister_style('e-animations');
		}

		public function quiety_block_editor_assets() {
			wp_enqueue_script (
				'quiety-gutenberg-editor-script',
				plugins_url('build/index.js', __FILE__),
				[
					'wp-block-editor', 'wp-blocks', 'wp-components', 'wp-element', 'wp-i18n', 'wp-polyfill', 'wp-server-side-render'
				]
			);
		}

		/*
		 * Gutenberg Block Register
		 */
		public function quiety_gutenberg_block_init() {
			register_block_type(
				'quiety-block/newsletter-widget',
				[
					'render_callback' => [ $this, 'render_newsletter' ],
					'attributes'      => [
						'btn_text'       => [
							'default' => __('Subscribe', 'crafto-core'),
							'type'    => 'string',
						],
						'content'       => [
							'default' => __('Subscribe to our newsletter to receive early discount offers.', 'crafto-core'),
							'type'    => 'string',
						],
					],
				]
			);
		}

		public function render_newsletter( $attributes ) {
			ob_start(); ?>
			<div class="wp-widget-block-newsletter">
				<p class="description"><?php echo $attributes['content'] ?></p>

				<form action="<?php echo admin_url( 'admin-ajax.php' ); ?>" method="post" class="footer-newsletter-form widget-newsletter" data-tt-form="newsletter-subscribe">
					<input type="hidden" name="action" value="quiety_mailchimp_subscribe">

					<div class="newsletter-inner d-flex">
						<input type="email" name="email" class="form-control" id="newsletter-form-email" placeholder="<?php echo esc_attr__( 'Email', 'quiety-core' ); ?>" required>
						<button type="submit" name="submit" id="newsletter-submit" class="newsletter-submit tt-btn">
							<?php echo esc_html($attributes['btn_text']); ?>
							<i class="fa fa-circle-o-notch fa-spin"></i>
						</button>
					</div>

					<div class="form-result alert">
						<div class="content"></div>
					</div><!-- /.form-result-->
				</form><!-- /.newsletter-form -->
				</div>
			<!-- /.wp-widget-block-newsletter -->
			<?php
			return ob_get_clean();
		}
	}
}
// Make sure the same function is not loaded twice in free/premium versions.

if (!function_exists('quiety_core_load')) {
	/**
	 * Load Quiety Core
	 *
	 * Main instance of Quiety_Core.
	 *
	 * @since 1.0.0
	 * @since 2.0.0 The logic moved from this function to a class method.
	 */
	function quiety_core_load()	{
		return Quiety_Core::instance();
	}

	// Run Quiety Core
	quiety_core_load();
}